@@ -55,7 +55,6 @@ block_info_to_hv(block_info_t *block_info, HV *hv)
 		}
 		hv_store_sv(hv, "ionode_inx", newRV_noinc((SV*)av));
 	}
-	STORE_FIELD(hv, block_info, job_running, uint32_t);
 	if(block_info->linuximage)
 		STORE_FIELD(hv, block_info, linuximage, charp);
 	if(block_info->mloaderimage)
@@ -63,9 +62,8 @@ block_info_to_hv(block_info_t *block_info, HV *hv)
 	if(block_info->mp_str)
 		STORE_FIELD(hv, block_info, mp_str, charp);
 	STORE_FIELD(hv, block_info, cnode_cnt, uint32_t);
+	STORE_FIELD(hv, block_info, cnode_err_cnt, uint32_t);
 	STORE_FIELD(hv, block_info, node_use, uint16_t);
-	if (block_info->owner_name)
-		STORE_FIELD(hv, block_info, owner_name, charp);
 	if(block_info->ramdiskimage)
 		STORE_FIELD(hv, block_info, ramdiskimage, charp);
 	if(block_info->reason)
@@ -124,13 +122,11 @@ hv_to_block_info(HV *hv, block_info_t *block_info)
 	} else {
 		/* nothing to do */
 	}
-	FETCH_FIELD(hv, block_info, job_running, uint32_t, TRUE);
 	FETCH_FIELD(hv, block_info, linuximage, charp, FALSE);
 	FETCH_FIELD(hv, block_info, mloaderimage, charp, FALSE);
 	FETCH_FIELD(hv, block_info, mp_str, charp, FALSE);
 	FETCH_FIELD(hv, block_info, cnode_cnt, uint32_t, TRUE);
 	FETCH_FIELD(hv, block_info, node_use, uint16_t, TRUE);
-	FETCH_FIELD(hv, block_info, owner_name, charp, FALSE);
 	FETCH_FIELD(hv, block_info, ramdiskimage, charp, FALSE);
 	FETCH_FIELD(hv, block_info, reason, charp, FALSE);
 	FETCH_FIELD(hv, block_info, state, uint16_t, TRUE);
@@ -252,13 +248,11 @@ hv_to_update_block_msg(HV *hv, update_block_msg_t *update_msg)
 	} else {
 		/* nothing to do */
 	}
-	FETCH_FIELD(hv, update_msg, job_running, uint32_t, FALSE);
 	FETCH_FIELD(hv, update_msg, linuximage, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, mloaderimage, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, mp_str, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, cnode_cnt, uint32_t, FALSE);
 	FETCH_FIELD(hv, update_msg, node_use, uint16_t, FALSE);
-	FETCH_FIELD(hv, update_msg, owner_name, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, ramdiskimage, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, reason, charp, FALSE);
 	FETCH_FIELD(hv, update_msg, state, uint16_t, FALSE);
