@@ -11,7 +11,7 @@
 #  CODE-OCEC-09-009. All rights reserved.
 #
 #  This file is part of SLURM, a resource management program.
-#  For details, see <http://www.schedmd.com/slurmdocs/>.
+#  For details, see <http://slurm.schedmd.com/>.
 #  Please also read the included file: DISCLAIMER.
 #
 #  SLURM is free software; you can redistribute it and/or modify it under
@@ -48,16 +48,13 @@ use lib "${FindBin::Bin}/../lib/perl";
 use autouse 'Pod::Usage' => qw(pod2usage);
 use Slurm ':all';
 use Switch;
+use English;
 
 my ($start_time,
     $account,
- #   $checkpoint_interval,
-    $directive_prefix,
     $err_path,
     $interactive,
     $hold,
-#    $join,
-#    $keep,
     $resource_list,
     $mail_options,
     $mail_user_list,
@@ -65,14 +62,10 @@ my ($start_time,
     $out_path,
     $priority,
     $destination,
-#    $rerunable,
-#    $script_path,
-#    $running_user_list,
-#    $variable_list,
-#    $all_env,
-    $additional_attributes,
-#    $no_std,
+    $variable_list,
+    @additional_attributes,
     $help,
+    $resp,
     $man);
 
 my $sbatch = "${FindBin::Bin}/sbatch";
@@ -81,14 +74,11 @@ my $srun = "${FindBin::Bin}/srun";
 
 GetOptions('a=s'      => \$start_time,
 	   'A=s'      => \$account,
-#	   'c=i'      => \$checkpoint_interval,
-	   'C=s'      => \$directive_prefix,
 	   'e=s'      => \$err_path,
 	   'h'        => \$hold,
 	   'I'        => \$interactive,
 	   'j:s'      => sub { warn "option -j is the default, " .
 				    "stdout/stderr go into the same file\n" },
-#	   'k=s'      => \$keep,
 	   'l=s'      => \$resource_list,
 	   'm=s'      => \$mail_options,
 	   'M=s'      => \$mail_user_list,
@@ -96,17 +86,13 @@ GetOptions('a=s'      => \$start_time,
 	   'o=s'      => \$out_path,
 	   'p=i'      => \$priority,
 	   'q=s'      => \$destination,
-#	   'r=s'      => \$rerunable,
-#	   'S=s'      => \$script_path,
-#	   'u=s'      => \$running_user_list,
-	   'v=s'      => sub { warn "option -v is not supported, " .
-				    "since the current environment " .
-				    "is exported by default\n" },
+	   'S=s'      => sub { warn "option -S is ignored, " .
+				    "specify shell via #!<shell> in the job script\n" },
+	   'v=s'      => \$variable_list,
 	   'V'        => sub { warn "option -V is not necessary, " .
 				    "since the current environment " .
 				    "is exported by default\n" },
-	   'W'        => \$additional_attributes,
-#	   'z'        => \$no_std,
+	   'W=s'      => \@additional_attributes,
 	   'help|?'   => \$help,
 	   'man'      => \$man,
 	   )
@@ -135,13 +121,40 @@ if ($ARGV[0]) {
 	foreach (@ARGV) {
 	        $script .= "$_ ";
 	}
-} else {
-        pod2usage(2);
 }
+my $block="false";
+my $depend;
+my $group_list;
+my $job_id;
 my %res_opts;
 my %node_opts;
 
-if($resource_list) {
+# remove PBS_NODEFILE environment as passed in to qsub.
+if ($ENV{PBS_NODEFILE}) {
+	delete $ENV{PBS_NODEFILE};
+}
+
+# Process options provided with the -W name=value syntax.
+my $W;
+foreach $W (@additional_attributes) {
+	my($name, $value) = split('=', $W);
+	if ($name eq 'umask') {
+		$ENV{SLURM_UMASK} = $value;
+	} elsif ($name eq 'depend') {
+		$depend = $value;
+	} elsif ($name eq 'group_list') {
+		$group_list = $value;
+	} elsif (lc($name) eq 'block') {
+		if (defined $value) {
+			$block = $value;
+		}
+#	} else {
+#		print("Invalid attribute: $W!");
+#		exit(1);
+	}
+}
+
+if ($resource_list) {
 	%res_opts = %{parse_resource_list($resource_list)};
 
 # 	while((my $key, my $val) = each(%res_opts)) {
@@ -156,6 +169,26 @@ if($resource_list) {
 	if($res_opts{nodes}) {
 		%node_opts =  %{parse_node_opts($res_opts{nodes})};
 	}
+	if ($res_opts{select} && (!$node_opts{node_cnt} || ($res_opts{select} > $node_opts{node_cnt}))) {
+		$node_opts{node_cnt} = $res_opts{select};
+	}
+	if ($res_opts{select} && $res_opts{ncpus} && $res_opts{mpiprocs}) {
+		my $cpus_per_task = int ($res_opts{ncpus} / $res_opts{mppnppn});
+		if (!$res_opts{mppdepth} || ($cpus_per_task > $res_opts{mppdepth})) {
+			$res_opts{mppdepth} = $cpus_per_task;
+		}
+	}
+}
+
+if($variable_list) {
+	$variable_list =~ s/\'/\"/g;
+	my @parts = $variable_list =~ m/(?:(?<=")[^"]*(?=(?:\s*"\s*,|\s*"\s*$)))|(?<=,)(?:[^",]*(?=(?:\s*,|\s*$)))|(?<=^)(?:[^",]+(?=(?:\s*,|\s*$)))|(?<=^)(?:[^",]*(?=(?:\s*,)))/g;
+	foreach my $part (@parts) {
+		my ($key, $value) = $part =~ /(.*)=(.*)/;
+		if ($key && $value) {
+			$ENV{$key} = $value;
+		}
+	}
 }
 
 my $command;
@@ -163,18 +196,44 @@ my $command;
 if($interactive) {
 	$command = "$salloc";
 
+#	Always want at least one node in the allocation
+	if (!$node_opts{node_cnt}) {
+		$node_opts{node_cnt} = 1;
+	}
+
+#	Calculate the task count based of the node cnt and the amount
+#	of ppn's in the request
+	if ($node_opts{task_cnt}) {
+		$node_opts{task_cnt} *= $node_opts{node_cnt};
+	}
+
+	if (!$node_opts{node_cnt} && !$node_opts{task_cnt} && !$node_opts{hostlist}) {
+		$node_opts{task_cnt} = 1;
+	}
 } else {
+	if (!$script) {
+		pod2usage(2);
+	}
+
 	$command = "$sbatch";
 
-	$command .= " -D $directive_prefix" if $directive_prefix;
 	$command .= " -e $err_path" if $err_path;
 	$command .= " -o $out_path" if $out_path;
+
+#	The job size specification may be within the batch script,
+#	Reset task count if node count also specified
+	if ($node_opts{task_cnt} && $node_opts{node_cnt}) {
+		$node_opts{task_cnt} *= $node_opts{node_cnt};
+	}
 }
 
 $command .= " -N$node_opts{node_cnt}" if $node_opts{node_cnt};
 $command .= " -n$node_opts{task_cnt}" if $node_opts{task_cnt};
 $command .= " -w$node_opts{hostlist}" if $node_opts{hostlist};
 
+$command .= " --mincpus=$res_opts{ncpus}"            if $res_opts{ncpus};
+$command .= " --ntasks-per-node=$res_opts{mppnppn}"  if $res_opts{mppnppn};
+
 if($res_opts{walltime}) {
 	$command .= " -t$res_opts{walltime}";
 } elsif($res_opts{cput}) {
@@ -183,14 +242,19 @@ if($res_opts{walltime}) {
 	$command .= " -t$res_opts{pcput}";
 }
 
-$command .= " --tmp=$res_opts{file}" if $res_opts{file};
-$command .= " --mem=$res_opts{mem}" if $res_opts{mem};
+$command .= " --account='$group_list'" if $group_list;
+$command .= " --constraint='$res_opts{proc}'" if $res_opts{proc};
+$command .= " --dependency=$depend"   if $depend;
+$command .= " --tmp=$res_opts{file}"  if $res_opts{file};
+$command .= " --mem=$res_opts{mem}"   if $res_opts{mem};
 $command .= " --nice=$res_opts{nice}" if $res_opts{nice};
+
+$command .= " --gres=gpu:$res_opts{naccelerators}"  if $res_opts{naccelerators};
+
 # Cray-specific options
 $command .= " -n$res_opts{mppwidth}"		    if $res_opts{mppwidth};
 $command .= " -w$res_opts{mppnodes}"		    if $res_opts{mppnodes};
 $command .= " --cpus-per-task=$res_opts{mppdepth}"  if $res_opts{mppdepth};
-$command .= " --ntasks-per-node=$res_opts{mppnppn}" if $res_opts{mppnppn};
 
 $command .= " --begin=$start_time" if $start_time;
 $command .= " --account=$account" if $account;
@@ -205,49 +269,127 @@ $command .= " --mail-user=$mail_user_list" if $mail_user_list;
 $command .= " -J $job_name" if $job_name;
 $command .= " --nice=$priority" if $priority;
 $command .= " -p $destination" if $destination;
-$command .= " -C $additional_attributes" if $additional_attributes;
+$command .= " $script" if $script;
 
+# print "$command\n";
 
-$command .= " $script";
+# Execute the command and capture its stdout, stderr, and exit status. Note
+# that if interactive mode was requested, the standard output and standard
+# error are _not_ captured.
+if ($interactive) {
+	my $ret = system($command);
+	exit ($ret >> 8);
+} else {
+	# Capture stderr from the command to the stdout stream.
+	$command .= ' 2>&1';
 
-system($command);
+	# Execute the command and capture the combined stdout and stderr.
+	my @command_output = `$command 2>&1`;
 
+	# Save the command exit status.
+	my $command_exit_status = $CHILD_ERROR;
+
+	# If available, extract the job ID from the command output and print
+	# it to stdout, as done in the PBS version of qsub.
+	# The "Submitted batch job" header is for backward compatability
+	# with earlier versions of Slurm's qsub wrapper
+	if ($command_exit_status == 0) {
+		my @spcommand_output=split(" ", $command_output[$#command_output]);
+		$job_id= $spcommand_output[$#spcommand_output];
+		print "Submitted batch job ";
+		print "$job_id\n";
+	} else {
+		print("There was an error running the SLURM sbatch command.\n" .
+		      "The command was:\n" .
+		      "'$command'\n" .
+		      "and the output was:\n" .
+		      "'@command_output'\n");
+	}
+
+	# If block is true wait for the job to finish
+	my($resp, $count);
+	my $slurm = Slurm::new();
+	if ( (lc($block) eq "true" ) and ($command_exit_status == 0) ) {
+		sleep 2;
+		my($job) = $slurm->load_job($job_id);
+		$resp = $$job{'job_array'}[0]->{job_state};
+		while ( $resp < JOB_COMPLETE ) {
+			$job = $slurm->load_job($job_id);
+			$resp = $$job{'job_array'}[0]->{job_state};
+			sleep 1;
+		}
+	}
+
+	# Exit with the command return code.
+	exit($command_exit_status >> 8);
+}
 
 sub parse_resource_list {
 	my ($rl) = @_;
-	my %opt = ('arch' => "",
+	my %opt = ('accelerator' => "",
+		   'arch' => "",
+		   'block' => "",
 		   'cput' => "",
 		   'file' => "",
 		   'host' => "",
 		   'mem' => "",
+		   'mpiprocs' => "",
+		   'ncpus' => "",
 		   'nice' => "",
 		   'nodes' => "",
+		   'naccelerators' => "",
 		   'opsys' => "",
 		   'other' => "",
 		   'pcput' => "",
 		   'pmem' => "",
+		   'proc' => '',
 		   'pvmem' => "",
+		   'select' => "",
 		   'software' => "",
 		   'vmem' => "",
+		   'walltime' => "",
 		   # Cray-specific resources
 		   'mppwidth' => "",
 		   'mppdepth' => "",
 		   'mppnppn' => "",
 		   'mppmem' => "",
-		   'mppnodes' => "",
-		   'walltime' => ""
+		   'mppnodes' => ""
 		   );
 	my @keys = keys(%opt);
 
+#	The select option uses a ":" separator rather than ","
+#	This wrapper currently does not support multiple select options
+
+#	Protect the colons used to separate elements in walltime=hh:mm:ss.
+#	Convert to NNhNNmNNs format.
+	$rl =~ s/walltime=(\d{1,2}):(\d{2}):(\d{2})/walltime=$1h$2m$3s/;
+
+	$rl =~ s/:/,/g;
 	foreach my $key (@keys) {
 		#print "$rl\n";
 		($opt{$key}) = $rl =~ m/$key=([\w:\+=+]+)/;
 
 	}
+
+#	If needed, un-protect the walltime string.
+	if ($opt{walltime}) {
+		$opt{walltime} =~ s/(\d{1,2})h(\d{2})m(\d{2})s/$1:$2:$3/;
+#		Convert to minutes for SLURM.
+		$opt{walltime} = get_minutes($opt{walltime});
+	}
+
+	if($opt{accelerator} && $opt{accelerator} =~ /^[Tt]/ && !$opt{naccelerators}) {
+		$opt{naccelerators} = 1;
+	}
+
 	if($opt{cput}) {
 		$opt{cput} = get_minutes($opt{cput});
 	}
 
+	if ($opt{mpiprocs} && (!$opt{mppnppn} || ($opt{mpiprocs} > $opt{mppnppn}))) {
+		$opt{mppnppn} = $opt{mpiprocs};
+	}
+
 	if($opt{mppmem}) {
 		$opt{mem} = convert_mb_format($opt{mppmem});
 	} elsif($opt{mem}) {
@@ -294,18 +436,6 @@ sub parse_node_opts {
 	my $hl_cnt = Slurm::Hostlist::count($hl);
 	$opt{node_cnt} = $hl_cnt if $hl_cnt > $opt{node_cnt};
 
-	# we always want at least one here
-	if(!$opt{node_cnt}) {
-
-		$opt{node_cnt} = 1;
-	}
-
-	# figure out the amount of tasks based of the node cnt and the amount
-	# of ppn's in the request
-	if($opt{task_cnt}) {
-		$opt{task_cnt} *= $opt{node_cnt};
-	}
-
 	return \%opt;
 }
 
@@ -366,25 +496,24 @@ B<qsub> - submit a batch job in a familiar pbs format
 
 =head1 SYNOPSIS
 
-qsub  [-a date_time]
-      [-A account_string]
-      [-b secs]
-      [-C directive_prefix]
-      [-e path]
+qsub  [-a start_time]
+      [-A account]
+      [-e err_path]
       [-I]
       [-l resource_list]
-      [-m mail_options] [-M  user_list]
-      [-N name]
-      [-o path]
+      [-m mail_options] [-M user_list]
+      [-N job_name]
+      [-o out_path]
       [-p priority]
       [-q destination]
+      [-v variable_list]
       [-W additional_attributes]
       [-h]
       [script]
 
 =head1 DESCRIPTION
 
-The B<qsub> command displays information about nodes. It is aimed to be feature-compatible with PBS' qsub.
+The B<qsub> submits batch jobs. It is aimed to be feature-compatible with PBS' qsub.
 
 =head1 OPTIONS
 
@@ -392,24 +521,58 @@ The B<qsub> command displays information about nodes. It is aimed to be feature-
 
 =item B<-a>
 
-Display information for all nodes. This is the default if no node name is specified.
+Earliest start time of job. Format: [HH:MM][MM/DD/YY]
+
+=item B<-A account>
+
+Specify the account to which the job should be charged.
+
+=item B<-e err_path>
+
+Specify a new path to receive the standard error output for the job.
 
 =item B<-I>
 
 Interactive execution.
 
-=item B<-j> join
+=item B<-l resource_list>
 
-It is not necessary (currently also not possible) since stderr/stdout are always joined.
+Specify an additional list of resources to request for the job.
+
+=item B<-m mail_options>
+
+Specify a list of events on which email is to be generated.
+
+=item B<-M user_list>
+
+Specify a list of email addresses to receive messages on specified events.
+
+=item B<-N job_name>
+
+Specify a name for the job.
+
+=item B<-o out_path>
+
+Specify the path to a file to hold the standard output from the job.
+
+=item B<-p priority>
+
+Specify the priority under which the job should run.
+
+=item B<-p priority>
+
+Specify the priority under which the job should run.
 
 =item B<-v> [variable_list]
 
-Exporting single variables via -v is not supported, since the entire login environment
-is exported by the default.
+Exporting single variables via -v is generally not required, since the entire
+login environment is exported by the default. However this option can be used
+to add newly defined environment variables to specific jobs.
 
 =item B<-V>
 
-The -V option to export the current environment is not required since it is done by default.
+The -V option to export the current environment is not required since it is
+done by default.
 
 =item B<-?> | B<--help>
 
