@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -66,7 +66,7 @@ static int _sort_pids_by_name(job_step_pids_t *rec_a, job_step_pids_t *rec_b)
 {
 	int diff = 0;
 
-	if(!rec_a->node_name || !rec_b->node_name)
+	if (!rec_a->node_name || !rec_b->node_name)
 		return 0;
 
 	diff = strcmp(rec_a->node_name, rec_b->node_name);
@@ -80,7 +80,7 @@ static int _sort_pids_by_name(job_step_pids_t *rec_a, job_step_pids_t *rec_b)
 
 static int _sort_stats_by_name(job_step_stat_t *rec_a, job_step_stat_t *rec_b)
 {
-	if(!rec_a->step_pids || !rec_b->step_pids)
+	if (!rec_a->step_pids || !rec_b->step_pids)
 		return 0;
 
 	return _sort_pids_by_name(rec_a->step_pids, rec_b->step_pids);
@@ -157,17 +157,30 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 	else
 		secs2time_str ((time_t)job_step_ptr->time_limit * 60,
 				limit_str, sizeof(limit_str));
+	if (job_step_ptr->array_job_id) {
+		snprintf(tmp_line, sizeof(tmp_line), "StepId=%u_%u.%u ",
+			 job_step_ptr->array_job_id,
+			 job_step_ptr->array_task_id, job_step_ptr->step_id);
+		out = xstrdup(tmp_line);
+	} else {
+		snprintf(tmp_line, sizeof(tmp_line), "StepId=%u.%u ",
+			 job_step_ptr->job_id, job_step_ptr->step_id);
+		out = xstrdup(tmp_line);
+	}
 	snprintf(tmp_line, sizeof(tmp_line),
-		"StepId=%u.%u UserId=%u StartTime=%s TimeLimit=%s",
-		job_step_ptr->job_id, job_step_ptr->step_id,
-		job_step_ptr->user_id, time_str, limit_str);
-	out = xstrdup(tmp_line);
+		 "UserId=%u StartTime=%s TimeLimit=%s",
+		 job_step_ptr->user_id, time_str, limit_str);
+	xstrcat(out, tmp_line);
 	if (one_liner)
 		xstrcat(out, " ");
 	else
 		xstrcat(out, "\n   ");
 
 	/****** Line 2 ******/
+	snprintf(tmp_line, sizeof(tmp_line),
+		 "State=%s ",
+		 job_state_string(job_step_ptr->state));
+	xstrcat(out, tmp_line);
 	if (cluster_flags & CLUSTER_FLAG_BG) {
 		char *io_nodes;
 		select_g_select_jobinfo_get(job_step_ptr->select_jobinfo,
@@ -199,7 +212,6 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 		xstrcat(out, "\n   ");
 
 	/****** Line 3 ******/
-
 	if (cluster_flags & CLUSTER_FLAG_BGQ) {
 		uint32_t nodes = 0;
 		select_g_select_jobinfo_get(job_step_ptr->select_jobinfo,
@@ -235,10 +247,10 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 		xstrcat(out, "\n   ");
 
 	/****** Line 5 ******/
-	if (job_step_ptr->cpu_freq == NO_VAL)
+	if (job_step_ptr->cpu_freq == NO_VAL) {
 		snprintf(tmp_line, sizeof(tmp_line), 
 			 "CPUFreqReq=Default\n\n");
-	else if (job_step_ptr->cpu_freq & CPU_FREQ_RANGE_FLAG) {
+	} else if (job_step_ptr->cpu_freq & CPU_FREQ_RANGE_FLAG) {
 		switch (job_step_ptr->cpu_freq) 
 		{
 		case CPU_FREQ_LOW :
@@ -257,10 +269,10 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 			snprintf(tmp_line, sizeof(tmp_line),
 				 "CPUFreqReq=Unknown\n\n");
 		}
-	}
-	else 
+	} else {
 		snprintf(tmp_line, sizeof(tmp_line),
 			 "CPUFreqReq=%u\n\n", job_step_ptr->cpu_freq);
+	}
 	xstrcat(out, tmp_line);
 
 	return out;
@@ -494,8 +506,8 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
 
 	xassert(resp);
 
-	if(!node_list) {
-		if(!(step_layout =
+	if (!node_list) {
+		if (!(step_layout =
 		     slurm_job_step_layout_get(job_id, step_id))) {
 			rc = errno;
 			error("slurm_job_step_get_pids: "
@@ -506,7 +518,7 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
 		node_list = step_layout->node_list;
 	}
 
-	if(!*resp) {
+	if (!*resp) {
 		resp_out = xmalloc(sizeof(job_step_pids_response_msg_t));
 		*resp = resp_out;
 		created = 1;
@@ -526,11 +538,11 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
 	req_msg.msg_type = REQUEST_JOB_STEP_PIDS;
         req_msg.data = &req;
 
-        if(!(ret_list = slurm_send_recv_msgs(node_list,
+        if (!(ret_list = slurm_send_recv_msgs(node_list,
 					     &req_msg, 0, false))) {
                 error("slurm_job_step_get_pids: got an error no list returned");
                 rc = SLURM_ERROR;
-		if(created) {
+		if (created) {
 			slurm_job_step_pids_response_msg_free(resp_out);
 			*resp = NULL;
 		}
@@ -541,7 +553,7 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
         while((ret_data_info = list_next(itr))) {
                 switch (ret_data_info->type) {
 			case RESPONSE_JOB_STEP_PIDS:
-				if(!resp_out->pid_list)
+				if (!resp_out->pid_list)
 					resp_out->pid_list = list_create(
 						slurm_free_job_step_pids);
 				list_push(resp_out->pid_list,
@@ -568,7 +580,7 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
         list_iterator_destroy(itr);
         list_destroy(ret_list);
 
- 	if(resp_out->pid_list)
+ 	if (resp_out->pid_list)
 		list_sort(resp_out->pid_list, (ListCmpF)_sort_pids_by_name);
 cleanup:
 	slurm_step_layout_destroy(step_layout);
@@ -590,8 +602,8 @@ extern void slurm_job_step_pids_response_msg_free(void *object)
 {
 	job_step_pids_response_msg_t *step_pids_msg =
 		(job_step_pids_response_msg_t *) object;
-	if(step_pids_msg) {
-		if(step_pids_msg->pid_list)
+	if (step_pids_msg) {
+		if (step_pids_msg->pid_list)
 			list_destroy(step_pids_msg->pid_list);
 		xfree(step_pids_msg);
 	}
@@ -606,8 +618,8 @@ extern void slurm_job_step_stat_response_msg_free(void *object)
 {
 	job_step_stat_response_msg_t *step_stat_msg =
 		(job_step_stat_response_msg_t *) object;
-	if(step_stat_msg) {
-		if(step_stat_msg->stats_list)
+	if (step_stat_msg) {
+		if (step_stat_msg->stats_list)
 			list_destroy(step_stat_msg->stats_list);
 		xfree(step_stat_msg);
 	}
