@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -64,6 +64,7 @@
 
 typedef struct {
 	pthread_cond_t *notify;
+	int            *p_thr_count;
 	slurm_msg_t *orig_msg;
 	List ret_list;
 	int timeout;
@@ -73,9 +74,19 @@ typedef struct {
 
 void _destroy_tree_fwd(fwd_tree_t *fwd_tree)
 {
-	if(fwd_tree) {
-		if(fwd_tree->tree_hl)
+	if (fwd_tree) {
+		if (fwd_tree->tree_hl)
 			hostlist_destroy(fwd_tree->tree_hl);
+
+		/*
+		 * Lock and decrease thread counter, start_msg_tree is waiting
+		 * for a null thread count to exit its main loop
+		 */
+		slurm_mutex_lock(fwd_tree->tree_mutex);
+		(*(fwd_tree->p_thr_count))--;
+		pthread_cond_signal(fwd_tree->notify);
+		slurm_mutex_unlock(fwd_tree->tree_mutex);
+
 		xfree(fwd_tree);
 	}
 }
@@ -95,8 +106,8 @@ void *_forward_thread(void *arg)
 	int start_timeout = fwd_msg->timeout;
 
 	/* repeat until we are sure the message was sent */
-	while((name = hostlist_shift(hl))) {
-		if(slurm_conf_get_addr(name, &addr) == SLURM_ERROR) {
+	while ((name = hostlist_shift(hl))) {
+		if (slurm_conf_get_addr(name, &addr) == SLURM_ERROR) {
 			error("forward_thread: can't find address for host "
 			      "%s, check slurm.conf", name);
 			slurm_mutex_lock(fwd_msg->forward_mutex);
@@ -153,7 +164,7 @@ void *_forward_thread(void *arg)
 		/*
 		 * forward message
 		 */
-		if(_slurm_msg_sendto(fd,
+		if (_slurm_msg_sendto(fd,
 				     get_buf_data(buffer),
 				     get_buf_offset(buffer),
 				     SLURM_PROTOCOL_NO_SEND_RECV_FLAGS ) < 0) {
@@ -163,7 +174,7 @@ void *_forward_thread(void *arg)
 			mark_as_failed_forward(&fwd_msg->ret_list, name,
 					       errno);
 			free(name);
-			if(hostlist_count(hl) > 0) {
+			if (hostlist_count(hl) > 0) {
 				free_buf(buffer);
 				buffer = init_buf(fwd_msg->buf_len);
 				slurm_mutex_unlock(fwd_msg->forward_mutex);
@@ -182,7 +193,7 @@ void *_forward_thread(void *arg)
 			list_push(fwd_msg->ret_list, ret_data_info);
 			ret_data_info->node_name = xstrdup(name);
 			free(name);
-			while((name = hostlist_shift(hl))) {
+			while ((name = hostlist_shift(hl))) {
 				ret_data_info =
 					xmalloc(sizeof(ret_data_info_t));
 				list_push(fwd_msg->ret_list, ret_data_info);
@@ -192,7 +203,7 @@ void *_forward_thread(void *arg)
 			goto cleanup;
 		}
 
-		if(fwd_msg->header.forward.cnt > 0) {
+		if (fwd_msg->header.forward.cnt > 0) {
 			static int message_timeout = -1;
 			if (message_timeout < 0)
 				message_timeout =
@@ -210,13 +221,13 @@ void *_forward_thread(void *arg)
 		/* info("sent %d forwards got %d back", */
 /* 		     fwd_msg->header.forward.cnt, list_count(ret_list)); */
 
-		if(!ret_list || (fwd_msg->header.forward.cnt != 0
+		if (!ret_list || (fwd_msg->header.forward.cnt != 0
 				 && list_count(ret_list) <= 1)) {
 			slurm_mutex_lock(fwd_msg->forward_mutex);
 			mark_as_failed_forward(&fwd_msg->ret_list, name,
 					       errno);
 			free(name);
-			if(ret_list)
+			if (ret_list)
 				list_destroy(ret_list);
 			if (hostlist_count(hl) > 0) {
 				free_buf(buffer);
@@ -227,7 +238,7 @@ void *_forward_thread(void *arg)
 				continue;
 			}
 			goto cleanup;
-		} else if((fwd_msg->header.forward.cnt+1)
+		} else if ((fwd_msg->header.forward.cnt+1)
 			  != list_count(ret_list)) {
 			/* this should never be called since the above
 			   should catch the failed forwards and pipe
@@ -243,23 +254,23 @@ void *_forward_thread(void *arg)
 			      "but only got %d back",
 			      (fwd_msg->header.forward.cnt+1),
 			      list_count(ret_list));
-			while((tmp = hostlist_next(host_itr))) {
+			while ((tmp = hostlist_next(host_itr))) {
 				int node_found = 0;
 				itr = list_iterator_create(ret_list);
-				while((ret_data_info = list_next(itr))) {
-					if(!ret_data_info->node_name) {
+				while ((ret_data_info = list_next(itr))) {
+					if (!ret_data_info->node_name) {
 						first_node_found = 1;
 						ret_data_info->node_name =
 							xstrdup(name);
 					}
-					if(!strcmp(tmp,
+					if (!strcmp(tmp,
 						   ret_data_info->node_name)) {
 						node_found = 1;
 						break;
 					}
 				}
 				list_iterator_destroy(itr);
-				if(!node_found) {
+				if (!node_found) {
 					mark_as_failed_forward(
 						&fwd_msg->ret_list,
 						tmp,
@@ -268,7 +279,7 @@ void *_forward_thread(void *arg)
 				free(tmp);
 			}
 			hostlist_iterator_destroy(host_itr);
-			if(!first_node_found) {
+			if (!first_node_found) {
 				mark_as_failed_forward(&fwd_msg->ret_list,
 						       name,
 						       SLURM_COMMUNICATIONS_CONNECTION_ERROR);
@@ -277,9 +288,9 @@ void *_forward_thread(void *arg)
 		break;
 	}
 	slurm_mutex_lock(fwd_msg->forward_mutex);
-	if(ret_list) {
-		while((ret_data_info = list_pop(ret_list)) != NULL) {
-			if(!ret_data_info->node_name) {
+	if (ret_list) {
+		while ((ret_data_info = list_pop(ret_list)) != NULL) {
+			if (!ret_data_info->node_name) {
 				ret_data_info->node_name = xstrdup(name);
 			}
 			list_push(fwd_msg->ret_list, ret_data_info);
@@ -409,7 +420,7 @@ void *_fwd_tree_thread(void *arg)
 		free(name);
 
 		/* check for error and try again */
-		if(errno == SLURM_COMMUNICATIONS_CONNECTION_ERROR)
+		if (errno == SLURM_COMMUNICATIONS_CONNECTION_ERROR)
  			continue;
 
 		break;
@@ -429,7 +440,7 @@ void *_fwd_tree_thread(void *arg)
  */
 extern void forward_init(forward_t *forward, forward_t *from)
 {
-	if(from && from->init == FORWARD_INIT) {
+	if (from && from->init == FORWARD_INIT) {
 		forward->cnt = from->cnt;
 		forward->timeout = from->timeout;
 		forward->nodelist = from->nodelist;
@@ -466,7 +477,7 @@ extern int forward_msg(forward_struct_t *forward_struct,
 	hostlist_t forward_hl = NULL;
 	char *name = NULL;
 
-	if(!forward_struct->ret_list) {
+	if (!forward_struct->ret_list) {
 		error("didn't get a ret_list from forward_struct");
 		xfree(span);
 		return SLURM_ERROR;
@@ -474,7 +485,7 @@ extern int forward_msg(forward_struct_t *forward_struct,
 	hl = hostlist_create(header->forward.nodelist);
 	hostlist_uniq(hl);
 
-	while((name = hostlist_shift(hl))) {
+	while ((name = hostlist_shift(hl))) {
 		pthread_attr_t attr_agent;
 		pthread_t thread_agent;
 		char *buf = NULL;
@@ -489,7 +500,7 @@ extern int forward_msg(forward_struct_t *forward_struct,
 
 		forward_msg->timeout = forward_struct->timeout;
 
-		if(forward_msg->timeout <= 0) {
+		if (forward_msg->timeout <= 0) {
 			/* convert secs to msec */
 			forward_msg->timeout  = slurm_get_msg_timeout() * 1000;
 		}
@@ -514,7 +525,7 @@ extern int forward_msg(forward_struct_t *forward_struct,
 		free(name);
 		for(j = 0; j < span[thr_count]; j++) {
 			name = hostlist_shift(hl);
-			if(!name)
+			if (!name)
 				break;
 			hostlist_push(forward_hl, name);
 			free(name);
@@ -524,7 +535,7 @@ extern int forward_msg(forward_struct_t *forward_struct,
 		hostlist_destroy(forward_hl);
 		forward_init(&forward_msg->header.forward, NULL);
 		forward_msg->header.forward.nodelist = buf;
-		while(pthread_create(&thread_agent, &attr_agent,
+		while (pthread_create(&thread_agent, &attr_agent,
 				     _forward_thread,
 				     (void *)forward_msg)) {
 			error("pthread_create error %m");
@@ -592,6 +603,7 @@ extern List start_msg_tree(hostlist_t hl, slurm_msg_t *msg, int timeout)
 		fwd_tree->ret_list = ret_list;
 		fwd_tree->timeout = timeout;
 		fwd_tree->notify = &notify;
+		fwd_tree->p_thr_count = &thr_count;
 		fwd_tree->tree_mutex = &tree_mutex;
 
 		if (fwd_tree->timeout <= 0) {
@@ -609,6 +621,17 @@ extern List start_msg_tree(hostlist_t hl, slurm_msg_t *msg, int timeout)
 			free(name);
 		}
 
+		/*
+		 * Lock and increase thread counter, we need that to protect
+		 * the start_msg_tree waiting loop that was originally designed
+		 * around a "while ((count < host_count))" loop. In case where a
+		 * fwd thread was not able to get all the return codes from
+		 * children, the waiting loop was deadlocked.
+		 */
+		slurm_mutex_lock(&tree_mutex);
+		thr_count++;
+		slurm_mutex_unlock(&tree_mutex);
+
 		while (pthread_create(&thread_agent, &attr_agent,
 				      _fwd_tree_thread, (void *)fwd_tree)) {
 			error("pthread_create error %m");
@@ -617,7 +640,7 @@ extern List start_msg_tree(hostlist_t hl, slurm_msg_t *msg, int timeout)
 			sleep(1);	/* sleep and try again */
 		}
 		slurm_attr_destroy(&attr_agent);
-		thr_count++;
+
 	}
 	xfree(span);
 
@@ -625,12 +648,13 @@ extern List start_msg_tree(hostlist_t hl, slurm_msg_t *msg, int timeout)
 
 	count = list_count(ret_list);
 	debug2("Tree head got back %d looking for %d", count, host_count);
-	while ((count < host_count)) {
+	while (thr_count > 0) {
 		pthread_cond_wait(&notify, &tree_mutex);
 		count = list_count(ret_list);
 		debug2("Tree head got back %d", count);
 	}
-	debug2("Tree head got them all");
+	xassert(count >= host_count);	/* Tree head did not get all responses,
+					 * but no more active fwd threads!*/
 	slurm_mutex_unlock(&tree_mutex);
 
 	slurm_mutex_destroy(&tree_mutex);
@@ -652,7 +676,7 @@ extern void mark_as_failed_forward(List *ret_list, char *node_name, int err)
 	ret_data_info_t *ret_data_info = NULL;
 
 	debug3("problems with %s", node_name);
-	if(!*ret_list)
+	if (!*ret_list)
 		*ret_list = list_create(destroy_data_info);
 
 	ret_data_info = xmalloc(sizeof(ret_data_info_t));
@@ -669,7 +693,7 @@ extern void forward_wait(slurm_msg_t * msg)
 	int count = 0;
 
 	/* wait for all the other messages on the tree under us */
-	if(msg->forward_struct) {
+	if (msg->forward_struct) {
 		debug2("looking for %d", msg->forward_struct->fwd_cnt);
 		slurm_mutex_lock(&msg->forward_struct->forward_mutex);
 		count = 0;
@@ -677,7 +701,7 @@ extern void forward_wait(slurm_msg_t * msg)
 			count = list_count(msg->ret_list);
 
 		debug2("Got back %d", count);
-		while((count < msg->forward_struct->fwd_cnt)) {
+		while ((count < msg->forward_struct->fwd_cnt)) {
 			pthread_cond_wait(&msg->forward_struct->notify,
 					  &msg->forward_struct->forward_mutex);
 
@@ -697,7 +721,7 @@ extern void forward_wait(slurm_msg_t * msg)
 void destroy_data_info(void *object)
 {
 	ret_data_info_t *ret_data_info = (ret_data_info_t *)object;
-	if(ret_data_info) {
+	if (ret_data_info) {
 		slurm_free_msg_data(ret_data_info->type,
 				    ret_data_info->data);
 		xfree(ret_data_info->node_name);
@@ -707,7 +731,7 @@ void destroy_data_info(void *object)
 
 void destroy_forward(forward_t *forward)
 {
-	if(forward->init == FORWARD_INIT) {
+	if (forward->init == FORWARD_INIT) {
 		xfree(forward->nodelist);
 		forward->init = 0;
 	} else {
@@ -717,7 +741,7 @@ void destroy_forward(forward_t *forward)
 
 void destroy_forward_struct(forward_struct_t *forward_struct)
 {
-	if(forward_struct) {
+	if (forward_struct) {
 		xfree(forward_struct->buf);
 		xfree(forward_struct->forward_msg);
 		slurm_mutex_destroy(&forward_struct->forward_mutex);
