@@ -48,11 +48,13 @@
 
 #include <assert.h>
 #include <errno.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "list.h"
 #include "macros.h"
 #include "xmalloc.h"
+#include "src/common/log.h"
 
 /*
 ** Define slurm-specific aliases for use by plugins, see slurm_xlator.h
@@ -92,21 +94,16 @@ strong_alias(list_install_fork_handlers, slurm_list_install_fork_handlers);
 #include <unistd.h>
 #ifdef WITH_LSD_FATAL_ERROR_FUNC
 #  undef lsd_fatal_error
-   extern void lsd_fatal_error(char *file, int line, char *mesg);
+	extern void lsd_fatal_error(char *file, int line, char *mesg);
 #else /* !WITH_LSD_FATAL_ERROR_FUNC */
 #  ifndef lsd_fatal_error
-#    include <errno.h>
-#    include <stdio.h>
-#    include <string.h>
-#    define lsd_fatal_error(file, line, mesg)                                 \
-       do {                                                                   \
-	   fprintf(stderr, "ERROR: [%s:%d] %s: %s\n",                         \
-		   file, line, mesg, strerror(errno));                        \
-       } while (0)
+	static void lsd_fatal_error(char *file, int line, char *mesg)
+	{
+		log_fatal(file, line, mesg, strerror(errno));
+	}
 #  endif /* !lsd_fatal_error */
 #endif /* !WITH_LSD_FATAL_ERROR_FUNC */
 
-
 /*********************
  *  lsd_nomem_error  *
  *********************/
@@ -116,7 +113,13 @@ strong_alias(list_install_fork_handlers, slurm_list_install_fork_handlers);
    extern void * lsd_nomem_error(char *file, int line, char *mesg);
 #else /* !WITH_LSD_NOMEM_ERROR_FUNC */
 #  ifndef lsd_nomem_error
-#    define lsd_nomem_error(file, line, mesg) (NULL)
+	static void * lsd_nomem_error(char *file, int line, char *mesg)
+	{
+		
+		log_oom(file, line, mesg);
+		abort();
+		return NULL;
+	}
 #  endif /* !lsd_nomem_error */
 #endif /* !WITH_LSD_NOMEM_ERROR_FUNC */
 
@@ -384,7 +387,7 @@ list_append_list (List l, List sub)
     assert(sub != NULL);
     itr = list_iterator_create(sub);
     while((v = list_next(itr))) {
-	if(list_append(l, v))
+	if (list_append(l, v))
 	    n++;
 	else
 	    break;
@@ -404,10 +407,10 @@ list_transfer (List l, List sub)
     assert(sub != NULL);
     assert(l->fDel == sub->fDel);
     while((v = list_pop(sub))) {
-	if(list_append(l, v))
+	if (list_append(l, v))
 	    n++;
 	else {
-	    if(l->fDel)
+	    if (l->fDel)
 		l->fDel(v);
 	    break;
 	}
@@ -526,6 +529,88 @@ list_flush (List l)
     return(n);
 }
 
+void
+list_sort2 (List l, ListCmpF f)
+{
+    ListIterator it;
+
+    ListNode p, q, e, tail, head;
+    int insize, nmerges, psize, qsize, i;
+
+    assert(l != NULL);
+    assert(f != NULL);
+    list_mutex_lock(&l->mutex);
+    assert(l->magic == LIST_MAGIC);
+    head = l->head;
+    if (l->count > 1) {
+        insize=1;
+        while(1) {
+           p = head;
+           head = NULL;
+           tail = NULL;
+
+
+           nmerges = 0;
+           while(p) {
+              nmerges++;
+              q = p;
+
+              psize=0;
+              for (i = 0; i < insize; i++) {
+                psize++;
+                q = q->next;
+
+                if (!q) break;
+              }
+              qsize = insize;
+              while (psize > 0 || (qsize > 0 && q)) {
+                 if (psize == 0) {
+                    e = q;
+                    q = q->next;
+                    qsize--;
+                 } else if (qsize == 0 || !q ) {
+                    e = p;
+                    p = p->next;
+                    psize--;
+                 } else if (f(p->data,q->data) < 0) {
+                    e = p;
+                    p = p->next;
+                    psize--;
+                 } else {
+                    e = q;
+                    q = q->next;
+                    qsize--;
+                 }
+                 if (tail) {
+                    tail->next = e;
+                 } else {
+                    head = e;
+                 }
+                 tail = e;
+              }
+              p = q;
+
+           }
+           tail->next = NULL;
+           if(nmerges <= 1) {
+              l->head = head;
+	      l->tail = &tail->next;
+              for (it=l->iNext; it; it=it->iNext) {
+                  assert(it->magic == LIST_MAGIC);
+                  it->pos = it->list->head;
+                  it->prev = &it->list->head;
+              }
+
+              list_mutex_unlock(&l->mutex);
+              return;
+           }
+           insize *=2;
+        }
+    }
+
+    list_mutex_unlock(&l->mutex);
+    return;
+}
 
 void
 list_sort (List l, ListCmpF f)
@@ -560,7 +645,6 @@ list_sort (List l, ListCmpF f)
 	    }
 	}
 	l->tail = pp;
-
 	for (i=l->iNext; i; i=i->iNext) {
 	    assert(i->magic == LIST_MAGIC);
 	    i->pos = i->list->head;
@@ -1009,8 +1093,10 @@ list_reinit_mutexes (void)
 void list_install_fork_handlers (void)
 {
 	int err;
-	if ((err = pthread_atfork(NULL, NULL, &list_reinit_mutexes)))
+	if ((err = pthread_atfork(NULL, NULL, &list_reinit_mutexes))) {
 		lsd_fatal_error(__FILE__, __LINE__, "list atfork install");
+		abort();
+	}
 	return;
 }
 #else
