@@ -109,6 +109,8 @@ typedef struct {
 	unsigned    buffered:1;     /* Use internal buffer to never block */
 } 	log_options_t;
 
+extern char *slurm_prog_name;
+
 /* some useful initializers for log_options_t
  */
 #define LOG_OPTS_INITIALIZER	\
@@ -205,11 +207,16 @@ void log_set_fpfx(char *pfx);
  */
 void log_set_argv0(char *pfx);
 
-/* grab the FILE * of the current logfile (or stderr if not logging to
- * a file)
- */
+/* Return the FILE * of the current logfile (or stderr if not logging to
+ * a file, but NOT both). Also see log_fatal() and log_oom() below. */
 FILE *log_fp(void);
 
+/* Log fatal error without message buffering */
+void log_fatal(const char *file, int line, const char *msg, const char *err_str);
+
+/* Log out of memory without message buffering */
+void log_oom(const char *file, int line, const char *func);
+
 /*
  * Buffered log functions:
  *
@@ -224,6 +231,12 @@ bool log_has_data(void);
  */
 void log_flush(void);
 
+/* log_set_debug_flags()
+ * Set or reset the debug flags based on the configuration
+ * file or the scontrol command.
+ */
+extern void log_set_debug_flags(void);
+
 /*
  * the following log a message to the log facility at the appropriate level:
  *
