@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -58,7 +58,7 @@ extern void destroy_print_field(void *object)
 {
 	print_field_t *field = (print_field_t *)object;
 
-	if(field) {
+	if (field) {
 		xfree(field->name);
 		xfree(field);
 	}
@@ -71,18 +71,18 @@ extern void print_fields_header(List print_fields_list)
 	int curr_inx = 1;
 	int field_count = 0;
 
-	if(!print_fields_list || !print_fields_have_header)
+	if (!print_fields_list || !print_fields_have_header)
 		return;
 
 	field_count = list_count(print_fields_list);
 
 	itr = list_iterator_create(print_fields_list);
-	while((field = list_next(itr))) {
-		if(print_fields_parsable_print
+	while ((field = list_next(itr))) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && (curr_inx == field_count))
 			printf("%s", field->name);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%s|", field->name);
 		else {
 			int abs_len = abs(field->len);
@@ -92,9 +92,9 @@ extern void print_fields_header(List print_fields_list)
 	}
 	list_iterator_reset(itr);
 	printf("\n");
-	if(print_fields_parsable_print)
+	if (print_fields_parsable_print)
 		return;
-	while((field = list_next(itr))) {
+	while ((field = list_next(itr))) {
 		int abs_len = abs(field->len);
 		printf("%*.*s ", abs_len, abs_len,
 		       "-----------------------------------------------------");
@@ -107,17 +107,14 @@ extern void print_fields_date(print_field_t *field, time_t value, int last)
 {
 	int abs_len = abs(field->len);
 	char temp_char[abs_len+1];
-	time_t now = value;
 
-	if(!now)
-		now = time(NULL);
 	slurm_make_time_str(&value, (char *)temp_char, sizeof(temp_char));
-	if(print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
+	if (print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
 	   && last)
 		printf("%s", temp_char);
-	else if(print_fields_parsable_print)
+	else if (print_fields_parsable_print)
 		printf("%s|", temp_char);
-	else if(field->len == abs_len)
+	else if (field->len == abs_len)
 		printf("%*.*s ", abs_len, abs_len, temp_char);
 	else
 		printf("%-*.*s ", abs_len, abs_len, temp_char);
@@ -128,21 +125,21 @@ extern void print_fields_str(print_field_t *field, char *value, int last)
 	int abs_len = abs(field->len);
 	char temp_char[abs_len+1];
 	char *print_this = NULL;
-	if(!value) {
-		if(print_fields_parsable_print)
+	if (!value) {
+		if (print_fields_parsable_print)
 			print_this = "";
 		else
 			print_this = " ";
 	} else
 		print_this = value;
 
-	if(print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
+	if (print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
 	   && last)
 		printf("%s", print_this);
-	else if(print_fields_parsable_print)
+	else if (print_fields_parsable_print)
 		printf("%s|", print_this);
 	else {
-		if(value) {
+		if (value) {
 			int len = strlen(value);
 			memcpy(&temp_char, value, MIN(len, abs_len) + 1);
 
@@ -151,7 +148,7 @@ extern void print_fields_str(print_field_t *field, char *value, int last)
 			print_this = temp_char;
 		}
 
-		if(field->len == abs_len)
+		if (field->len == abs_len)
 			printf("%*.*s ", abs_len, abs_len, print_this);
 		else
 			printf("%-*.*s ", abs_len, abs_len, print_this);
@@ -162,23 +159,23 @@ extern void print_fields_int(print_field_t *field, int value, int last)
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == NO_VAL) || (value == INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == NO_VAL) || (value == INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", abs_len, " ");
 	} else {
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%d", value);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%d|", value);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*d ", abs_len, value);
 		else
 			printf("%-*d ", abs_len, value);
@@ -189,23 +186,23 @@ extern void print_fields_uint32(print_field_t *field, uint32_t value, int last)
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == NO_VAL) || (value == INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == NO_VAL) || (value == INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%u", value);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%u|", value);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*u ", abs_len, value);
 		else
 			printf("%-*u ", abs_len, value);
@@ -217,23 +214,23 @@ extern void print_fields_uint64(print_field_t *field, uint64_t value, int last)
 	int abs_len = abs(field->len);
 
 	/* (value == unset)  || (value == cleared) */
-	if((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%llu", (long long unsigned) value);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%llu|", (long long unsigned) value);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*llu ", abs_len, (long long unsigned) value);
 		else
 			printf("%-*llu ", abs_len, (long long unsigned) value);
@@ -244,23 +241,23 @@ extern void print_fields_double(print_field_t *field, double value, int last)
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == NO_VAL) || (value == INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == NO_VAL) || (value == INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%f", value);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%f|", value);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*f ", abs_len, value);
 		else
 			printf("%-*f ", abs_len, value);
@@ -272,23 +269,23 @@ extern void print_fields_long_double(
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == NO_VAL) || (value == INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == NO_VAL) || (value == INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%Lf", value);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%Lf|", value);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*Lf ", abs_len, value);
 		else
 			printf("%-*Lf ", abs_len, value);
@@ -300,25 +297,25 @@ extern void print_fields_time(print_field_t *field, uint64_t value, int last)
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
 		char time_buf[32];
 		mins2time_str((time_t) value, time_buf, sizeof(time_buf));
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%s", time_buf);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%s|", time_buf);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*s ", abs_len, time_buf);
 		else
 			printf("%-*s ", abs_len, time_buf);
@@ -330,25 +327,25 @@ extern void print_fields_time_from_secs(print_field_t *field,
 {
 	int abs_len = abs(field->len);
 	/* (value == unset)  || (value == cleared) */
-	if((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
-		if(print_fields_parsable_print
+	if ((value == (uint64_t)NO_VAL) || (value == (uint64_t)INFINITE)) {
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			;
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("|");
 		else
 			printf("%*s ", field->len, " ");
 	} else {
 		char time_buf[32];
 		secs2time_str((time_t) value, time_buf, sizeof(time_buf));
-		if(print_fields_parsable_print
+		if (print_fields_parsable_print
 		   == PRINT_FIELDS_PARSABLE_NO_ENDING
 		   && last)
 			printf("%s", time_buf);
-		else if(print_fields_parsable_print)
+		else if (print_fields_parsable_print)
 			printf("%s|", time_buf);
-		else if(field->len == abs_len)
+		else if (field->len == abs_len)
 			printf("%*s ", abs_len, time_buf);
 		else
 			printf("%-*s ", abs_len, time_buf);
@@ -362,16 +359,16 @@ extern void print_fields_char_list(print_field_t *field, List value, int last)
 	char *print_this = NULL;
 	char *object = NULL;
 
-	if(!value || !list_count(value)) {
-		if(print_fields_parsable_print)
+	if (!value || !list_count(value)) {
+		if (print_fields_parsable_print)
 			print_this = xstrdup("");
 		else
 			print_this = xstrdup(" ");
 	} else {
 		list_sort(value, (ListCmpF)_sort_char_list);
 		itr = list_iterator_create(value);
-		while((object = list_next(itr))) {
-			if(print_this)
+		while ((object = list_next(itr))) {
+			if (print_this)
 				xstrfmtcat(print_this, ",%s", object);
 			else
 				print_this = xstrdup(object);
@@ -379,16 +376,16 @@ extern void print_fields_char_list(print_field_t *field, List value, int last)
 		list_iterator_destroy(itr);
 	}
 
-	if(print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
+	if (print_fields_parsable_print == PRINT_FIELDS_PARSABLE_NO_ENDING
 	   && last)
 		printf("%s", print_this);
-	else if(print_fields_parsable_print)
+	else if (print_fields_parsable_print)
 		printf("%s|", print_this);
-	else {
-		if(strlen(print_this) > abs_len)
+	else if (print_this) {
+		if (strlen(print_this) > abs_len)
 			print_this[abs_len-1] = '+';
 
-		if(field->len == abs_len)
+		if (field->len == abs_len)
 			printf("%*.*s ", abs_len, abs_len, print_this);
 		else
 			printf("%-*.*s ", abs_len, abs_len, print_this);
