@@ -7,7 +7,7 @@
  *  from existing SLURM source code, particularly src/srun/opt.c
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -68,6 +68,10 @@ void print_slurm_version(void);
 /* print the available gres options */
 void print_gres_help(void);
 
+/* set distribution type strings from distribution type const */
+void set_distribution(task_dist_states_t distribution,
+		      char **dist, char **lllp_dist);
+
 /* verify the requested distribution type */
 task_dist_states_t verify_dist_type(const char *arg, uint32_t *plane_size);
 
