@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -231,7 +231,7 @@ static slurm_errtab_t slurm_errtab[] = {
 	  "Job violates accounting/QOS policy (job submit limit, user's "
 	  "size and/or time limits)"},
 	{ ESLURM_INVALID_TIME_LIMIT,
-	  "Requested time limit is invalid (exceeds some limit)"},
+	  "Requested time limit is invalid (missing or exceeds some limit)"},
 	{ ESLURM_RESERVATION_ACCESS,
 	  "Access denied to requested reservation"		},
 	{ ESLURM_RESERVATION_INVALID,
@@ -286,6 +286,8 @@ static slurm_errtab_t slurm_errtab[] = {
 	  "Switch resources currently not available"		},
 	{ ESLURM_RESERVATION_EMPTY,
 	  "Reservation request lacks users or accounts"		},
+	{ ESLURM_INVALID_ARRAY,
+	  "Invalid job array specification"			},
 
 	/* slurmd error codes */
 
@@ -391,7 +393,11 @@ static slurm_errtab_t slurm_errtab[] = {
 	{ ESLURM_ONE_CHANGE,
 	  "Can only change one at a time"                       },
 	{ ESLURM_BAD_NAME,
-	  "Unacceptable name given. (No '.' in name allowed)"   }
+	  "Unacceptable name given. (No '.' in name allowed)"   },
+
+	/* plugin and custom errors */
+	{ ESLURM_MISSING_TIME_LIMIT,
+	  "Missing time limit"   }
 };
 
 /*
