@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -44,12 +44,13 @@
 typedef struct slurm_priority_ops {
 	uint32_t (*set)            (uint32_t last_prio,
 				    struct job_record *job_ptr);
-	void     (*reconfig)       (void);
+	void     (*reconfig)       (bool assoc_clear);
 	void     (*set_assoc_usage)(slurmdb_association_rec_t *assoc);
 	double   (*calc_fs_factor) (long double usage_efctv,
 				    long double shares_norm);
 	List	 (*get_priority_factors)
 	(priority_factors_request_msg_t *req_msg, uid_t uid);
+	void     (*job_end)        (struct job_record *job_ptr);
 } slurm_priority_ops_t;
 
 /*
@@ -61,6 +62,7 @@ static const char *syms[] = {
 	"priority_p_set_assoc_usage",
 	"priority_p_calc_fs_factor",
 	"priority_p_get_priority_factors_list",
+	"priority_p_job_end",
 };
 
 static slurm_priority_ops_t ops;
@@ -124,12 +126,12 @@ extern uint32_t priority_g_set(uint32_t last_prio, struct job_record *job_ptr)
 	return (*(ops.set))(last_prio, job_ptr);
 }
 
-extern void priority_g_reconfig(void)
+extern void priority_g_reconfig(bool assoc_clear)
 {
 	if (slurm_priority_init() < 0)
 		return;
 
-	(*(ops.reconfig))();
+	(*(ops.reconfig))(assoc_clear);
 
 	return;
 }
@@ -162,3 +164,11 @@ extern List priority_g_get_priority_factors_list(
 	return (*(ops.get_priority_factors))(req_msg, uid);
 }
 
+extern void priority_g_job_end(struct job_record *job_ptr)
+{
+	if (slurm_priority_init() < 0)
+		return;
+
+	(*(ops.job_end))(job_ptr);
+}
+
