@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -183,6 +183,8 @@ typedef enum {
 	RESPONSE_PING_SLURMD,
 	REQUEST_ACCT_GATHER_UPDATE,
 	RESPONSE_ACCT_GATHER_UPDATE,
+	REQUEST_ACCT_GATHER_ENERGY,
+	RESPONSE_ACCT_GATHER_ENERGY,
 
 	REQUEST_BUILD_INFO = 2001,
 	RESPONSE_BUILD_INFO,
@@ -222,6 +224,8 @@ typedef enum {
 	RESPONSE_STATS_INFO,
 	REQUEST_STATS_RESET,
 	RESPONSE_STATS_RESET,
+	REQUEST_JOB_USER_INFO,
+	REQUEST_NODE_INFO_SINGLE,
 
 	REQUEST_UPDATE_JOB = 3001,
 	REQUEST_UPDATE_NODE,
@@ -318,7 +322,8 @@ typedef enum {
 	SRUN_EXEC,
 	SRUN_STEP_MISSING,
 	SRUN_REQUEST_SUSPEND,
-	SRUN_STEP_SIGNAL,	/* BluegeneQ: srun forwards signal to runjob */
+	SRUN_STEP_SIGNAL,	/* for launch plugins aprun, poe and runjob,
+				 * srun forwards signal to the launch command */
 
 	PMI_KVS_PUT_REQ = 7201,
 	PMI_KVS_PUT_RESP,
@@ -479,7 +484,7 @@ typedef struct job_step_kill_msg {
 	uint32_t job_id;
 	uint32_t job_step_id;
 	uint16_t signal;
-	uint16_t batch_flag;
+	uint16_t flags;
 } job_step_kill_msg_t;
 
 typedef struct job_notify_msg {
@@ -493,6 +498,11 @@ typedef struct job_id_msg {
 	uint16_t show_flags;
 } job_id_msg_t;
 
+typedef struct job_user_id_msg {
+	uint32_t user_id;
+	uint16_t show_flags;
+} job_user_id_msg_t;
+
 typedef struct job_step_id_msg {
 	uint32_t job_id;
 	uint32_t step_id;
@@ -515,6 +525,11 @@ typedef struct node_info_request_msg {
 	uint16_t show_flags;
 } node_info_request_msg_t;
 
+typedef struct node_info_single_msg {
+	char *node_name;
+	uint16_t show_flags;
+} node_info_single_msg_t;
+
 typedef struct front_end_info_request_msg {
 	time_t last_update;
 } front_end_info_request_msg_t;
@@ -609,7 +624,9 @@ typedef struct job_step_specs {
 	uint16_t immediate;	/* 1 if allocate to run or fail immediately,
 				 * 0 if to be queued awaiting resources */
 	uint32_t job_id;	/* job ID */
-	uint32_t mem_per_cpu;	/* MB memory required per CPU, 0=no limit */
+	uint32_t pn_min_memory; /* minimum real memory per node OR
+				 * real memory per CPU | MEM_PER_CPU,
+				 * default=0 (use job limit) */
 	char *name;		/* name of the job step, default "" */
 	char *network;		/* network use spec */
 	uint32_t min_nodes;	/* minimum number of nodes required by job,
@@ -680,7 +697,7 @@ typedef struct launch_tasks_request_msg {
 				     1 for "user manged" IO */
 	uint8_t open_mode;	/* stdout/err append or truncate */
 	uint8_t pty;		/* use pseudo tty */
-	uint16_t acctg_freq;	/* accounting polling interval */
+	char *acctg_freq;	/* accounting polling intervals */
 	uint32_t cpu_freq;	/* requested cpu frequency */
 
 	/********** START "normal" IO only options **********/
@@ -694,6 +711,7 @@ typedef struct launch_tasks_request_msg {
 	uint16_t  *io_port;  /* array of available client IO listen ports */
 	/**********  END  "normal" IO only options **********/
 
+	uint32_t profile;
 	char     *task_prolog;
 	char     *task_epilog;
 
@@ -781,6 +799,8 @@ typedef struct reattach_tasks_response_msg {
 } reattach_tasks_response_msg_t;
 
 typedef struct batch_job_launch_msg {
+	uint32_t array_job_id;	/* job array master job ID */
+	uint16_t array_task_id;	/* job array ID or NO_VAL */
 	uint32_t job_id;
 	uint32_t step_id;
 	uint32_t uid;
@@ -813,7 +833,7 @@ typedef struct batch_job_launch_msg {
 	uint32_t pn_min_memory;  /* minimum real memory per node OR
 				  * real memory per CPU | MEM_PER_CPU,
 				  * default=0 (no limit) */
-	uint16_t acctg_freq;	/* accounting polling interval	*/
+	char *acctg_freq;	/* accounting polling intervals	*/
 	uint32_t cpu_freq;	/* requested cpu frequency */
 	uint32_t job_mem;	/* memory limit for job		*/
 	uint16_t restart_cnt;	/* batch job restart count	*/
@@ -1024,6 +1044,7 @@ extern void slurm_free_job_step_info_request_msg(
 extern void slurm_free_front_end_info_request_msg(
 		front_end_info_request_msg_t *msg);
 extern void slurm_free_node_info_request_msg(node_info_request_msg_t *msg);
+extern void slurm_free_node_info_single_msg(node_info_single_msg_t *msg);
 extern void slurm_free_part_info_request_msg(part_info_request_msg_t *msg);
 extern void slurm_free_stats_info_request_msg(stats_info_request_msg_t *msg);
 extern void slurm_free_stats_response_msg(stats_info_response_msg_t *msg);
@@ -1058,6 +1079,7 @@ extern void slurm_free_job_info(job_info_t * job);
 extern void slurm_free_job_info_members(job_info_t * job);
 
 extern void slurm_free_job_id_msg(job_id_msg_t * msg);
+extern void slurm_free_job_user_id_msg(job_user_id_msg_t * msg);
 extern void slurm_free_job_id_request_msg(job_id_request_msg_t * msg);
 extern void slurm_free_job_id_response_msg(job_id_response_msg_t * msg);
 
@@ -1147,6 +1169,8 @@ extern void slurm_free_block_info_request_msg(
 		block_info_request_msg_t *msg);
 extern void slurm_free_acct_gather_node_resp_msg(
 	acct_gather_node_resp_msg_t *msg);
+extern void slurm_free_acct_gather_energy_req_msg(
+	acct_gather_energy_req_msg_t *msg);
 extern void slurm_free_job_notify_msg(job_notify_msg_t * msg);
 
 extern void slurm_free_accounting_update_msg(accounting_update_msg_t *msg);
@@ -1162,6 +1186,10 @@ extern uint16_t preempt_mode_num(const char *preempt_mode);
 extern char *log_num2string(uint16_t inx);
 extern uint16_t log_string2num(char *name);
 
+/* Convert HealthCheckNodeState numeric value to a string.
+ * Caller must xfree() the return value */
+extern char *health_check_node_state_str(uint16_t node_state);
+
 extern char *sched_param_type_string(uint16_t select_type_param);
 extern char *job_reason_string(enum job_state_reason inx);
 extern char *job_state_string(uint16_t inx);
