@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -54,7 +54,7 @@
 #include "src/common/xmalloc.h"
 #include "src/common/xstring.h"
 
-#if(0)
+#if (0)
 #define DEBUG 1
 #endif
 
@@ -98,216 +98,6 @@ static bool _have_task_affinity(void)
 	return rc;
 }
 
-/*
- * slurm_get_avail_procs - Get the number of "available" cpus on a node
- *	given this number given the number of cpus_per_task and
- *	maximum sockets, cores, threads.  Note that the value of
- *	cpus is the lowest-level logical processor (LLLP).
- * IN socket_cnt     - Job requested socket count
- * IN core_cnt       - Job requested core count
- * IN threads_cnt    - Job requested thread count
- * IN cpus_per_task  - Job requested cpus per task
- * IN ntaskspernode  - number of tasks per node
- * IN ntaskspersocket- number of tasks per socket
- * IN ntaskspercore  - number of tasks per core
- * IN/OUT cpus       - Available cpu count
- * IN/OUT sockets    - Available socket count
- * IN/OUT cores      - Available core count
- * IN/OUT threads    - Available thread count
- * IN alloc_cores    - Allocated cores (per socket) count to other jobs
- * IN cr_type        - Consumable Resource type
- * IN job_id         - job ID
- * IN name           - Node name
- *
- * Note: currently only used in the select/linear plugin.
- */
-int slurm_get_avail_procs(const uint16_t socket_cnt,
-			  const uint16_t core_cnt,
-			  const uint16_t thread_cnt,
-			  uint16_t cpus_per_task,
-			  const uint16_t ntaskspernode,
-			  const uint16_t ntaskspersocket,
-			  const uint16_t ntaskspercore,
-			  uint16_t *cpus,
-			  uint16_t *sockets,
-			  uint16_t *cores,
-			  uint16_t *threads,
-			  const uint16_t *alloc_cores,
-			  const uint16_t cr_type,
-			  uint32_t job_id,
-			  char *name)
-{
-	uint16_t avail_cpus = 0, max_cpus = 0;
-	uint16_t allocated_cpus = 0, allocated_cores = 0, allocated_sockets = 0;
-	uint16_t max_avail_cpus = 0xffff;	/* for alloc_* accounting */
-	uint16_t min_sockets = 1, max_sockets = 0xffff;
-	uint16_t min_cores   = 1, max_cores   = 0xffff;
-	uint16_t                  max_threads = 0xffff;
-	int i;
-
-        /* pick defaults for any unspecified items */
-	if (socket_cnt != (uint16_t) NO_VAL)
-		min_sockets = max_sockets = socket_cnt;
-	if (core_cnt != (uint16_t) NO_VAL)
-		min_cores = max_cores = core_cnt;	
-	if (thread_cnt != (uint16_t) NO_VAL)
-		max_threads = thread_cnt;
-	if (cpus_per_task <= 0)
-		cpus_per_task = 1;
-	if (*threads <= 0)
-	    	*threads = 1;
-	if (*cores <= 0)
-	    	*cores = 1;
-	if (*sockets <= 0)
-	    	*sockets = *cpus / *cores / *threads;
-	for (i = 0 ; alloc_cores && i < *sockets; i++) {
-		allocated_cores += alloc_cores[i];
-		if (alloc_cores[i])
-			allocated_sockets++;
-	}
-#if(DEBUG)
-	info("get_avail_procs %u %s User_ sockets %u cores %u threads %u",
-			job_id, name, socket_cnt, core_cnt, thread_cnt);
-	info("get_avail_procs %u %s HW_   sockets %u cores %u threads %u",
-			job_id, name, *sockets, *cores, *threads);
-	info("get_avail_procs %u %s Ntask node   %u sockets %u core   %u",
-			job_id, name, ntaskspernode, ntaskspersocket,
-			ntaskspercore);
-	info("get_avail_procs %u %s cr_type %d cpus %u  alloc_ c %u s %u",
-			job_id, name, cr_type, *cpus, allocated_cores,
-			allocated_sockets);
-	for (i = 0; alloc_cores && i < *sockets; i++)
-		info("get_avail_procs %u %s alloc_cores[%d] = %u",
-		     job_id, name, i, alloc_cores[i]);
-#endif
-	allocated_cpus = allocated_cores * (*threads);
-
-	/* For the following CR types, nodes have no notion of socket, core,
-	   and thread.  Only one level of logical processors */
-	if (cr_type & CR_CORE) {
-		if (*cpus >= allocated_cpus)
-			*cpus -= allocated_cpus;
-		else {
-			*cpus = 0;
-			error("cons_res: *cpus underflow");
-		}
-		if (allocated_cores > 0) {
-			max_avail_cpus = 0;
-			int tmp_diff = 0;
-			for (i=0; i<*sockets; i++) {
-				tmp_diff = *cores - alloc_cores[i];
-				if (min_cores <= tmp_diff) {
-					tmp_diff *= (*threads);
-					max_avail_cpus += tmp_diff;
-				}
-			}
-		}
-
-		/*** honor socket/core/thread maximums ***/
-		*sockets = MIN(*sockets, max_sockets);
-		*cores   = MIN(*cores,   max_cores);
-		*threads = MIN(*threads, max_threads);
-
-		if (min_sockets > *sockets) {
-			*cpus = 0;
-		} else {
-			int max_cpus_socket = 0;
-			max_cpus = 0;
-			for (i=0; i<*sockets; i++) {
-				max_cpus_socket = 0;
-				if (min_cores <= *cores) {
-				        int num_threads = *threads;
-					if (ntaskspercore > 0) {
-						num_threads = MIN(num_threads,
-							       ntaskspercore);
-					}
-					max_cpus_socket = *cores * num_threads;
-				}
-				if (ntaskspersocket > 0) {
-					max_cpus_socket = MIN(max_cpus_socket,
-							      ntaskspersocket);
-				}
-				max_cpus += max_cpus_socket;
-			}
-			max_cpus = MIN(max_cpus, max_avail_cpus);
-		}
-
-		/*** honor any availability maximum ***/
-		max_cpus = MIN(max_cpus, max_avail_cpus);
-
-		if (ntaskspernode > 0) {
-			max_cpus = MIN(max_cpus, ntaskspernode);
-		}
-	} else if (cr_type & CR_SOCKET) {
-		if (*sockets >= allocated_sockets)
-			*sockets -= allocated_sockets; /* sockets count */
-		else {
-			*sockets = 0;
-			error("cons_res: *sockets underflow");
-		}
-		if (*cpus >= allocated_cpus)
-			*cpus -= allocated_cpus;
-		else {
-			*cpus = 0;
-			error("cons_res: *cpus underflow");
-		}
-
-		if (min_sockets > *sockets)
-			*cpus = 0;
-
-		/*** honor socket/core/thread maximums ***/
-		*sockets = MIN(*sockets, max_sockets);
-		*cores   = MIN(*cores,   max_cores);
-		*threads = MIN(*threads, max_threads);
-
-		/*** compute an overall maximum cpu count honoring ntasks* ***/
-		max_cpus  = *threads;
-		if (ntaskspercore > 0) {
-			max_cpus = MIN(max_cpus, ntaskspercore);
-		}
-		max_cpus *= *cores;
-		if (ntaskspersocket > 0) {
-			max_cpus = MIN(max_cpus, ntaskspersocket);
-		}
-		max_cpus *= *sockets;
-		if (ntaskspernode > 0) {
-			max_cpus = MIN(max_cpus, ntaskspernode);
-		}
-
-		/*** honor any availability maximum ***/
-		max_cpus = MIN(max_cpus, max_avail_cpus);
-	} else {	/* CR_CPU (default) */
-		if ((cr_type & CR_CPU) ||
-		    (!(cr_type & CR_MEMORY))) {
-			if (*cpus >= allocated_cpus)
-				*cpus -= allocated_cpus;
-			else {
-				*cpus = 0;
-				error("cons_res: *cpus underflow");
-			}
-		}
-
-		/*** compute an overall maximum cpu count honoring ntasks* ***/
-		max_cpus  = *cpus;
-		if (ntaskspernode > 0) {
-			max_cpus = MIN(max_cpus, ntaskspernode);
-		}
-	}
-
-	/*** factor cpus_per_task into max_cpus ***/
-	max_cpus *= cpus_per_task;
-	/*** round down available based on cpus_per_task ***/
-	avail_cpus = (*cpus / cpus_per_task) * cpus_per_task;
-	avail_cpus = MIN(avail_cpus, max_cpus);
-
-#if(DEBUG)
-	info("get_avail_procs %u %s return cpus %u sockets %u cores %u threads %u",
-			job_id, name, *cpus, *sockets, *cores, *threads);
-	info("get_avail_procs %d %s avail_cpus %u",  job_id, name, avail_cpus);
-#endif
-	return(avail_cpus);
-}
-
 /*
  * slurm_sprint_cpu_bind_type
  *
@@ -515,7 +305,7 @@ int slurm_verify_cpu_bind(const char *arg, char **cpu_bind,
 		           (strncasecmp(tok, "mapcpu", 6) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits, CPU_BIND_MAP);
 			xfree(*cpu_bind);
 			if (list && *list) {
@@ -530,7 +320,7 @@ int slurm_verify_cpu_bind(const char *arg, char **cpu_bind,
 		           (strncasecmp(tok, "maskcpu", 7) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits, CPU_BIND_MASK);
 			xfree(*cpu_bind);
 			if (list && *list) {
@@ -549,7 +339,7 @@ int slurm_verify_cpu_bind(const char *arg, char **cpu_bind,
 		           (strncasecmp(tok, "mapldom", 7) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits,
 					CPU_BIND_LDMAP);
 			xfree(*cpu_bind);
@@ -565,7 +355,7 @@ int slurm_verify_cpu_bind(const char *arg, char **cpu_bind,
 		           (strncasecmp(tok, "maskldom", 8) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits,
 					CPU_BIND_LDMASK);
 			xfree(*cpu_bind);
@@ -712,7 +502,7 @@ int slurm_verify_mem_bind(const char *arg, char **mem_bind,
 		           (strncasecmp(tok, "mapmem", 6) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits, MEM_BIND_MAP);
 			xfree(*mem_bind);
 			if (list && *list) {
@@ -726,7 +516,7 @@ int slurm_verify_mem_bind(const char *arg, char **mem_bind,
 		           (strncasecmp(tok, "maskmem", 7) == 0)) {
 			char *list;
 			list = strsep(&tok, ":=");
-			list = strsep(&tok, ":=");
+			list = strsep(&tok, ":=");  /* THIS IS NOT REDUNDANT */
 			_clear_then_set((int *)flags, bind_bits, MEM_BIND_MASK);
 			xfree(*mem_bind);
 			if (list && *list) {
