@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -49,36 +49,27 @@
  * IN len_tv_str - size of tv_str in bytes
  * IN from - where the function was called form
  */
-extern void slurm_diff_tv_str(struct timeval *tv1,struct timeval *tv2,
+extern void slurm_diff_tv_str(struct timeval *tv1, struct timeval *tv2,
 			      char *tv_str, int len_tv_str, char *from,
-			      long limit)
+			      long limit, long *delta_t)
 {
-	long delta_t;
+	char p[64] = "";
+	struct tm tm;
 
-	delta_t  = (tv2->tv_sec  - tv1->tv_sec) * 1000000;
-	delta_t +=  tv2->tv_usec - tv1->tv_usec;
-	snprintf(tv_str, len_tv_str, "usec=%ld", delta_t);
+	(*delta_t)  = (tv2->tv_sec  - tv1->tv_sec) * 1000000;
+	(*delta_t) +=  tv2->tv_usec - tv1->tv_usec;
+	snprintf(tv_str, len_tv_str, "usec=%ld", *delta_t);
 	if (from) {
 		if (!limit)
 			limit = 1000000;
-		if (delta_t > limit) {
+		if (*delta_t > limit) {
+			if (!localtime_r(&tv1->tv_sec, &tm))
+				fprintf(stderr, "localtime_r() failed\n");
+			if (strftime(p, sizeof(p), "%T", &tm) == 0)
+				fprintf(stderr, "strftime() returned 0\n");
 			verbose("Warning: Note very large processing "
-				"time from %s: %s",
-				from, tv_str);
+				"time from %s: %s began=%s.%3.3d",
+				from, tv_str, p, (int)(tv1->tv_usec / 1000));
 		}
 	}
 }
-
-/*
- * slurm_diff_tv - return the difference between two times
- * IN tv1 - start of event
- * IN tv2 - end of event
- * RET time in micro-seconds
- */
-extern long slurm_diff_tv(struct timeval *tv1, struct timeval *tv2)
-{
-	long delta_t;
-	delta_t  = (tv2->tv_sec  - tv1->tv_sec) * 1000000;
-	delta_t +=  tv2->tv_usec - tv1->tv_usec;
-	return delta_t;
-}
