@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -37,8 +37,11 @@
 \*****************************************************************************/
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 
+#include "src/common/log.h"
+
 extern int unsetenv (const char *name)
 {
 	int len, rc;
@@ -49,6 +52,10 @@ extern int unsetenv (const char *name)
 
 	len = strlen(name);
 	tmp = malloc(len + 3);
+	if (!tmp) {
+		log_oom(__FILE__, __LINE__, __CURRENT_FUNC__);
+		abort();
+	}
 	strcpy(tmp, name);
 	strcat(tmp, "=x");
 	if ((rc = putenv(tmp)) != 0)
