@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -47,6 +47,7 @@
 #define xstrcatchar(__p, __c)		_xstrcatchar(&(__p), __c)
 #define xslurm_strerrorcat(__p)		_xslurm_strerrorcat(&(__p))
 #define xstrftimecat(__p, __fmt)	_xstrftimecat(&(__p), __fmt)
+#define xiso8601timecat(__p)            _xiso8601timecat(&(__p))
 #define xrfc5424timecat(__p)            _xrfc5424timecat(&(__p))
 #define xstrfmtcat(__p, __fmt, args...)	_xstrfmtcat(&(__p), __fmt, ## args)
 #define xmemcat(__p, __s, __e)          _xmemcat(&(__p), __s, __e)
@@ -89,6 +90,11 @@ void _xslurm_strerrorcat(char **str);
 */
 void _xstrftimecat(char **str, const char *fmt);
 
+/*
+** Concatenate a ISO 8601 timestamp onto str.
+*/
+void _xiso8601timecat(char **str);
+
 /*
 ** Concatenate a RFC 5424 timestamp onto str.
 */
