@@ -10,7 +10,7 @@
  *  Written by Danny Auble <da@schedmd.com, da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -935,6 +935,7 @@ extern int create_cluster_tables(mysql_conn_t *mysql_conn, char *cluster_name)
 		{ "id_user", "int unsigned not null" },
 		{ "id_group", "int unsigned not null" },
 		{ "kill_requid", "int default -1 not null" },
+		{ "mem_req", "int unsigned default 0 not null" },
 		{ "nodelist", "text" },
 		{ "nodes_alloc", "int unsigned not null" },
 		{ "node_inx", "text" },
@@ -998,23 +999,32 @@ extern int create_cluster_tables(mysql_conn_t *mysql_conn, char *cluster_name)
 		{ "sys_sec", "int unsigned default 0 not null" },
 		{ "sys_usec", "int unsigned default 0 not null" },
 		{ "max_pages", "int unsigned default 0 not null" },
-		{ "max_pages_task", "smallint unsigned default 0 not null" },
+		{ "max_pages_task", "int unsigned default 0 not null" },
 		{ "max_pages_node", "int unsigned default 0 not null" },
 		{ "ave_pages", "double unsigned default 0.0 not null" },
 		{ "max_rss", "bigint unsigned default 0 not null" },
-		{ "max_rss_task", "smallint unsigned default 0 not null" },
+		{ "max_rss_task", "int unsigned default 0 not null" },
 		{ "max_rss_node", "int unsigned default 0 not null" },
 		{ "ave_rss", "double unsigned default 0.0 not null" },
 		{ "max_vsize", "bigint unsigned default 0 not null" },
-		{ "max_vsize_task", "smallint unsigned default 0 not null" },
+		{ "max_vsize_task", "int unsigned default 0 not null" },
 		{ "max_vsize_node", "int unsigned default 0 not null" },
 		{ "ave_vsize", "double unsigned default 0.0 not null" },
 		{ "min_cpu", "int unsigned default 0 not null" },
-		{ "min_cpu_task", "smallint unsigned default 0 not null" },
+		{ "min_cpu_task", "int unsigned default 0 not null" },
 		{ "min_cpu_node", "int unsigned default 0 not null" },
 		{ "ave_cpu", "double unsigned default 0.0 not null" },
 		{ "act_cpufreq", "double unsigned default 0.0 not null" },
 		{ "consumed_energy", "double unsigned default 0.0 not null" },
+		{ "req_cpufreq", "int unsigned default 0 not null" },
+		{ "max_disk_read", "double unsigned default 0.0 not null" },
+		{ "max_disk_read_task", "int unsigned default 0 not null" },
+		{ "max_disk_read_node", "int unsigned default 0 not null" },
+		{ "ave_disk_read", "double unsigned default 0.0 not null" },
+		{ "max_disk_write", "double unsigned default 0.0 not null" },
+		{ "max_disk_write_task", "int unsigned default 0 not null" },
+		{ "max_disk_write_node", "int unsigned default 0 not null" },
+		{ "ave_disk_write", "double unsigned default 0.0 not null" },
 		{ NULL, NULL}
 	};
 
