@@ -8,7 +8,7 @@
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -79,6 +79,7 @@ typedef struct {
 	char *priority;
 	char *qos;
 	char *req_cpus;
+	char *req_mem;
 	char *resvid;
 	char *start;
 	char *state;
@@ -92,14 +93,36 @@ typedef struct {
 } local_job_t;
 
 typedef struct {
+	char *assocs;
+	char *cpus;
+	char *flags;
+	char *id;
+	char *name;
+	char *nodes;
+	char *node_inx;
+	char *time_end;
+	char *time_start;
+} local_resv_t;
+
+typedef struct {
+	char *act_cpufreq;
 	char *ave_cpu;
+	char *ave_disk_read;
+	char *ave_disk_write;
 	char *ave_pages;
 	char *ave_rss;
 	char *ave_vsize;
 	char *exit_code;
+	char *consumed_energy;
 	char *cpus;
 	char *id;
 	char *kill_requid;
+	char *max_disk_read;
+	char *max_disk_read_node;
+	char *max_disk_read_task;
+	char *max_disk_write;
+	char *max_disk_write_node;
+	char *max_disk_write_task;
 	char *max_pages;
 	char *max_pages_node;
 	char *max_pages_task;
@@ -119,6 +142,7 @@ typedef struct {
 	char *period_end;
 	char *period_start;
 	char *period_suspended;
+	char *req_cpufreq;
 	char *state;
 	char *stepid;
 	char *sys_sec;
@@ -127,8 +151,6 @@ typedef struct {
 	char *task_dist;
 	char *user_sec;
 	char *user_usec;
-	char *act_cpufreq;
-	char *consumed_energy;
 } local_step_t;
 
 typedef struct {
@@ -188,6 +210,7 @@ static char *job_req_inx[] = {
 	"priority",
 	"id_qos",
 	"cpus_req",
+	"mem_req",
 	"id_resv",
 	"time_start",
 	"state",
@@ -223,6 +246,7 @@ enum {
 	JOB_REQ_PRIORITY,
 	JOB_REQ_QOS,
 	JOB_REQ_REQ_CPUS,
+	JOB_REQ_REQ_MEM,
 	JOB_REQ_START,
 	JOB_REQ_STATE,
 	JOB_REQ_SUBMIT,
@@ -234,6 +258,32 @@ enum {
 	JOB_REQ_COUNT
 };
 
+/* if this changes you will need to edit the corresponding enum */
+char *resv_req_inx[] = {
+	"id_resv",
+	"assoclist",
+	"cpus",
+	"flags",
+	"nodelist",
+	"node_inx",
+	"resv_name",
+	"time_start",
+	"time_end",
+};
+
+enum {
+	RESV_REQ_ID,
+	RESV_REQ_ASSOCS,
+	RESV_REQ_CPUS,
+	RESV_REQ_FLAGS,
+	RESV_REQ_NODES,
+	RESV_REQ_NODE_INX,
+	RESV_REQ_NAME,
+	RESV_REQ_START,
+	RESV_REQ_END,
+	RESV_REQ_COUNT
+};
+
 /* if this changes you will need to edit the corresponding
  * enum below */
 static char *step_req_inx[] = {
@@ -273,7 +323,16 @@ static char *step_req_inx[] = {
 	"min_cpu_node",
 	"ave_cpu",
 	"act_cpufreq",
-	"consumed_energy"
+	"consumed_energy",
+	"req_cpufreq",
+	"max_disk_read",
+	"max_disk_read_task",
+	"max_disk_read_node",
+	"ave_disk_read",
+	"max_disk_write",
+	"max_disk_write_task",
+	"max_disk_write_node",
+	"ave_disk_write"
 };
 
 
@@ -315,7 +374,16 @@ enum {
 	STEP_REQ_AVE_CPU,
 	STEP_REQ_ACT_CPUFREQ,
 	STEP_REQ_CONSUMED_ENERGY,
-	STEP_REQ_COUNT
+	STEP_REQ_REQ_CPUFREQ,
+	STEP_REQ_MAX_DISK_READ,
+	STEP_REQ_MAX_DISK_READ_TASK,
+	STEP_REQ_MAX_DISK_READ_NODE,
+	STEP_REQ_AVE_DISK_READ,
+	STEP_REQ_MAX_DISK_WRITE,
+	STEP_REQ_MAX_DISK_WRITE_TASK,
+	STEP_REQ_MAX_DISK_WRITE_NODE,
+	STEP_REQ_AVE_DISK_WRITE,
+	STEP_REQ_COUNT,
 };
 
 /* if this changes you will need to edit the corresponding
@@ -394,6 +462,7 @@ static void _pack_local_job(local_job_t *object,
 	packstr(object->priority, buffer);
 	packstr(object->qos, buffer);
 	packstr(object->req_cpus, buffer);
+	packstr(object->req_mem, buffer);
 	packstr(object->resvid, buffer);
 	packstr(object->start, buffer);
 	packstr(object->state, buffer);
@@ -412,37 +481,105 @@ static int _unpack_local_job(local_job_t *object,
 {
 	uint32_t tmp32;
 
-	unpackstr_ptr(&object->account, &tmp32, buffer);
-	unpackstr_ptr(&object->alloc_cpus, &tmp32, buffer);
-	unpackstr_ptr(&object->alloc_nodes, &tmp32, buffer);
-	unpackstr_ptr(&object->associd, &tmp32, buffer);
-	unpackstr_ptr(&object->blockid, &tmp32, buffer);
-	unpackstr_ptr(&object->derived_ec, &tmp32, buffer);
-	unpackstr_ptr(&object->derived_es, &tmp32, buffer);
-	unpackstr_ptr(&object->exit_code, &tmp32, buffer);
-	unpackstr_ptr(&object->timelimit, &tmp32, buffer);
-	unpackstr_ptr(&object->eligible, &tmp32, buffer);
-	unpackstr_ptr(&object->end, &tmp32, buffer);
-	unpackstr_ptr(&object->gid, &tmp32, buffer);
+	if (rpc_version >= SLURMDBD_2_6_VERSION) {
+		unpackstr_ptr(&object->account, &tmp32, buffer);
+		unpackstr_ptr(&object->alloc_cpus, &tmp32, buffer);
+		unpackstr_ptr(&object->alloc_nodes, &tmp32, buffer);
+		unpackstr_ptr(&object->associd, &tmp32, buffer);
+		unpackstr_ptr(&object->blockid, &tmp32, buffer);
+		unpackstr_ptr(&object->derived_ec, &tmp32, buffer);
+		unpackstr_ptr(&object->derived_es, &tmp32, buffer);
+		unpackstr_ptr(&object->exit_code, &tmp32, buffer);
+		unpackstr_ptr(&object->timelimit, &tmp32, buffer);
+		unpackstr_ptr(&object->eligible, &tmp32, buffer);
+		unpackstr_ptr(&object->end, &tmp32, buffer);
+		unpackstr_ptr(&object->gid, &tmp32, buffer);
+		unpackstr_ptr(&object->id, &tmp32, buffer);
+		unpackstr_ptr(&object->jobid, &tmp32, buffer);
+		unpackstr_ptr(&object->kill_requid, &tmp32, buffer);
+		unpackstr_ptr(&object->name, &tmp32, buffer);
+		unpackstr_ptr(&object->nodelist, &tmp32, buffer);
+		unpackstr_ptr(&object->node_inx, &tmp32, buffer);
+		unpackstr_ptr(&object->partition, &tmp32, buffer);
+		unpackstr_ptr(&object->priority, &tmp32, buffer);
+		unpackstr_ptr(&object->qos, &tmp32, buffer);
+		unpackstr_ptr(&object->req_cpus, &tmp32, buffer);
+		unpackstr_ptr(&object->req_mem, &tmp32, buffer);
+		unpackstr_ptr(&object->resvid, &tmp32, buffer);
+		unpackstr_ptr(&object->start, &tmp32, buffer);
+		unpackstr_ptr(&object->state, &tmp32, buffer);
+		unpackstr_ptr(&object->submit, &tmp32, buffer);
+		unpackstr_ptr(&object->suspended, &tmp32, buffer);
+		unpackstr_ptr(&object->track_steps, &tmp32, buffer);
+		unpackstr_ptr(&object->uid, &tmp32, buffer);
+		unpackstr_ptr(&object->wckey, &tmp32, buffer);
+		unpackstr_ptr(&object->wckey_id, &tmp32, buffer);
+	} else {
+		unpackstr_ptr(&object->account, &tmp32, buffer);
+		unpackstr_ptr(&object->alloc_cpus, &tmp32, buffer);
+		unpackstr_ptr(&object->alloc_nodes, &tmp32, buffer);
+		unpackstr_ptr(&object->associd, &tmp32, buffer);
+		unpackstr_ptr(&object->blockid, &tmp32, buffer);
+		unpackstr_ptr(&object->derived_ec, &tmp32, buffer);
+		unpackstr_ptr(&object->derived_es, &tmp32, buffer);
+		unpackstr_ptr(&object->exit_code, &tmp32, buffer);
+		unpackstr_ptr(&object->timelimit, &tmp32, buffer);
+		unpackstr_ptr(&object->eligible, &tmp32, buffer);
+		unpackstr_ptr(&object->end, &tmp32, buffer);
+		unpackstr_ptr(&object->gid, &tmp32, buffer);
+		unpackstr_ptr(&object->id, &tmp32, buffer);
+		unpackstr_ptr(&object->jobid, &tmp32, buffer);
+		unpackstr_ptr(&object->kill_requid, &tmp32, buffer);
+		unpackstr_ptr(&object->name, &tmp32, buffer);
+		unpackstr_ptr(&object->nodelist, &tmp32, buffer);
+		unpackstr_ptr(&object->node_inx, &tmp32, buffer);
+		unpackstr_ptr(&object->partition, &tmp32, buffer);
+		unpackstr_ptr(&object->priority, &tmp32, buffer);
+		unpackstr_ptr(&object->qos, &tmp32, buffer);
+		unpackstr_ptr(&object->req_cpus, &tmp32, buffer);
+		unpackstr_ptr(&object->resvid, &tmp32, buffer);
+		unpackstr_ptr(&object->start, &tmp32, buffer);
+		unpackstr_ptr(&object->state, &tmp32, buffer);
+		unpackstr_ptr(&object->submit, &tmp32, buffer);
+		unpackstr_ptr(&object->suspended, &tmp32, buffer);
+		unpackstr_ptr(&object->track_steps, &tmp32, buffer);
+		unpackstr_ptr(&object->uid, &tmp32, buffer);
+		unpackstr_ptr(&object->wckey, &tmp32, buffer);
+		unpackstr_ptr(&object->wckey_id, &tmp32, buffer);
+	}
+	return SLURM_SUCCESS;
+}
+
+static void _pack_local_resv(local_resv_t *object,
+			     uint16_t rpc_version, Buf buffer)
+{
+	packstr(object->assocs, buffer);
+	packstr(object->cpus, buffer);
+	packstr(object->flags, buffer);
+	packstr(object->id, buffer);
+	packstr(object->name, buffer);
+	packstr(object->nodes, buffer);
+	packstr(object->node_inx, buffer);
+	packstr(object->time_end, buffer);
+	packstr(object->time_start, buffer);
+}
+
+/* this needs to be allocated before calling, and since we aren't
+ * doing any copying it needs to be used before destroying buffer */
+static int _unpack_local_resv(local_resv_t *object,
+			      uint16_t rpc_version, Buf buffer)
+{
+	uint32_t tmp32;
+
+	unpackstr_ptr(&object->assocs, &tmp32, buffer);
+	unpackstr_ptr(&object->cpus, &tmp32, buffer);
+	unpackstr_ptr(&object->flags, &tmp32, buffer);
 	unpackstr_ptr(&object->id, &tmp32, buffer);
-	unpackstr_ptr(&object->jobid, &tmp32, buffer);
-	unpackstr_ptr(&object->kill_requid, &tmp32, buffer);
 	unpackstr_ptr(&object->name, &tmp32, buffer);
-	unpackstr_ptr(&object->nodelist, &tmp32, buffer);
+	unpackstr_ptr(&object->nodes, &tmp32, buffer);
 	unpackstr_ptr(&object->node_inx, &tmp32, buffer);
-	unpackstr_ptr(&object->partition, &tmp32, buffer);
-	unpackstr_ptr(&object->priority, &tmp32, buffer);
-	unpackstr_ptr(&object->qos, &tmp32, buffer);
-	unpackstr_ptr(&object->req_cpus, &tmp32, buffer);
-	unpackstr_ptr(&object->resvid, &tmp32, buffer);
-	unpackstr_ptr(&object->start, &tmp32, buffer);
-	unpackstr_ptr(&object->state, &tmp32, buffer);
-	unpackstr_ptr(&object->submit, &tmp32, buffer);
-	unpackstr_ptr(&object->suspended, &tmp32, buffer);
-	unpackstr_ptr(&object->track_steps, &tmp32, buffer);
-	unpackstr_ptr(&object->uid, &tmp32, buffer);
-	unpackstr_ptr(&object->wckey, &tmp32, buffer);
-	unpackstr_ptr(&object->wckey_id, &tmp32, buffer);
+	unpackstr_ptr(&object->time_end, &tmp32, buffer);
+	unpackstr_ptr(&object->time_start, &tmp32, buffer);
 
 	return SLURM_SUCCESS;
 }
@@ -450,7 +587,54 @@ static int _unpack_local_job(local_job_t *object,
 static void _pack_local_step(local_step_t *object,
 			     uint16_t rpc_version, Buf buffer)
 {
-	if (rpc_version >= SLURMDBD_2_5_VERSION) {
+	if (rpc_version >= SLURMDBD_2_6_VERSION) {
+		packstr(object->act_cpufreq, buffer);
+		packstr(object->ave_cpu, buffer);
+		packstr(object->ave_disk_read, buffer);
+		packstr(object->ave_disk_write, buffer);
+		packstr(object->ave_pages, buffer);
+		packstr(object->ave_rss, buffer);
+		packstr(object->ave_vsize, buffer);
+		packstr(object->exit_code, buffer);
+		packstr(object->consumed_energy, buffer);
+		packstr(object->cpus, buffer);
+		packstr(object->id, buffer);
+		packstr(object->kill_requid, buffer);
+		packstr(object->max_disk_read, buffer);
+		packstr(object->max_disk_read_node, buffer);
+		packstr(object->max_disk_read_task, buffer);
+		packstr(object->max_disk_write, buffer);
+		packstr(object->max_disk_write_node, buffer);
+		packstr(object->max_disk_write_task, buffer);
+		packstr(object->max_pages, buffer);
+		packstr(object->max_pages_node, buffer);
+		packstr(object->max_pages_task, buffer);
+		packstr(object->max_rss, buffer);
+		packstr(object->max_rss_node, buffer);
+		packstr(object->max_rss_task, buffer);
+		packstr(object->max_vsize, buffer);
+		packstr(object->max_vsize_node, buffer);
+		packstr(object->max_vsize_task, buffer);
+		packstr(object->min_cpu, buffer);
+		packstr(object->min_cpu_node, buffer);
+		packstr(object->min_cpu_task, buffer);
+		packstr(object->name, buffer);
+		packstr(object->nodelist, buffer);
+		packstr(object->nodes, buffer);
+		packstr(object->node_inx, buffer);
+		packstr(object->period_end, buffer);
+		packstr(object->period_start, buffer);
+		packstr(object->period_suspended, buffer);
+		packstr(object->req_cpufreq, buffer);
+		packstr(object->state, buffer);
+		packstr(object->stepid, buffer);
+		packstr(object->sys_sec, buffer);
+		packstr(object->sys_usec, buffer);
+		packstr(object->tasks, buffer);
+		packstr(object->task_dist, buffer);
+		packstr(object->user_sec, buffer);
+		packstr(object->user_usec, buffer);
+	} else if (rpc_version >= SLURMDBD_2_5_VERSION) {
 		packstr(object->act_cpufreq, buffer);
 		packstr(object->ave_cpu, buffer);
 		packstr(object->ave_pages, buffer);
@@ -534,7 +718,54 @@ static int _unpack_local_step(local_step_t *object,
 {
 	uint32_t tmp32;
 
-	if (rpc_version >= SLURMDBD_2_5_VERSION) {
+	if (rpc_version >= SLURMDBD_2_6_VERSION) {
+		unpackstr_ptr(&object->act_cpufreq, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_cpu, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_disk_read, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_disk_write, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_pages, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_rss, &tmp32, buffer);
+		unpackstr_ptr(&object->ave_vsize, &tmp32, buffer);
+		unpackstr_ptr(&object->exit_code, &tmp32, buffer);
+		unpackstr_ptr(&object->consumed_energy, &tmp32, buffer);
+		unpackstr_ptr(&object->cpus, &tmp32, buffer);
+		unpackstr_ptr(&object->id, &tmp32, buffer);
+		unpackstr_ptr(&object->kill_requid, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_read, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_read_node, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_read_task, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_write, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_write_node, &tmp32, buffer);
+		unpackstr_ptr(&object->max_disk_write_task, &tmp32, buffer);
+		unpackstr_ptr(&object->max_pages, &tmp32, buffer);
+		unpackstr_ptr(&object->max_pages_node, &tmp32, buffer);
+		unpackstr_ptr(&object->max_pages_task, &tmp32, buffer);
+		unpackstr_ptr(&object->max_rss, &tmp32, buffer);
+		unpackstr_ptr(&object->max_rss_node, &tmp32, buffer);
+		unpackstr_ptr(&object->max_rss_task, &tmp32, buffer);
+		unpackstr_ptr(&object->max_vsize, &tmp32, buffer);
+		unpackstr_ptr(&object->max_vsize_node, &tmp32, buffer);
+		unpackstr_ptr(&object->max_vsize_task, &tmp32, buffer);
+		unpackstr_ptr(&object->min_cpu, &tmp32, buffer);
+		unpackstr_ptr(&object->min_cpu_node, &tmp32, buffer);
+		unpackstr_ptr(&object->min_cpu_task, &tmp32, buffer);
+		unpackstr_ptr(&object->name, &tmp32, buffer);
+		unpackstr_ptr(&object->nodelist, &tmp32, buffer);
+		unpackstr_ptr(&object->nodes, &tmp32, buffer);
+		unpackstr_ptr(&object->node_inx, &tmp32, buffer);
+		unpackstr_ptr(&object->period_end, &tmp32, buffer);
+		unpackstr_ptr(&object->period_start, &tmp32, buffer);
+		unpackstr_ptr(&object->period_suspended, &tmp32, buffer);
+		unpackstr_ptr(&object->req_cpufreq, &tmp32, buffer);
+		unpackstr_ptr(&object->state, &tmp32, buffer);
+		unpackstr_ptr(&object->stepid, &tmp32, buffer);
+		unpackstr_ptr(&object->sys_sec, &tmp32, buffer);
+		unpackstr_ptr(&object->sys_usec, &tmp32, buffer);
+		unpackstr_ptr(&object->tasks, &tmp32, buffer);
+		unpackstr_ptr(&object->task_dist, &tmp32, buffer);
+		unpackstr_ptr(&object->user_sec, &tmp32, buffer);
+		unpackstr_ptr(&object->user_usec, &tmp32, buffer);
+	} else if (rpc_version >= SLURMDBD_2_5_VERSION) {
 		unpackstr_ptr(&object->act_cpufreq, &tmp32, buffer);
 		unpackstr_ptr(&object->ave_cpu, &tmp32, buffer);
 		unpackstr_ptr(&object->ave_pages, &tmp32, buffer);
@@ -1353,6 +1584,7 @@ static uint32_t _archive_jobs(mysql_conn_t *mysql_conn, char *cluster_name,
 		job.priority = row[JOB_REQ_PRIORITY];
 		job.qos = row[JOB_REQ_QOS];
 		job.req_cpus = row[JOB_REQ_REQ_CPUS];
+		job.req_mem = row[JOB_REQ_REQ_MEM];
 		job.resvid = row[JOB_REQ_RESVID];
 		job.start = row[JOB_REQ_START];
 		job.state = row[JOB_REQ_STATE];
@@ -1433,6 +1665,7 @@ static char *_load_jobs(uint16_t rpc_version, Buf buffer,
 			   object.priority,
 			   object.qos,
 			   object.req_cpus,
+			   object.req_mem,
 			   object.resvid,
 			   object.start,
 			   object.state,
@@ -1451,6 +1684,135 @@ static char *_load_jobs(uint16_t rpc_version, Buf buffer,
 	return insert;
 }
 
+/* returns count of resvations archived or SLURM_ERROR on error */
+static uint32_t _archive_resvs(mysql_conn_t *mysql_conn, char *cluster_name,
+			       time_t period_end, char *arch_dir,
+			       uint32_t archive_period)
+{
+	MYSQL_RES *result = NULL;
+	MYSQL_ROW row;
+	char *tmp = NULL, *query = NULL;
+	time_t period_start = 0;
+	uint32_t cnt = 0;
+	local_resv_t resv;
+	Buf buffer;
+	int error_code = 0, i = 0;
+
+	xfree(tmp);
+	xstrfmtcat(tmp, "%s", resv_req_inx[0]);
+	for(i=1; i<RESV_REQ_COUNT; i++) {
+		xstrfmtcat(tmp, ", %s", resv_req_inx[i]);
+	}
+
+	/* get all the events started before this time listed */
+	query = xstrdup_printf("select %s from \"%s_%s\" where "
+			       "time_start <= %ld "
+			       "&& time_end != 0 order by time_start asc",
+			       tmp, cluster_name, resv_table, period_end);
+	xfree(tmp);
+
+//	START_TIMER;
+	debug3("%d(%s:%d) query\n%s",
+	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
+		xfree(query);
+		return SLURM_ERROR;
+	}
+	xfree(query);
+
+	if (!(cnt = mysql_num_rows(result))) {
+		mysql_free_result(result);
+		return 0;
+	}
+
+	buffer = init_buf(high_buffer_size);
+	pack16(SLURMDBD_VERSION, buffer);
+	pack_time(time(NULL), buffer);
+	pack16(DBD_GOT_RESVS, buffer);
+	packstr(cluster_name, buffer);
+	pack32(cnt, buffer);
+
+	while ((row = mysql_fetch_row(result))) {
+		if (!period_start)
+			period_start = slurm_atoul(row[RESV_REQ_START]);
+
+		memset(&resv, 0, sizeof(local_resv_t));
+
+		resv.assocs = row[RESV_REQ_ASSOCS];
+		resv.cpus = row[RESV_REQ_CPUS];
+		resv.flags = row[RESV_REQ_FLAGS];
+		resv.id = row[RESV_REQ_ID];
+		resv.name = row[RESV_REQ_NAME];
+		resv.nodes = row[RESV_REQ_NODES];
+		resv.node_inx = row[RESV_REQ_NODE_INX];
+		resv.time_end = row[RESV_REQ_END];
+		resv.time_start = row[RESV_REQ_START];
+
+		_pack_local_resv(&resv, SLURMDBD_VERSION, buffer);
+	}
+	mysql_free_result(result);
+
+//	END_TIMER2("step query");
+//	info("event query took %s", TIME_STR);
+
+	error_code = archive_write_file(buffer, cluster_name,
+					period_start, period_end,
+					arch_dir, "resv", archive_period);
+	free_buf(buffer);
+
+	if (error_code != SLURM_SUCCESS)
+		return error_code;
+
+	return cnt;
+}
+
+/* returns sql statement from archived data or NULL on error */
+static char *_load_resvs(uint16_t rpc_version, Buf buffer,
+			 char *cluster_name, uint32_t rec_cnt)
+{
+	char *insert = NULL, *format = NULL;
+	local_resv_t object;
+	int i = 0;
+
+	xstrfmtcat(insert, "insert into \"%s_%s\" (%s",
+		   cluster_name, resv_table, resv_req_inx[0]);
+	xstrcat(format, "('%s'");
+	for(i=1; i<RESV_REQ_COUNT; i++) {
+		xstrfmtcat(insert, ", %s", resv_req_inx[i]);
+		xstrcat(format, ", '%s'");
+	}
+	xstrcat(insert, ") values ");
+	xstrcat(format, ")");
+	for(i=0; i<rec_cnt; i++) {
+		memset(&object, 0, sizeof(local_resv_t));
+		if (_unpack_local_resv(&object, rpc_version, buffer)
+		    != SLURM_SUCCESS) {
+			error("issue unpacking");
+			xfree(format);
+			xfree(insert);
+			break;
+		}
+		if (i)
+			xstrcat(insert, ", ");
+
+		xstrfmtcat(insert, format,
+			   object.assocs,
+			   object.cpus,
+			   object.flags,
+			   object.id,
+			   object.name,
+			   object.nodes,
+			   object.node_inx,
+			   object.time_end,
+			   object.time_start);
+	}
+//	END_TIMER2("step query");
+//	info("resv query took %s", TIME_STR);
+	xfree(format);
+
+	return insert;
+}
+
 /* returns count of steps archived or SLURM_ERROR on error */
 static uint32_t _archive_steps(mysql_conn_t *mysql_conn, char *cluster_name,
 			       time_t period_end, char *arch_dir,
@@ -1508,6 +1870,8 @@ static uint32_t _archive_steps(mysql_conn_t *mysql_conn, char *cluster_name,
 		step.ave_cpu = row[STEP_REQ_AVE_CPU];
 		step.act_cpufreq = row[STEP_REQ_ACT_CPUFREQ];
 		step.consumed_energy = row[STEP_REQ_CONSUMED_ENERGY];
+		step.ave_disk_read = row[STEP_REQ_AVE_DISK_READ];
+		step.ave_disk_write = row[STEP_REQ_AVE_DISK_WRITE];
 		step.ave_pages = row[STEP_REQ_AVE_PAGES];
 		step.ave_rss = row[STEP_REQ_AVE_RSS];
 		step.ave_vsize = row[STEP_REQ_AVE_VSIZE];
@@ -1515,6 +1879,12 @@ static uint32_t _archive_steps(mysql_conn_t *mysql_conn, char *cluster_name,
 		step.cpus = row[STEP_REQ_CPUS];
 		step.id = row[STEP_REQ_ID];
 		step.kill_requid = row[STEP_REQ_KILL_REQUID];
+		step.max_disk_read = row[STEP_REQ_MAX_DISK_READ];
+		step.max_disk_read_node = row[STEP_REQ_MAX_DISK_READ_NODE];
+		step.max_disk_read_task = row[STEP_REQ_MAX_DISK_READ_TASK];
+		step.max_disk_write = row[STEP_REQ_MAX_DISK_WRITE];
+		step.max_disk_write_node = row[STEP_REQ_MAX_DISK_WRITE_NODE];
+		step.max_disk_write_task = row[STEP_REQ_MAX_DISK_WRITE_TASK];
 		step.max_pages = row[STEP_REQ_MAX_PAGES];
 		step.max_pages_node = row[STEP_REQ_MAX_PAGES_NODE];
 		step.max_pages_task = row[STEP_REQ_MAX_PAGES_TASK];
@@ -1534,6 +1904,7 @@ static uint32_t _archive_steps(mysql_conn_t *mysql_conn, char *cluster_name,
 		step.period_end = row[STEP_REQ_END];
 		step.period_start = row[STEP_REQ_START];
 		step.period_suspended = row[STEP_REQ_SUSPENDED];
+		step.req_cpufreq = row[STEP_REQ_REQ_CPUFREQ];
 		step.state = row[STEP_REQ_STATE];
 		step.stepid = row[STEP_REQ_STEPID];
 		step.sys_sec = row[STEP_REQ_SYS_SEC];
@@ -1594,6 +1965,8 @@ static char *_load_steps(uint16_t rpc_version, Buf buffer,
 			   object.ave_cpu,
 			   object.act_cpufreq,
 			   object.consumed_energy,
+			   object.ave_disk_read,
+			   object.ave_disk_write,
 			   object.ave_pages,
 			   object.ave_rss,
 			   object.ave_vsize,
@@ -1601,6 +1974,12 @@ static char *_load_steps(uint16_t rpc_version, Buf buffer,
 			   object.cpus,
 			   object.id,
 			   object.kill_requid,
+			   object.max_disk_read,
+			   object.max_disk_read_node,
+			   object.max_disk_read_task,
+			   object.max_disk_write,
+			   object.max_disk_write_node,
+			   object.max_disk_write_task,
 			   object.max_pages,
 			   object.max_pages_node,
 			   object.max_pages_task,
@@ -1620,6 +1999,7 @@ static char *_load_steps(uint16_t rpc_version, Buf buffer,
 			   object.period_end,
 			   object.period_start,
 			   object.period_suspended,
+			   object.req_cpufreq,
 			   object.state,
 			   object.stepid,
 			   object.sys_sec,
@@ -1921,6 +2301,44 @@ exit_steps:
 		}
 	}
 exit_jobs:
+
+	if (arch_cond->purge_resv != NO_VAL) {
+		/* remove all data from resv table that was older than
+		 * last_submit * arch_cond->purge_resv.
+		 */
+		if (!(curr_end = archive_setup_end_time(
+			      last_submit, arch_cond->purge_resv))) {
+			error("Parsing purge resv");
+			return SLURM_ERROR;
+		}
+
+		debug4("Purging resv entires before %ld for %s",
+		       curr_end, cluster_name);
+
+		if (SLURMDB_PURGE_ARCHIVE_SET(arch_cond->purge_resv)) {
+			rc = _archive_resvs(mysql_conn, cluster_name,
+					   curr_end, arch_cond->archive_dir,
+					   arch_cond->purge_resv);
+			if (!rc)
+				goto exit_resvs;
+			else if (rc == SLURM_ERROR)
+				return rc;
+		}
+
+		query = xstrdup_printf("delete from \"%s_%s\" "
+				       "where time_submit <= %ld "
+				       "&& time_end != 0",
+				       cluster_name, resv_table, curr_end);
+		debug3("%d(%s:%d) query\n%s",
+		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		rc = mysql_db_query(mysql_conn, query);
+		xfree(query);
+		if (rc != SLURM_SUCCESS) {
+			error("Couldn't remove old resv data");
+			return SLURM_ERROR;
+		}
+	}
+exit_resvs:
 	return SLURM_SUCCESS;
 }
 
@@ -2062,6 +2480,9 @@ extern int as_mysql_jobacct_process_archive_load(
 	case DBD_GOT_JOBS:
 		data = _load_jobs(ver, buffer, cluster_name, rec_cnt);
 		break;
+	case DBD_GOT_RESVS:
+		data = _load_resvs(ver, buffer, cluster_name, rec_cnt);
+		break;
 	case DBD_STEP_START:
 		data = _load_steps(ver, buffer, cluster_name, rec_cnt);
 		break;
