@@ -9,7 +9,7 @@
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -659,6 +659,7 @@ extern int as_mysql_convert_tables(mysql_conn_t *mysql_conn)
 		{ "comp_code", "int default 0 not null" },
 		{ "priority", "int not null" },
 		{ "req_cpus", "int unsigned not null" },
+		{ "req_mem", "int unsigned default 0 not null" },
 		{ "alloc_cpus", "int unsigned not null" },
 		{ "alloc_nodes", "int unsigned not null" },
 		{ "nodelist", "text" },
@@ -713,23 +714,32 @@ extern int as_mysql_convert_tables(mysql_conn_t *mysql_conn)
 		{ "sys_sec", "int unsigned default 0 not null" },
 		{ "sys_usec", "int unsigned default 0 not null" },
 		{ "max_vsize", "bigint unsigned default 0 not null" },
-		{ "max_vsize_task", "smallint unsigned default 0 not null" },
+		{ "max_vsize_task", "int unsigned default 0 not null" },
 		{ "max_vsize_node", "int unsigned default 0 not null" },
 		{ "ave_vsize", "double unsigned default 0.0 not null" },
 		{ "max_rss", "bigint unsigned default 0 not null" },
-		{ "max_rss_task", "smallint unsigned default 0 not null" },
+		{ "max_rss_task", "int unsigned default 0 not null" },
 		{ "max_rss_node", "int unsigned default 0 not null" },
 		{ "ave_rss", "double unsigned default 0.0 not null" },
 		{ "max_pages", "int unsigned default 0 not null" },
-		{ "max_pages_task", "smallint unsigned default 0 not null" },
+		{ "max_pages_task", "int unsigned default 0 not null" },
 		{ "max_pages_node", "int unsigned default 0 not null" },
 		{ "ave_pages", "double unsigned default 0.0 not null" },
 		{ "min_cpu", "int unsigned default 0 not null" },
-		{ "min_cpu_task", "smallint unsigned default 0 not null" },
+		{ "min_cpu_task", "int unsigned default 0 not null" },
 		{ "min_cpu_node", "int unsigned default 0 not null" },
 		{ "ave_cpu", "double unsigned default 0.0 not null" },
 		{ "act_cpufreq", "double unsigned default 0.0 not null" },
 		{ "consumed_energy", "double unsigned default 99.0 not null" },
+		{ "req_cpufreq", "int unsigned default 0 not null" },
+		{ "max_disk_read", "double unsigned default 0 not null" },
+		{ "max_disk_read_task", "int unsigned default 0 not null" },
+		{ "max_disk_read_node", "int unsigned default 0 not null" },
+		{ "ave_disk_read", "double unsigned default 0.0 not null" },
+		{ "max_disk_write", "double unsigned default 0 not null" },
+		{ "max_disk_write_task", "int unsigned default 0 not null" },
+		{ "max_disk_write_node", "int unsigned default 0 not null" },
+		{ "ave_disk_write", "double unsigned default 0.0 not null" },
 		{ NULL, NULL}
 	};
 
