@@ -8,7 +8,7 @@
  *  Written by Danny Auble <da@llnl.gov>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -426,7 +426,7 @@ no_rollup_change:
 			"id_group, nodelist, id_resv, timelimit, "
 			"time_eligible, time_submit, time_start, "
 			"job_name, track_steps, state, priority, cpus_req, "
-			"cpus_alloc, nodes_alloc",
+			"cpus_alloc, nodes_alloc, mem_req",
 			mysql_conn->cluster_name, job_table);
 
 		if (job_ptr->account)
@@ -446,7 +446,7 @@ no_rollup_change:
 
 		xstrfmtcat(query,
 			   ") values (%u, %u, %u, %u, %u, %u, '%s', %u, %u, "
-			   "%ld, %ld, %ld, '%s', %u, %u, %u, %u, %u, %u",
+			   "%ld, %ld, %ld, '%s', %u, %u, %u, %u, %u, %u, %u",
 			   job_ptr->job_id, job_ptr->assoc_id,
 			   job_ptr->qos_id, wckeyid,
 			   job_ptr->user_id, job_ptr->group_id, nodes,
@@ -454,7 +454,8 @@ no_rollup_change:
 			   begin_time, submit_time, start_time,
 			   jname, track_steps, job_state,
 			   job_ptr->priority, job_ptr->details->min_cpus,
-			   job_ptr->total_cpus, node_cnt);
+			   job_ptr->total_cpus, node_cnt,
+			   job_ptr->details->pn_min_memory);
 
 		if (job_ptr->account)
 			xstrfmtcat(query, ", '%s'", job_ptr->account);
@@ -479,13 +480,15 @@ no_rollup_change:
 			   "time_submit=%ld, time_start=%ld, "
 			   "job_name='%s', track_steps=%u, id_qos=%u, "
 			   "state=greatest(state, %u), priority=%u, "
-			   "cpus_req=%u, cpus_alloc=%u, nodes_alloc=%u",
+			   "cpus_req=%u, cpus_alloc=%u, nodes_alloc=%u, "
+			   "mem_req=%u",
 			   wckeyid, job_ptr->user_id, job_ptr->group_id, nodes,
 			   job_ptr->resv_id, job_ptr->time_limit,
 			   submit_time, start_time,
 			   jname, track_steps, job_ptr->qos_id, job_state,
 			   job_ptr->priority, job_ptr->details->min_cpus,
-			   job_ptr->total_cpus, node_cnt);
+			   job_ptr->total_cpus, node_cnt,
+			   job_ptr->details->pn_min_memory);
 
 		if (job_ptr->account)
 			xstrfmtcat(query, ", account='%s'", job_ptr->account);
@@ -542,12 +545,13 @@ no_rollup_change:
 		xstrfmtcat(query, "time_start=%ld, job_name='%s', state=%u, "
 			   "cpus_alloc=%u, nodes_alloc=%u, id_qos=%u, "
 			   "id_assoc=%u, id_wckey=%u, id_resv=%u, "
-			   "timelimit=%u, "
+			   "timelimit=%u, mem_req=%u, "
 			   "time_eligible=%ld where job_db_inx=%d",
 			   start_time, jname, job_state,
 			   job_ptr->total_cpus, node_cnt, job_ptr->qos_id,
 			   job_ptr->assoc_id, wckeyid,
 			   job_ptr->resv_id, job_ptr->time_limit,
+			   job_ptr->details->pn_min_memory,
 			   begin_time, job_ptr->db_index);
 
 		debug3("%d(%s:%d) query\n%s",
@@ -629,12 +633,13 @@ extern List as_mysql_modify_job(mysql_conn_t *mysql_conn, uint32_t uid,
 	}
 
 	/* Here we want to get the last job submitted here */
-	query = xstrdup_printf("select job_db_inx, id_job, time_submit "
+	query = xstrdup_printf("select job_db_inx, id_job, time_submit, "
+			       "id_user "
 			       "from \"%s_%s\" where deleted=0 "
-			       "&& id_job=%u && id_user=%u "
+			       "&& id_job=%u "
 			       "order by time_submit desc limit 1;",
 			       job_cond->cluster, job_table,
-			       job_cond->job_id, uid);
+			       job_cond->job_id);
 
 	debug3("%d(%s:%d) query\n%s",
 	       mysql_conn->conn, THIS_FILE, __LINE__, query);
@@ -647,6 +652,17 @@ extern List as_mysql_modify_job(mysql_conn_t *mysql_conn, uint32_t uid,
 	if ((row = mysql_fetch_row(result))) {
 		char tmp_char[25];
 		time_t time_submit = atol(row[2]);
+
+		if ((uid != atoi(row[3])) &&
+		    !is_user_min_admin_level(mysql_conn, uid,
+					     SLURMDB_ADMIN_OPERATOR)) {
+			errno = ESLURM_ACCESS_DENIED;
+			xfree(vals);
+			xfree(query);
+			mysql_free_result(result);
+			return NULL;
+		}
+
 		slurm_make_time_str(&time_submit, tmp_char, sizeof(tmp_char));
 
 		xstrfmtcat(cond_char, "job_db_inx=%s", row[0]);
@@ -925,19 +941,19 @@ extern int as_mysql_step_start(mysql_conn_t *mysql_conn,
 		"insert into \"%s_%s\" (job_db_inx, id_step, time_start, "
 		"step_name, state, "
 		"cpus_alloc, nodes_alloc, task_cnt, nodelist, "
-		"node_inx, task_dist) "
+		"node_inx, task_dist, req_cpufreq) "
 		"values (%d, %d, %d, '%s', %d, %d, %d, %d, "
-		"'%s', '%s', %d) "
+		"'%s', '%s', %d, %u) "
 		"on duplicate key update cpus_alloc=%d, nodes_alloc=%d, "
 		"task_cnt=%d, time_end=0, state=%d, "
-		"nodelist='%s', node_inx='%s', task_dist=%d",
+		"nodelist='%s', node_inx='%s', task_dist=%d, req_cpufreq=%u",
 		mysql_conn->cluster_name, step_table,
 		step_ptr->job_ptr->db_index,
 		step_ptr->step_id,
 		(int)start_time, step_name,
 		JOB_RUNNING, cpus, nodes, tasks, node_list, node_inx, task_dist,
-		cpus, nodes, tasks, JOB_RUNNING,
-		node_list, node_inx, task_dist);
+		step_ptr->cpu_freq, cpus, nodes, tasks, JOB_RUNNING,
+		node_list, node_inx, task_dist, step_ptr->cpu_freq);
 	debug3("%d(%s:%d) query\n%s",
 	       mysql_conn->conn, THIS_FILE, __LINE__, query);
 	rc = mysql_db_query(mysql_conn, query);
@@ -956,6 +972,8 @@ extern int as_mysql_step_complete(mysql_conn_t *mysql_conn,
 	struct jobacctinfo *jobacct = (struct jobacctinfo *)step_ptr->jobacct;
 	struct jobacctinfo dummy_jobacct;
 	double ave_vsize = NO_VAL, ave_rss = NO_VAL, ave_pages = NO_VAL;
+	double ave_disk_read =  (double)NO_VAL;
+	double ave_disk_write = (double)NO_VAL;
 	double ave_cpu = (double)NO_VAL;
 	char *query = NULL;
 	int rc =SLURM_SUCCESS;
@@ -1025,6 +1043,10 @@ extern int as_mysql_step_complete(mysql_conn_t *mysql_conn,
 		ave_pages /= (double)tasks;
 		ave_cpu = (double)jobacct->tot_cpu;
 		ave_cpu /= (double)tasks;
+		ave_disk_read = (double)jobacct->tot_disk_read;
+		ave_disk_read /= (double)tasks;
+		ave_disk_write = (double)jobacct->tot_disk_write;
+		ave_disk_write /= (double)tasks;
 	}
 
 	if (!step_ptr->job_ptr->db_index) {
@@ -1052,6 +1074,10 @@ extern int as_mysql_step_complete(mysql_conn_t *mysql_conn,
 		"kill_requid=%d, exit_code=%d, "
 		"user_sec=%u, user_usec=%u, "
 		"sys_sec=%u, sys_usec=%u, "
+		"max_disk_read=%f, max_disk_read_task=%u, "
+		"max_disk_read_node=%u, ave_disk_read=%f, "
+		"max_disk_write=%f, max_disk_write_task=%u, "
+		"max_disk_write_node=%u, ave_disk_write=%f, "
 		"max_vsize=%u, max_vsize_task=%u, "
 		"max_vsize_node=%u, ave_vsize=%f, "
 		"max_rss=%u, max_rss_task=%u, "
@@ -1074,6 +1100,22 @@ extern int as_mysql_step_complete(mysql_conn_t *mysql_conn,
 		jobacct->sys_cpu_sec,
 		/* system microsecs */
 		jobacct->sys_cpu_usec,
+		/* max disk_read */
+		jobacct->max_disk_read,
+		/* max disk_read task */
+		jobacct->max_disk_read_id.taskid,
+		/* max disk_read node */
+		jobacct->max_disk_read_id.nodeid,
+		/* ave disk_read */
+		ave_disk_read,
+		/* max disk_write */
+		jobacct->max_disk_write,
+		/* max disk_write task */
+		jobacct->max_disk_write_id.taskid,
+		/* max disk_write node */
+		jobacct->max_disk_write_id.nodeid,
+		/* ave disk_write */
+		ave_disk_write,
 		jobacct->max_vsize,	/* max vsize */
 		jobacct->max_vsize_id.taskid,	/* max vsize task */
 		jobacct->max_vsize_id.nodeid,	/* max vsize node */
