@@ -375,6 +375,8 @@ static int _get_job_req_field (lua_State *L)
 		lua_pushnumber (L, job_desc->contiguous);
 	} else if (!strcmp(name, "cores_per_socket")) {
 		lua_pushnumber (L, job_desc->cores_per_socket);
+	} else if (!strcmp(name, "cpus_per_task")) {
+		lua_pushnumber (L, job_desc->cpus_per_task);
 	} else if (!strcmp(name, "default_account")) {
 		lua_pushstring (L, _get_default_account(job_desc->user_id));
 	} else if (!strcmp(name, "dependency")) {
@@ -499,6 +501,8 @@ static int _set_job_req_field (lua_State *L)
 		job_desc->contiguous = luaL_checknumber(L, 3);
 	} else if (!strcmp(name, "cores_per_socket")) {
 		job_desc->cores_per_socket = luaL_checknumber(L, 3);
+	} else if (!strcmp(name, "cpus_per_task")) {
+		job_desc->cpus_per_task = luaL_checknumber(L, 3);
 	} else if (!strcmp(name, "dependency")) {
 		value_str = luaL_checkstring(L, 3);
 		xfree(job_desc->dependency);
