@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -102,7 +102,7 @@ const uint32_t min_plug_version = 100;
 /*****************************************************************************\
  * We've provided a simple example of the type of things you can do with this
  * plugin. If you develop another plugin that may be of interest to others
- * please post it to slurm-dev@lists.llnl.gov  Thanks!
+ * please post it to slurm-dev@schedmd.com  Thanks!
 \*****************************************************************************/
 
 /* Test if this user can run jobs in the selected partition based upon
@@ -144,8 +144,6 @@ extern int job_submit(struct job_descriptor *job_desc, uint32_t submit_uid)
 		return SLURM_SUCCESS;
 
 	part_iterator = list_iterator_create(part_list);
-	if (!part_iterator)
-		fatal("list_iterator_create malloc");
 	while ((part_ptr = (struct part_record *) list_next(part_iterator))) {
 		if (!(part_ptr->state_up & PARTITION_SUBMIT))
 			continue;	/* nobody can submit jobs here */
