@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -50,6 +50,9 @@
  *  PARTITION		Partition name used to run job
  *  PROCS		Count of allocated CPUs
  *  START		Time of job start, UTS
+ *  STDERR		Job's stderr file name (if any)
+ *  STDIN		Job's stdin file name (if any)
+ *  STDOUT		Job's stdout file name (if any)
  *  SUBMIT		Time of job submission, UTS
  *  UID			User ID of job owner
  *  WORK_DIR		Job's working directory
@@ -189,6 +192,9 @@ struct jobcomp_info {
 	char *jobstate;
 	char *account;
 	char *work_dir;
+	char *std_in;
+	char *std_out;
+	char *std_err;
 #ifdef HAVE_BG
 	char *connect_type;
 	char *geometry;
@@ -246,6 +252,15 @@ static struct jobcomp_info * _jobcomp_info_create (struct job_record *job)
 		j->work_dir = xstrdup(job->details->work_dir);
 	else
 		j->work_dir = xstrdup("unknown");
+	if (job->details) {
+		if (job->details->std_in)
+			j->std_in = xstrdup(job->details->std_in);
+		if (job->details->std_out)
+			j->std_out = xstrdup(job->details->std_out);
+		if (job->details->std_err)
+			j->std_err = xstrdup(job->details->std_err);
+	}
+		
 #ifdef HAVE_BG
 	j->connect_type = select_g_select_jobinfo_xstrdup(job->select_jobinfo,
 						   SELECT_PRINT_CONNECTION);
@@ -267,6 +282,9 @@ static void _jobcomp_info_destroy (struct jobcomp_info *j)
 	xfree (j->jobstate);
 	xfree (j->account);
 	xfree (j->work_dir);
+	xfree (j->std_in);
+	xfree (j->std_out);
+	xfree (j->std_err);
 #ifdef HAVE_BG
 	xfree (j->connect_type);
 	xfree (j->geometry);
@@ -379,6 +397,12 @@ static char ** _create_environment (struct jobcomp_info *job)
 	_env_append (&env, "JOBSTATE",  job->jobstate);
 	_env_append (&env, "PARTITION", job->partition);
 	_env_append (&env, "WORK_DIR",  job->work_dir);
+	if (job->std_in)
+		_env_append (&env, "STDIN",     job->std_in);
+	if (job->std_out)
+		_env_append (&env, "STDOUT",     job->std_out);
+	if (job->std_err)
+		_env_append (&env, "STDERR",     job->std_err);
 
 #ifdef HAVE_BG
 	_env_append (&env, "BLOCKID",      job->blockid);
