@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -124,8 +124,6 @@ extern List find_preemptable_jobs(struct job_record *job_ptr)
 		/* This job is a preemption candidate */
 		if (preemptee_job_list == NULL) {
 			preemptee_job_list = list_create(NULL);
-			if (preemptee_job_list == NULL)
-				fatal("list_create malloc failure");
 		}
 		list_append(preemptee_job_list, job_p);
 	}
