@@ -223,6 +223,12 @@ static int _will_run_test(struct job_record *job_ptr, bitstr_t *bitmap,
 			  List preemptee_candidates, List *preemptee_job_list,
 			  bitstr_t *exc_core_bitmap);
 
+struct sort_support {
+	int jstart;
+	struct job_resources *tmpjobs;
+};
+static int _compare_support(const void *, const void *);
+
 static void _dump_job_res(struct job_resources *job) {
 	char str[64];
 
@@ -567,9 +573,9 @@ static void _build_row_bitmaps(struct part_res_record *p_ptr,
 			       struct job_record *job_ptr)
 {
 	uint32_t i, j, num_jobs, size;
-	int x, *jstart;
+	int x;
 	struct part_row_data *this_row, *orig_row;
-	struct job_resources **tmpjobs, *job;
+	struct sort_support *ss;
 
 	if (!p_ptr->row)
 		return;
@@ -634,16 +640,15 @@ static void _build_row_bitmaps(struct part_res_record *p_ptr,
 	size = bit_size(p_ptr->row[0].row_bitmap);
 
 	/* create a master job list and clear out ALL row data */
-	tmpjobs = xmalloc(num_jobs * sizeof(struct job_resources *));
-	jstart  = xmalloc(num_jobs * sizeof(int));
+	ss = xmalloc(num_jobs * sizeof(struct sort_support));
 	x = 0;
 	for (i = 0; i < p_ptr->num_rows; i++) {
 		for (j = 0; j < p_ptr->row[i].num_jobs; j++) {
-			tmpjobs[x] = p_ptr->row[i].job_list[j];
+			ss[x].tmpjobs = p_ptr->row[i].job_list[j];
 			p_ptr->row[i].job_list[j] = NULL;
-			jstart[x] = bit_ffs(tmpjobs[x]->node_bitmap);
-			jstart[x] = cr_get_coremap_offset(jstart[x]);
-			jstart[x] += bit_ffs(tmpjobs[x]->core_bitmap);
+			ss[x].jstart = bit_ffs(ss[x].tmpjobs->node_bitmap);
+			ss[x].jstart = cr_get_coremap_offset(ss[x].jstart);
+			ss[x].jstart += bit_ffs(ss[x].tmpjobs->core_bitmap);
 			x++;
 		}
 		p_ptr->row[i].num_jobs = 0;
@@ -661,46 +666,33 @@ static void _build_row_bitmaps(struct part_res_record *p_ptr,
 	 *     - may still get scenarios where jobs should switch rows
 	 *     - fixme: JOB SHUFFLING BETWEEN ROWS NEEDS TESTING
 	 */
-	for (i = 0; i < num_jobs; i++) {
-		for (j = i+1; j < num_jobs; j++) {
-			if (jstart[j] < jstart[i]
-			    || (jstart[j] == jstart[i] &&
-				tmpjobs[j]->ncpus > tmpjobs[i]->ncpus)) {
-				x = jstart[i];
-				jstart[i] = jstart[j];
-				jstart[j] = x;
-				job = tmpjobs[i];
-				tmpjobs[i] = tmpjobs[j];
-				tmpjobs[j] = job;
-			}
-		}
-	}
-
+	qsort(ss, num_jobs, sizeof(struct sort_support), _compare_support);
 	if (select_debug_flags & DEBUG_FLAG_CPU_BIND) {
 		for (i = 0; i < num_jobs; i++) {
 			char cstr[64], nstr[64];
-			if (tmpjobs[i]->core_bitmap) {
+			if (ss[i].tmpjobs->core_bitmap) {
 				bit_fmt(cstr, (sizeof(cstr)-1) ,
-					tmpjobs[i]->core_bitmap);
+					ss[i].tmpjobs->core_bitmap);
 			} else
 				sprintf(cstr, "[no core_bitmap]");
-			if (tmpjobs[i]->node_bitmap) {
+			if (ss[i].tmpjobs->node_bitmap) {
 				bit_fmt(nstr, (sizeof(nstr)-1),
-					tmpjobs[i]->node_bitmap);
+					ss[i].tmpjobs->node_bitmap);
 			} else
 				sprintf(nstr, "[no node_bitmap]");
-			info("DEBUG:  jstart %d job nb %s cb %s", jstart[i],
-			     nstr, cstr);
+			info("DEBUG:  jstart %d job nb %s cb %s",
+			     ss[i].jstart, nstr, cstr);
 		}
 	}
 
 	/* add jobs to the rows */
 	for (j = 0; j < num_jobs; j++) {
 		for (i = 0; i < p_ptr->num_rows; i++) {
-			if (_can_job_fit_in_row(tmpjobs[j], &(p_ptr->row[i]))) {
+			if (_can_job_fit_in_row(ss[j].tmpjobs,
+						&(p_ptr->row[i]))) {
 				/* job fits in row, so add it */
-				_add_job_to_row(tmpjobs[j], &(p_ptr->row[i]));
-				tmpjobs[j] = NULL;
+				_add_job_to_row(ss[j].tmpjobs,&(p_ptr->row[i]));
+				ss[j].tmpjobs = NULL;
 				break;
 			}
 		}
@@ -710,7 +702,7 @@ static void _build_row_bitmaps(struct part_res_record *p_ptr,
 
 	/* test for dangling jobs */
 	for (j = 0; j < num_jobs; j++) {
-		if (tmpjobs[j])
+		if (ss[j].tmpjobs)
 			break;
 	}
 	if (j < num_jobs) {
@@ -750,8 +742,8 @@ static void _build_row_bitmaps(struct part_res_record *p_ptr,
 
 	if (orig_row)
 		_destroy_row_data(orig_row, p_ptr->num_rows);
-	xfree(tmpjobs);
-	xfree(jstart);
+	xfree(ss);
+
 	return;
 
 	/* LEFTOVER DESIGN THOUGHTS, PRESERVED HERE */
@@ -1815,6 +1807,22 @@ static int _will_run_test(struct job_record *job_ptr, bitstr_t *bitmap,
 	return rc;
 }
 
+static int
+_compare_support(const void *v, const void *v1)
+{
+	struct sort_support *s;
+	struct sort_support *s1;
+
+	s = (struct sort_support *)v;
+	s1 = (struct sort_support *)v1;
+
+	if (s->jstart > s1->jstart
+		|| (s->jstart == s1->jstart
+			&& s->tmpjobs->ncpus > s1->tmpjobs->ncpus))
+		return 1;
+
+	return 0;
+}
 /*
  * init() is called when the plugin is loaded, before any other functions
  * are called.  Put global initialization here.
@@ -2662,7 +2670,7 @@ bitstr_t *sequential_pick(bitstr_t *avail_bitmap, uint32_t node_cnt,
 
 			cores_in_node = 0;
 
-			/* First let's see in there are enough cores in 
+			/* First let's see in there are enough cores in
 			 * this node */
 			for (i = 0; i < local_cores; i++) {
 				if (bit_test(tmpcore, coff + i))
@@ -2671,7 +2679,7 @@ bitstr_t *sequential_pick(bitstr_t *avail_bitmap, uint32_t node_cnt,
 			if (cores_in_node < cores_per_node)
 				continue;
 
-			debug2("Using node %d (avail: %d, needed: %d)", 
+			debug2("Using node %d (avail: %d, needed: %d)",
 				inx, cores_in_node, cores_per_node);
 
 			cores_in_node = 0;
@@ -2803,7 +2811,7 @@ extern bitstr_t * select_p_resv_test(bitstr_t *avail_bitmap, uint32_t node_cnt,
 
 	if (core_cnt && (*core_bitmap == NULL))
 		*core_bitmap = _make_core_bitmap_filtered(avail_bitmap, 0);
-	
+
 	rem_nodes = node_cnt;
 
 	/* Assuming symmetric cluster */
@@ -2917,7 +2925,7 @@ extern bitstr_t * select_p_resv_test(bitstr_t *avail_bitmap, uint32_t node_cnt,
 			if (switches_node_cnt[j] == 0)
 				continue;
 			if (core_cnt) {
-				sufficient = 
+				sufficient =
 					(switches_node_cnt[j] >= rem_nodes) &&
 					(switches_cpu_cnt[j] >= core_cnt[0]);
 			} else
@@ -2968,7 +2976,7 @@ extern bitstr_t * select_p_resv_test(bitstr_t *avail_bitmap, uint32_t node_cnt,
 				}
 				if (avail_cores_in_node < cores_per_node)
 					continue;
-				
+
 				debug2("Using node %d with %d cores available",
 				       i, avail_cores_in_node);
 			}
@@ -2995,7 +3003,7 @@ fini:	for (i=0; i<switch_record_cnt; i++) {
 	xfree(switches_node_cnt);
 	xfree(switches_required);
 
-	if (avail_nodes_bitmap && core_cnt) { 
+	if (avail_nodes_bitmap && core_cnt) {
 		/* Reservation is using partial nodes */
 		//char str[100];
 		bitstr_t *exc_core_bitmap = NULL;
