@@ -47,6 +47,9 @@
 
 /* Location of ALPS apbasil executable (supported on XT/XE CNL) */
 #define DEFAULT_APBASIL           "/usr/bin/apbasil"
+/* Default amount of time to wait for the apbasil command to finish.
+ * (uint16_t) NO_VAL signifies no time out. */
+#define DEFAULT_APBASIL_TIMEOUT   (uint16_t) NO_VAL
 /* Location of ALPS apkill executable (supported on XT/XE CNL) */
 #define DEFAULT_APKILL            "/usr/bin/apkill"
 /* database name to use  */
@@ -80,6 +83,7 @@
 typedef struct {
 	char		*alps_engine;
 	char		*apbasil;
+	uint16_t	apbasil_timeout;
 	char		*apkill;
 
 	char		*sdb_host;
