@@ -5,13 +5,18 @@
  * Portions Copyright (C) 2011 SchedMD <http://www.schedmd.com>.
  * Licensed under the GPLv2.
  */
+#include "basil_interface.h"
 #include "parser_internal.h"
 #include <stdarg.h>
+#include <unistd.h>
 
 int   log_sel = -1;
 char *xml_log_loc = NULL;
 char  xml_log_file_name[256] = "";
 
+pthread_cond_t  timer_cond = PTHREAD_COND_INITIALIZER;
+pthread_mutex_t timer_lock = PTHREAD_MUTEX_INITIALIZER;
+
 /*
  * Function: _write_xml
  * Purpose:  Intercepts SLURM's ALPS BASIL XML requests so that it can
@@ -181,6 +186,30 @@ static void _rsvn_write_reserve_xml(FILE *fp, struct basil_reservation *r,
 		   "</BasilRequest>\n");
 }
 
+static void *_timer_func(void *raw_data)
+{
+	pid_t child = *(pid_t *)raw_data;
+	int time_out;
+	struct timespec ts;
+
+	time_out = cray_conf->apbasil_timeout;
+	debug2("This is a timer thread for process: %d (slurmctld)--"
+	       "timeout: %d, apbasil pid: %d\n", getpid(), time_out, child);
+
+	pthread_mutex_lock(&timer_lock);
+	ts.tv_sec  = time(NULL);
+	ts.tv_nsec = 0;
+	ts.tv_sec += time_out;
+	if (pthread_cond_timedwait(&timer_cond, &timer_lock, &ts) == ETIMEDOUT){
+		info("Apbasil taking too long--terminating apbasil pid: %d",
+		     child);
+		kill(child, SIGKILL);
+		debug2("Exiting timer thread, apbasil pid had been: %d", child);
+	}
+	pthread_mutex_unlock(&timer_lock);
+	pthread_exit(NULL);
+}
+
 /*
  * basil_request - issue BASIL request and parse response
  * @bp:	method-dependent parse data to guide the parsing process
@@ -190,9 +219,13 @@ static void _rsvn_write_reserve_xml(FILE *fp, struct basil_reservation *r,
 int basil_request(struct basil_parse_data *bp)
 {
 	int to_child, from_child;
-	int ec, rc = -BE_UNKNOWN;
+	int ec, i, rc = -BE_UNKNOWN;
 	FILE *apbasil;
-	pid_t pid;
+	pid_t pid = -1;
+	pthread_t thread;
+	pthread_attr_t attr;
+	int time_it_out = 1;
+	DEF_TIMERS;
 
 	if (log_sel == -1)
 		_init_log_config();
@@ -201,13 +234,33 @@ int basil_request(struct basil_parse_data *bp)
 		error("No alps client defined");
 		return 0;
 	}
+
+	if ((cray_conf->apbasil_timeout == 0) ||
+	    (cray_conf->apbasil_timeout == (uint16_t) NO_VAL)) {
+		debug2("No ApbasilTimeout configured (%u)",
+		       cray_conf->apbasil_timeout);
+		time_it_out = 0;
+	} else {
+		slurm_attr_init(&attr);
+		pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
+	}
+
 	assert(bp->version < BV_MAX);
 	assert(bp->method > BM_none && bp->method < BM_MAX);
 
-	pid = popen2(cray_conf->apbasil, &to_child, &from_child, true);
+	START_TIMER;
+	for (i = 0; ((i < 10) && (pid < 0)); i++) {
+		if (i)
+			usleep(100000);
+		pid = popen2(cray_conf->apbasil, &to_child, &from_child, true);
+	}
 	if (pid < 0)
 		fatal("popen2(\"%s\", ...)", cray_conf->apbasil);
 
+	if (time_it_out) {
+		pthread_create(&thread, &attr, _timer_func, (void*)&pid);
+	}
+
 	/* write out request */
 	apbasil = fdopen(to_child, "w");
 	if (apbasil == NULL)
@@ -263,9 +316,22 @@ int basil_request(struct basil_parse_data *bp)
 
 	rc = parse_basil(bp, from_child);
 	ec = wait_for_child(pid);
+
+	if (time_it_out) {
+		slurm_attr_destroy(&attr);
+		debug2("Killing the timer thread.");
+		pthread_mutex_lock(&timer_lock);
+		pthread_cond_broadcast(&timer_cond);
+		pthread_mutex_unlock(&timer_lock);
+	}
+
+	END_TIMER;
 	if (ec) {
 		error("%s child process for BASIL %s method exited with %d",
 		      cray_conf->apbasil, bm_names[bp->method], ec);
+	} else if (DELTA_TIMER > 5000000) {	/* 5 seconds limit */
+		info("%s child process for BASIL %s method time %s",
+		     cray_conf->apbasil, bm_names[bp->method], TIME_STR);
 	}
 
 	return rc;
