@@ -6,7 +6,7 @@
  *  Written by Morris Jette <jette@schedmd.com>
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -490,7 +490,7 @@ extern void   free_inv(struct basil_inventory *inv)
 
 extern long basil_reserve(const char *user, const char *batch_id,
 			  uint32_t width, uint32_t depth, uint32_t nppn,
-			  uint32_t mem_mb, struct nodespec *ns_head,
+			  uint32_t mem_mb, uint32_t nppcu, struct nodespec *ns_head,
 			  struct basil_accel_param *accel_head)
 {
 	int i;
@@ -499,8 +499,8 @@ extern long basil_reserve(const char *user, const char *batch_id,
 #if _DEBUG
 	struct nodespec *my_node_spec;
 	info("basil_reserve user:%s batch_id:%s width:%u depth:%u nppn:%u "
-	     "mem_mb:%u",
-	     user, batch_id, width, depth, nppn, mem_mb);
+	     "mem_mb:%u nppcu:%u",
+	     user, batch_id, width, depth, nppn, mem_mb, nppcu);
 	my_node_spec = ns_head;
 	while (my_node_spec) {
 		info("basil_reserve node_spec:start:%u,end:%u",
