@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -74,7 +74,6 @@ int switch_record_cnt __attribute__((weak_import));
 slurmdb_cluster_rec_t *working_cluster_rec  __attribute__((weak_import)) = NULL;
 void *acct_db_conn __attribute__((weak_import)) = NULL;
 bitstr_t *avail_node_bitmap __attribute__((weak_import)) = NULL;
-char *default_slurm_config_file __attribute__((weak_import)) = NULL;
 #else
 slurm_ctl_conf_t slurmctld_conf;
 struct node_record *node_record_table_ptr;
@@ -87,7 +86,6 @@ int switch_record_cnt;
 slurmdb_cluster_rec_t *working_cluster_rec = NULL;
 void *acct_db_conn = NULL;
 bitstr_t *avail_node_bitmap = NULL;
-char *default_slurm_config_file = NULL;
 
 int clusteracct_storage_g_node_down(void *db_conn, struct node_record *node_ptr,
 			time_t event_time, char *reason,
@@ -864,7 +862,7 @@ extern int select_p_reconfigure(void)
 }
 
 extern bitstr_t * select_p_resv_test(bitstr_t *avail_bitmap, uint32_t node_cnt,
-				     uint32_t core_cnt, bitstr_t **core_bitmap)
+				     uint32_t *core_cnt, bitstr_t **core_bitmap)
 {
 	return other_resv_test(avail_bitmap, node_cnt, core_cnt, core_bitmap);
 }
