@@ -450,3 +450,63 @@ extern int task_cgroup_memory_attach_task(slurmd_job_t *job)
 
 	return fstatus;
 }
+
+/* return 1 if failcnt file exists and is > 0 */
+int failcnt_non_zero(xcgroup_t* cg, char* param)
+{
+	int fstatus = XCGROUP_ERROR;
+	uint64_t value;
+
+	fstatus = xcgroup_get_uint64_param(cg, param, &value);
+
+	if (fstatus != XCGROUP_SUCCESS) {
+		debug2("unable to read '%s' from '%s'", param, cg->path);
+		return 0;
+	}
+
+	return value > 0;
+}
+
+extern int task_cgroup_memory_check_oom(slurmd_job_t *job)
+{
+	xcgroup_t memory_cg;
+
+	if (xcgroup_create(&memory_ns, &memory_cg, "", 0, 0)
+	    == XCGROUP_SUCCESS) {
+		if (xcgroup_lock(&memory_cg) == XCGROUP_SUCCESS) {
+			/* for some reason the job cgroup limit is hit
+			 * for a step and vice versa...
+			 * can't tell which is which so we'll treat
+			 * them the same */
+			if (failcnt_non_zero(&step_memory_cg,
+					     "memory.memsw.failcnt"))
+				error("Exceeded step memory limit at some "
+				      "point. oom-killer likely killed a "
+				      "process.");
+			else if(failcnt_non_zero(&step_memory_cg,
+						 "memory.failcnt"))
+				error("Exceeded step memory limit at some "
+				      "point. Step may have been partially "
+				      "swapped out to disk.");
+			if (failcnt_non_zero(&job_memory_cg,
+					     "memory.memsw.failcnt"))
+				error("Exceeded job memory limit at some "
+				      "point. oom-killer likely killed a "
+				      "process.");
+			else if (failcnt_non_zero(&job_memory_cg,
+						  "memory.failcnt"))
+				error("Exceeded job memory limit at some "
+				      "point. Job may have been partially "
+				      "swapped out to disk.");
+			xcgroup_unlock(&memory_cg);
+		} else
+			error("task/cgroup task_cgroup_memory_check_oom: "
+			      "task_cgroup_memory_check_oom: unable to lock "
+			      "root memcg : %m");
+		xcgroup_destroy(&memory_cg);
+	} else
+		error("task/cgroup task_cgroup_memory_check_oom: "
+		      "unable to create root memcg : %m");
+
+	return SLURM_SUCCESS;
+}
