@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -97,7 +97,6 @@ static char* topo_conf = NULL;
 static void _destroy_switches(void *ptr);
 static void _free_switch_record_table(void);
 static int  _get_switch_inx(const char *name);
-static char *_get_topo_conf(void);
 static void _log_switches(void);
 static int  _node_name2bitmap(char *node_names, bitstr_t **bitmap, 
 			      hostlist_t *invalid_hostlist);
@@ -295,8 +294,10 @@ static void _validate_switches(void)
 			if (switch_ptr->level != -1)
 				continue;
 			hl = hostlist_create(switch_ptr->switches);
-			if (!hl)
-				fatal("hostlist_create: malloc failure");
+			if (!hl) {
+				fatal("Invalid switches: %s",
+				      switch_ptr->switches);
+			}
 			while ((child = hostlist_pop(hl))) {
 				j = _get_switch_inx(child);
 				if ((j < 0) || (j == i)) {
@@ -427,28 +428,6 @@ static void _free_switch_record_table(void)
 	}
 }
 
-static char *_get_topo_conf(void)
-{
-	char *val = getenv("SLURM_CONF");
-	char *rc;
-	int i;
-
-	if (!val)
-		return xstrdup(TOPOLOGY_CONFIG_FILE);
-
-	/* Replace file name on end of path */
-	i = strlen(val) - strlen("slurm.conf") + strlen("topology.conf") + 1;
-	rc = xmalloc(i);
-	strcpy(rc, val);
-	val = strrchr(rc, (int)'/');
-	if (val)	/* absolute path */
-		val++;
-	else		/* not absolute path */
-		val = rc;
-	strcpy(val, "topology.conf");
-	return rc;
-}
-
 /* Return count of switch configuration entries read */
 extern int  _read_topo_file(slurm_conf_switches_t **ptr_array[])
 {
@@ -461,7 +440,7 @@ extern int  _read_topo_file(slurm_conf_switches_t **ptr_array[])
 
 	debug("Reading the topology.conf file");
 	if (!topo_conf)
-		topo_conf = _get_topo_conf();
+		topo_conf = get_extra_conf_path("topology.conf");
 
 	conf_hashtbl = s_p_hashtbl_create(switch_options);
 	if (s_p_parse_file(conf_hashtbl, NULL, topo_conf, false) ==
@@ -548,8 +527,6 @@ static int _node_name2bitmap(char *node_names, bitstr_t **bitmap,
 	hostlist_t host_list;
 
 	my_bitmap = (bitstr_t *) bit_alloc(node_record_count);
-	if (my_bitmap == NULL)
-		fatal("bit_alloc malloc failure");
 	*bitmap = my_bitmap;
 
 	if (node_names == NULL) {
