@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -50,7 +50,7 @@ char *_elapsed_time(long secs, long usecs)
 	long    subsec = 0;
 	char *str = NULL;
 
-	if(secs < 0 || secs == (long)NO_VAL)
+	if (secs < 0 || secs == (long)NO_VAL)
 		return NULL;
 
 
@@ -58,7 +58,7 @@ char *_elapsed_time(long secs, long usecs)
 		secs++;
 		usecs -= 1E6;
 	}
-	if(usecs > 0) {
+	if (usecs > 0) {
 		/* give me 3 significant digits to tack onto the sec */
 		subsec = (usecs/1000);
 	}
@@ -73,7 +73,7 @@ char *_elapsed_time(long secs, long usecs)
 	else if (hours)
 		str = xstrdup_printf("%2.2ld:%2.2ld:%2.2ld",
 				     hours, minutes, seconds);
-	else if(subsec)
+	else if (subsec)
 		str = xstrdup_printf("%2.2ld:%2.2ld.%3.3ld",
 				     minutes, seconds, subsec);
 	else
@@ -88,23 +88,35 @@ static char *_find_qos_name_from_list(
 	ListIterator itr = NULL;
 	slurmdb_qos_rec_t *qos = NULL;
 
-	if(!qos_list || qosid == NO_VAL)
+	if (!qos_list || qosid == NO_VAL)
 		return NULL;
 
 	itr = list_iterator_create(qos_list);
 	while((qos = list_next(itr))) {
-		if(qosid == qos->id)
+		if (qosid == qos->id)
 			break;
 	}
 	list_iterator_destroy(itr);
 
-	if(qos)
+	if (qos)
 		return qos->name;
 	else
 		return "Unknown";
 }
 
+static void _print_small_double(
+	char *outbuf, int buf_size, double dub, int units)
+{
+	if (fuzzy_equal(dub, NO_VAL))
+		return;
 
+	if (dub > 1)
+		convert_num_unit((float)dub, outbuf, buf_size, units);
+	else if (dub > 0)
+		snprintf(outbuf, buf_size, "%.2fM", dub);
+	else
+		snprintf(outbuf, buf_size, "0");
+}
 
 void print_fields(type_t type, void *object)
 {
@@ -120,13 +132,13 @@ void print_fields(type_t type, void *object)
 	switch(type) {
 	case JOB:
 		step = NULL;
-		if(!job->track_steps)
+		if (!job->track_steps)
 			step = (slurmdb_step_rec_t *)job->first_step_ptr;
 		/* set this to avoid printing out info for things that
 		   don't mean anything.  Like an allocation that never
 		   ran anything.
 		*/
-		if(!step)
+		if (!step)
 			job->track_steps = 1;
 
 		break;
@@ -139,6 +151,7 @@ void print_fields(type_t type, void *object)
 		char *tmp_char = NULL;
 		int tmp_int = NO_VAL, tmp_int2 = NO_VAL;
 		double tmp_dub = (double)NO_VAL;
+		uint32_t tmp_uint32 = (uint32_t)NO_VAL;
 		uint64_t tmp_uint64 = (uint64_t)NO_VAL;
 
 		memset(&outbuf, 0, sizeof(outbuf));
@@ -148,7 +161,7 @@ void print_fields(type_t type, void *object)
 			case JOB:
 				tmp_int = job->alloc_cpus;
 				// we want to use the step info
-				if(!step)
+				if (!step)
 					break;
 			case JOBSTEP:
 				tmp_int = step->ncpus;
@@ -192,9 +205,9 @@ void print_fields(type_t type, void *object)
 				break;
 			}
 			if (!fuzzy_equal(tmp_dub, NO_VAL))
-				convert_num_unit((float)tmp_dub,
-						outbuf, sizeof(outbuf),
-						UNIT_NONE);
+				convert_num_unit2((float)tmp_dub,
+						  outbuf, sizeof(outbuf),
+						  UNIT_KILO, 1000, false);
 
 			field->print_routine(field,
 					     outbuf,
@@ -220,7 +233,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_AVECPU:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_dub = job->stats.cpu_ave;
 				break;
 			case JOBSTEP:
@@ -239,10 +252,50 @@ void print_fields(type_t type, void *object)
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
+		case PRINT_AVEDISKREAD:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_dub = job->stats.disk_read_ave;
+				break;
+			case JOBSTEP:
+				tmp_dub = step->stats.disk_read_ave;
+				break;
+			case JOBCOMP:
+			default:
+				break;
+			}
+			_print_small_double(outbuf, sizeof(outbuf),
+					    tmp_dub, UNIT_MEGA);
+
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_AVEDISKWRITE:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_dub = job->stats.disk_write_ave;
+				break;
+			case JOBSTEP:
+				tmp_dub = step->stats.disk_write_ave;
+				break;
+			case JOBCOMP:
+			default:
+				break;
+			}
+			_print_small_double(outbuf, sizeof(outbuf),
+					    tmp_dub, UNIT_MEGA);
+
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_AVEPAGES:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_dub = job->stats.pages_ave;
 				break;
 			case JOBSTEP:
@@ -264,7 +317,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_AVERSS:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_dub = job->stats.rss_ave;
 				break;
 			case JOBSTEP:
@@ -286,7 +339,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_AVEVSIZE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_dub = job->stats.vsize_ave;
 				break;
 			case JOBSTEP:
@@ -366,14 +419,31 @@ void print_fields(type_t type, void *object)
 				break;
 			}
 			if (!fuzzy_equal(tmp_dub, NO_VAL))
-				convert_num_unit((float)tmp_dub,
-						 outbuf, sizeof(outbuf),
-						 UNIT_NONE);
+				convert_num_unit2((float)tmp_dub,
+						  outbuf, sizeof(outbuf),
+						  UNIT_NONE, 1000, false);
 
 			field->print_routine(field,
 					     outbuf,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_CONSUMED_ENERGY_RAW:
+			switch (type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_dub = step->stats.consumed_energy;
+				break;
+			case JOBSTEP:
+				tmp_dub = step->stats.consumed_energy;
+				break;
+			default:
+				break;
+			}
+
+			field->print_routine(field,
+					     tmp_dub,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_CPU_TIME:
 			switch(type) {
 			case JOB:
@@ -611,7 +681,7 @@ void print_fields(type_t type, void *object)
 			case JOB:
 				/* below really should be step.  It is
 				   not a typo */
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_char = slurm_step_layout_type_name(
 						step->task_dist);
 				break;
@@ -629,10 +699,138 @@ void print_fields(type_t type, void *object)
 					     tmp_char,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_MAXDISKREAD:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_dub = job->stats.disk_read_max;
+				break;
+			case JOBSTEP:
+				tmp_dub = step->stats.disk_read_max;
+				break;
+			case JOBCOMP:
+			default:
+				break;
+			}
+			_print_small_double(outbuf, sizeof(outbuf),
+					    tmp_dub, UNIT_MEGA);
+
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_MAXDISKREADNODE:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_char = find_hostname(
+						job->stats.disk_read_max_nodeid,
+						job->nodes);
+				break;
+			case JOBSTEP:
+				tmp_char = find_hostname(
+					step->stats.disk_read_max_nodeid,
+					step->nodes);
+				break;
+			case JOBCOMP:
+			default:
+				tmp_char = NULL;
+				break;
+			}
+			field->print_routine(field,
+					     tmp_char,
+					     (curr_inx == field_count));
+			xfree(tmp_char);
+			break;
+		case PRINT_MAXDISKREADTASK:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_uint32 =
+						job->stats.disk_read_max_taskid;
+				break;
+			case JOBSTEP:
+				tmp_uint32 = step->stats.disk_read_max_taskid;
+				break;
+			case JOBCOMP:
+			default:
+				tmp_uint32 = NO_VAL;
+				break;
+			}
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
+			field->print_routine(field,
+					     tmp_uint32,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_MAXDISKWRITE:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_dub = job->stats.disk_write_max;
+				break;
+			case JOBSTEP:
+				tmp_dub = step->stats.disk_write_max;
+				break;
+			case JOBCOMP:
+			default:
+				break;
+			}
+			_print_small_double(outbuf, sizeof(outbuf),
+					    tmp_dub, UNIT_MEGA);
+
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
+		case PRINT_MAXDISKWRITENODE:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_char = find_hostname(
+					   job->stats.disk_write_max_nodeid,
+					   job->nodes);
+				break;
+			case JOBSTEP:
+				tmp_char = find_hostname(
+					step->stats.disk_write_max_nodeid,
+					step->nodes);
+				break;
+			case JOBCOMP:
+			default:
+				tmp_char = NULL;
+				break;
+			}
+			field->print_routine(field,
+					     tmp_char,
+					     (curr_inx == field_count));
+			xfree(tmp_char);
+			break;
+		case PRINT_MAXDISKWRITETASK:
+			switch(type) {
+			case JOB:
+				if (!job->track_steps)
+					tmp_uint32 =
+					   job->stats.disk_write_max_taskid;
+				break;
+			case JOBSTEP:
+				tmp_uint32 = step->stats.disk_write_max_taskid;
+				break;
+			case JOBCOMP:
+			default:
+				tmp_uint32 = NO_VAL;
+				break;
+			}
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
+			field->print_routine(field,
+					     tmp_uint32,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_MAXPAGES:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_int = job->stats.pages_max;
 				break;
 			case JOBSTEP:
@@ -642,7 +840,7 @@ void print_fields(type_t type, void *object)
 			default:
 				break;
 			}
-			if(tmp_int != NO_VAL)
+			if (tmp_int != NO_VAL)
 				convert_num_unit((float)tmp_int,
 						 outbuf, sizeof(outbuf),
 						 UNIT_KILO);
@@ -654,7 +852,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXPAGESNODE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_char = find_hostname(
 						job->stats.pages_max_nodeid,
 						job->nodes);
@@ -677,28 +875,28 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXPAGESTASK:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
-					tmp_int =
+				if (!job->track_steps)
+					tmp_uint32 =
 						job->stats.pages_max_taskid;
 				break;
 			case JOBSTEP:
-				tmp_int = step->stats.pages_max_taskid;
+				tmp_uint32 = step->stats.pages_max_taskid;
 				break;
 			case JOBCOMP:
 			default:
-				tmp_int = NO_VAL;
+				tmp_uint32 = NO_VAL;
 				break;
 			}
-			if (tmp_int == (uint16_t)NO_VAL)
-				tmp_int = NO_VAL;
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
 			field->print_routine(field,
-					     tmp_int,
+					     tmp_uint32,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXRSS:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_int = job->stats.rss_max;
 				break;
 			case JOBSTEP:
@@ -708,7 +906,7 @@ void print_fields(type_t type, void *object)
 			default:
 				break;
 			}
-			if(tmp_int != NO_VAL)
+			if (tmp_int != NO_VAL)
 				convert_num_unit((float)tmp_int,
 						 outbuf, sizeof(outbuf),
 						 UNIT_KILO);
@@ -720,7 +918,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXRSSNODE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_char = find_hostname(
 						job->stats.rss_max_nodeid,
 						job->nodes);
@@ -743,27 +941,27 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXRSSTASK:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
-					tmp_int = job->stats.rss_max_taskid;
+				if (!job->track_steps)
+					tmp_uint32 = job->stats.rss_max_taskid;
 				break;
 			case JOBSTEP:
-				tmp_int = step->stats.rss_max_taskid;
+				tmp_uint32 = step->stats.rss_max_taskid;
 				break;
 			case JOBCOMP:
 			default:
-				tmp_int = NO_VAL;
+				tmp_uint32 = NO_VAL;
 				break;
 			}
-			if (tmp_int == (uint16_t)NO_VAL)
-				tmp_int = NO_VAL;
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
 			field->print_routine(field,
-					     tmp_int,
+					     tmp_uint32,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXVSIZE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_int = job->stats.vsize_max;
 				break;
 			case JOBSTEP:
@@ -774,7 +972,7 @@ void print_fields(type_t type, void *object)
 				tmp_int = NO_VAL;
 				break;
 			}
-			if(tmp_int != NO_VAL)
+			if (tmp_int != NO_VAL)
 				convert_num_unit((float)tmp_int,
 						 outbuf, sizeof(outbuf),
 						 UNIT_KILO);
@@ -786,7 +984,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXVSIZENODE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_char = find_hostname(
 						job->stats.vsize_max_nodeid,
 						job->nodes);
@@ -809,28 +1007,28 @@ void print_fields(type_t type, void *object)
 		case PRINT_MAXVSIZETASK:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
-					tmp_int =
+				if (!job->track_steps)
+					tmp_uint32 =
 						job->stats.vsize_max_taskid;
 				break;
 			case JOBSTEP:
-				tmp_int = step->stats.vsize_max_taskid;
+				tmp_uint32 = step->stats.vsize_max_taskid;
 				break;
 			case JOBCOMP:
 			default:
-				tmp_int = NO_VAL;
+				tmp_uint32 = NO_VAL;
 				break;
 			}
-			if (tmp_int == (uint16_t)NO_VAL)
-				tmp_int = NO_VAL;
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
 			field->print_routine(field,
-					     tmp_int,
+					     tmp_uint32,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MINCPU:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_dub = job->stats.cpu_min;
 				break;
 			case JOBSTEP:
@@ -850,7 +1048,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_MINCPUNODE:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
+				if (!job->track_steps)
 					tmp_char = find_hostname(
 						job->stats.cpu_min_nodeid,
 						job->nodes);
@@ -873,21 +1071,21 @@ void print_fields(type_t type, void *object)
 		case PRINT_MINCPUTASK:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps)
-					tmp_int = job->stats.cpu_min_taskid;
+				if (!job->track_steps)
+					tmp_uint32 = job->stats.cpu_min_taskid;
 				break;
 			case JOBSTEP:
-				tmp_int = step->stats.cpu_min_taskid;
+				tmp_uint32 = step->stats.cpu_min_taskid;
 				break;
 			case JOBCOMP:
 			default:
-				tmp_int = NO_VAL;
+				tmp_uint32 = NO_VAL;
 				break;
 			}
-			if (tmp_int == (uint16_t)NO_VAL)
-				tmp_int = NO_VAL;
+			if (tmp_uint32 == (uint32_t)NO_VAL)
+				tmp_uint32 = NO_VAL;
 			field->print_routine(field,
-					     tmp_int,
+					     tmp_uint32,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_NODELIST:
@@ -926,7 +1124,7 @@ void print_fields(type_t type, void *object)
 				break;
 			}
 
-			if(!tmp_int) {
+			if (!tmp_int) {
 				hostlist_t hl = hostlist_create(tmp_char);
 				tmp_int = hostlist_count(hl);
 				hostlist_destroy(hl);
@@ -940,10 +1138,10 @@ void print_fields(type_t type, void *object)
 		case PRINT_NTASKS:
 			switch(type) {
 			case JOB:
-				if(!job->track_steps && !step)
+				if (!job->track_steps && !step)
 					tmp_int = job->alloc_cpus;
 				// we want to use the step info
-				if(!step)
+				if (!step)
 					break;
 			case JOBSTEP:
 				tmp_int = step->ntasks;
@@ -1044,6 +1242,34 @@ void print_fields(type_t type, void *object)
 					     tmp_int,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_REQ_CPUFREQ:
+			switch (type) {
+			case JOB:
+				if (!job->track_steps && !step)
+					tmp_dub = NO_VAL;
+				// we want to use the step info
+				if (!step)
+					break;
+			case JOBSTEP:
+				tmp_dub = step->req_cpufreq;
+				break;
+			default:
+				break;
+			}
+			if (tmp_dub == CPU_FREQ_LOW)
+				snprintf(outbuf, sizeof(outbuf), "Low");
+			else if (tmp_dub == CPU_FREQ_MEDIUM)
+				snprintf(outbuf, sizeof(outbuf), "Medium");
+			else if (tmp_dub == CPU_FREQ_HIGH)
+				snprintf(outbuf, sizeof(outbuf), "High");
+			else if (!fuzzy_equal(tmp_dub, NO_VAL))
+				convert_num_unit2((float)tmp_dub,
+						  outbuf, sizeof(outbuf),
+						  UNIT_KILO, 1000, false);
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_REQ_CPUS:
 			switch(type) {
 			case JOB:
@@ -1063,10 +1289,42 @@ void print_fields(type_t type, void *object)
 					     tmp_int,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_REQ_MEM:
+			switch(type) {
+			case JOB:
+				tmp_uint32 = job->req_mem;
+				break;
+			case JOBSTEP:
+				tmp_uint32 = step->job_ptr->req_mem;
+				break;
+			case JOBCOMP:
+			default:
+				tmp_uint32 = NO_VAL;
+				break;
+			}
+
+			if (tmp_uint32 != (uint32_t)NO_VAL) {
+				bool per_cpu = false;
+				if (tmp_uint32 & MEM_PER_CPU) {
+					tmp_uint32 &= (~MEM_PER_CPU);
+					per_cpu = true;
+				}
+				convert_num_unit((float)tmp_uint32,
+						 outbuf, sizeof(outbuf),
+						 UNIT_MEGA);
+				if (per_cpu)
+					sprintf(outbuf+strlen(outbuf), "c");
+				else
+					sprintf(outbuf+strlen(outbuf), "n");
+			}
+			field->print_routine(field,
+					     outbuf,
+					     (curr_inx == field_count));
+			break;
 		case PRINT_RESV:
 			switch(type) {
 			case JOB:
-				if(job->start)
+				if (job->start)
 					tmp_int = job->start - job->eligible;
 				else
 					tmp_int = time(NULL) - job->eligible;
@@ -1087,7 +1345,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_RESV_CPU:
 			switch(type) {
 			case JOB:
-				if(job->start)
+				if (job->start)
 					tmp_int = (job->start - job->eligible)
 						* job->req_cpus;
 				else
@@ -1110,7 +1368,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_RESV_CPU_RAW:
 			switch(type) {
 			case JOB:
-				if(job->start)
+				if (job->start)
 					tmp_int = (job->start - job->eligible)
 						* job->req_cpus;
 				else
@@ -1173,11 +1431,11 @@ void print_fields(type_t type, void *object)
 					 "%s by %d",
 					 job_state_string(tmp_int),
 					 tmp_int2);
-			else if(tmp_int != NO_VAL)
+			else if (tmp_int != NO_VAL)
 				snprintf(outbuf, FORMAT_STRING_SIZE,
 					 "%s",
 					 job_state_string(tmp_int));
-			else if(tmp_char)
+			else if (tmp_char)
 				snprintf(outbuf, FORMAT_STRING_SIZE,
 					 "%s",
 					 tmp_char);
@@ -1255,7 +1513,7 @@ void print_fields(type_t type, void *object)
 					tmp_char = "UNLIMITED";
 				else if (job->timelimit == NO_VAL)
 					tmp_char = "Partition_Limit";
-				else if(job->timelimit) {
+				else if (job->timelimit) {
 					char tmp1[128];
 					mins2time_str(job->timelimit,
 						      tmp1, sizeof(tmp1));
@@ -1302,7 +1560,7 @@ void print_fields(type_t type, void *object)
 		case PRINT_UID:
 			switch(type) {
 			case JOB:
-				if(job->user) {
+				if (job->user) {
 					if ((pw=getpwnam(job->user)))
 						tmp_int = pw->pw_uid;
 				} else
@@ -1325,9 +1583,9 @@ void print_fields(type_t type, void *object)
 		case PRINT_USER:
 			switch(type) {
 			case JOB:
-				if(job->user)
+				if (job->user)
 					tmp_char = job->user;
-				else if(job->uid != -1) {
+				else if (job->uid != -1) {
 					if ((pw=getpwuid(job->uid)))
 						tmp_char = pw->pw_name;
 				}
