@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -47,8 +47,7 @@
 #define POLL_SLEEP	3	/* retry interval in seconds  */
 
 static bool	_in_node_bit_list(int inx, int *node_list_array);
-static int	_scontrol_load_jobs(job_info_msg_t ** job_buffer_pptr,
-				    uint32_t job_id);
+
 /*
  * Determine if a node index is in a node list pair array.
  * RET -  true if specified index is in the array
@@ -73,8 +72,8 @@ _in_node_bit_list(int inx, int *node_list_array)
 }
 
 /* Load current job table information into *job_buffer_pptr */
-static int
-_scontrol_load_jobs(job_info_msg_t ** job_buffer_pptr, uint32_t job_id)
+extern int
+scontrol_load_job(job_info_msg_t ** job_buffer_pptr, uint32_t job_id)
 {
 	int error_code;
 	static uint16_t last_show_flags = 0xffff;
@@ -175,7 +174,7 @@ scontrol_print_completing (void)
 	node_info_msg_t *node_info_msg;
 	uint16_t         show_flags = 0;
 
-	error_code = _scontrol_load_jobs (&job_info_msg, 0);
+	error_code = scontrol_load_job (&job_info_msg, 0);
 	if (error_code) {
 		exit_code = 1;
 		if (quiet_flag != 1)
@@ -251,11 +250,11 @@ scontrol_get_job_state(uint32_t job_id)
 	int error_code = SLURM_SUCCESS, i;
 	job_info_t *job_ptr = NULL;
 
-	error_code = _scontrol_load_jobs(&job_buffer_ptr, job_id);
+	error_code = scontrol_load_job(&job_buffer_ptr, job_id);
 	if (error_code) {
 		exit_code = 1;
 		if (quiet_flag == -1)
-			slurm_perror ("slurm_load_jobs error");
+			slurm_perror ("slurm_load_job error");
 		return (uint16_t) NO_VAL;
 	}
 	if (quiet_flag == -1) {
@@ -285,13 +284,18 @@ scontrol_print_job (char * job_id_str)
 {
 	int error_code = SLURM_SUCCESS, i, print_cnt = 0;
 	uint32_t job_id = 0;
+	uint16_t array_id = (uint16_t) NO_VAL;
 	job_info_msg_t * job_buffer_ptr = NULL;
 	job_info_t *job_ptr = NULL;
+	char *end_ptr = NULL;
 
-	if (job_id_str)
-		job_id = (uint32_t) strtol (job_id_str, (char **)NULL, 10);
+	if (job_id_str) {
+		job_id = (uint32_t) strtol (job_id_str, &end_ptr, 10);
+		if (end_ptr[0] == '_')
+			array_id = strtol( end_ptr + 1, &end_ptr, 10 );
+	}
 
-	error_code = _scontrol_load_jobs(&job_buffer_ptr, job_id);
+	error_code = scontrol_load_job(&job_buffer_ptr, job_id);
 	if (error_code) {
 		exit_code = 1;
 		if (quiet_flag != 1)
@@ -307,16 +311,26 @@ scontrol_print_job (char * job_id_str)
 	}
 
 	job_ptr = job_buffer_ptr->job_array ;
-	for (i = 0; i < job_buffer_ptr->record_count; i++) {
+	for (i = 0, job_ptr = job_buffer_ptr->job_array;
+	     i < job_buffer_ptr->record_count; i++, job_ptr++) {
+		if ((array_id != (uint16_t) NO_VAL) &&
+		    (array_id != job_ptr->array_task_id))
+			continue;
+		slurm_print_job_info(stdout, job_ptr, one_liner);
 		print_cnt++;
-		slurm_print_job_info (stdout, & job_ptr[i], one_liner ) ;
 	}
 
 	if (print_cnt == 0) {
 		if (job_id_str) {
 			exit_code = 1;
-			if (quiet_flag != 1)
-				printf ("Job %u not found\n", job_id);
+			if (quiet_flag != 1) {
+				if (array_id == (uint16_t) NO_VAL) {
+					printf("Job %u not found\n", job_id);
+				} else {
+					printf("Job %u_%u not found\n",
+					       job_id, array_id);
+				}
+			}
 		} else if (quiet_flag != 1)
 			printf ("No jobs in the system\n");
 	}
@@ -330,27 +344,30 @@ scontrol_print_job (char * job_id_str)
 extern void
 scontrol_print_step (char *job_step_id_str)
 {
-	int error_code, i;
+	int error_code, i, print_cnt = 0;
 	uint32_t job_id = NO_VAL, step_id = NO_VAL;
+	uint16_t array_id = (uint16_t) NO_VAL;
 	char *next_str;
 	job_step_info_response_msg_t *job_step_info_ptr;
 	job_step_info_t * job_step_ptr;
-	static uint32_t last_job_id = 0, last_step_id = 0;
+	static uint32_t last_job_id = 0, last_array_id, last_step_id = 0;
 	static job_step_info_response_msg_t *old_job_step_info_ptr = NULL;
 	static uint16_t last_show_flags = 0xffff;
 	uint16_t show_flags = 0;
 
 	if (job_step_id_str) {
 		job_id = (uint32_t) strtol (job_step_id_str, &next_str, 10);
+		if (next_str[0] == '_')
+			array_id = (uint16_t) strtol(next_str+1, &next_str, 10);
 		if (next_str[0] == '.')
-			step_id = (uint32_t) strtol (&next_str[1], NULL, 10);
+			step_id = (uint32_t) strtol (next_str+1, NULL, 10);
 	}
 
 	if (all_flag)
 		show_flags |= SHOW_ALL;
 
-	if ((old_job_step_info_ptr) &&
-	    (last_job_id == job_id) && (last_step_id == step_id)) {
+	if ((old_job_step_info_ptr) && (last_job_id == job_id) &&
+	    (last_array_id == array_id) && (last_step_id == step_id)) {
 		if (last_show_flags != show_flags)
 			old_job_step_info_ptr->last_update = (time_t) 0;
 		error_code = slurm_get_job_steps (
@@ -366,8 +383,7 @@ scontrol_print_step (char *job_step_id_str)
 			if (quiet_flag == -1)
 				printf ("slurm_get_job_steps no change in data\n");
 		}
-	}
-	else {
+	} else {
 		if (old_job_step_info_ptr) {
 			slurm_free_job_step_info_response_msg (
 				old_job_step_info_ptr);
@@ -399,17 +415,27 @@ scontrol_print_step (char *job_step_id_str)
 	}
 
 	job_step_ptr = job_step_info_ptr->job_steps ;
-	for (i = 0; i < job_step_info_ptr->job_step_count; i++) {
-		slurm_print_job_step_info (stdout, & job_step_ptr[i],
-		                           one_liner ) ;
+	for (i = 0, job_step_ptr = job_step_info_ptr->job_steps;
+	     i < job_step_info_ptr->job_step_count; i++, job_step_ptr++) {
+		if ((array_id != (uint16_t) NO_VAL) &&
+		    (array_id != job_step_ptr->array_task_id))
+			continue;
+		slurm_print_job_step_info(stdout, job_step_ptr, one_liner);
+		print_cnt++;
 	}
 
-	if (job_step_info_ptr->job_step_count == 0) {
+	if (print_cnt == 0) {
 		if (job_step_id_str) {
 			exit_code = 1;
-			if (quiet_flag != 1)
-				printf ("Job step %u.%u not found\n",
-				        job_id, step_id);
+			if (quiet_flag != 1) {
+				if (array_id == (uint16_t) NO_VAL) {
+					printf ("Job step %u.%u not found\n",
+						job_id, step_id);
+				} else {
+					printf ("Job step %u_%u.%u not found\n",
+						job_id, array_id, step_id);
+				}
+			}
 		} else if (quiet_flag != 1)
 			printf ("No job steps in the system\n");
 	}
@@ -510,20 +536,32 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 	stepd_task_info(fd, &task_info, &tcount);
 	for (i = 0; i < (int)tcount; i++) {
 		if (!task_info[i].exited) {
-			printf("%-8d %-8u %-6u %-7d %-8d\n",
-			       task_info[i].pid,
-			       jobid,
-			       stepid,
-			       task_info[i].id,
-			       task_info[i].gtid);
+			if (stepid == NO_VAL)
+				printf("%-8d %-8u %-6s %-7d %-8d\n",
+				       task_info[i].pid,
+				       jobid,
+				       "batch",
+				       task_info[i].id,
+				       task_info[i].gtid);
+			else
+				printf("%-8d %-8u %-6u %-7d %-8d\n",
+				       task_info[i].pid,
+				       jobid,
+				       stepid,
+				       task_info[i].id,
+				       task_info[i].gtid);
 		}
 	}
 
 	stepd_list_pids(fd, &pids, &count);
 	for (i = 0; i < count; i++) {
 		if (!_in_task_array((pid_t)pids[i], task_info, tcount)) {
-			printf("%-8d %-8u %-6u %-7s %-8s\n",
-			       pids[i], jobid, stepid, "-", "-");
+			if (stepid == NO_VAL)
+				printf("%-8d %-8u %-6s %-7s %-8s\n",
+				       pids[i], jobid, "batch", "-", "-");
+			else
+				printf("%-8d %-8u %-6u %-7s %-8s\n",
+				       pids[i], jobid, stepid, "-", "-");
 		}
 	}
 
@@ -764,7 +802,7 @@ static int _blocks_dealloc(void)
 		return -1;
 	}
 	for (i=0; i<new_bg_ptr->record_count; i++) {
-		if(new_bg_ptr->block_array[i].state == BG_BLOCK_TERM) {
+		if (new_bg_ptr->block_array[i].state == BG_BLOCK_TERM) {
 			rc = 1;
 			break;
 		}
@@ -883,7 +921,7 @@ extern int scontrol_job_ready(char *job_id_str)
 		return SLURM_ERROR;
 	}
 
-	if(cluster_flags & CLUSTER_FLAG_BG) {
+	if (cluster_flags & CLUSTER_FLAG_BG) {
 		resource_allocation_response_msg_t *alloc;
 		rc = slurm_allocation_lookup_lite(job_id, &alloc);
 		if (rc == SLURM_SUCCESS) {
