@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -234,37 +234,39 @@ static uint32_t _get_job_time(uint32_t job_id)
 extern int
 scontrol_hold(char *op, char *job_id_str)
 {
-	int rc = SLURM_SUCCESS;
+	int i, rc = SLURM_SUCCESS;
 	char *next_str;
 	job_desc_msg_t job_msg;
-	uint16_t job_state;
-
-	slurm_init_job_desc_msg (&job_msg);
-
-	/* set current user, needed e.g., for AllowGroups checks */
-	job_msg.user_id = getuid();
+	uint32_t job_id;
+	uint16_t array_id;
+	job_info_msg_t *resp;
+	slurm_job_info_t *job_ptr;
 
 	if (job_id_str) {
-		job_msg.job_id = (uint32_t) strtol(job_id_str, &next_str, 10);
-		if ((job_msg.job_id == 0) || (next_str[0] != '\0')) {
+		job_id = (uint32_t) strtol(job_id_str, &next_str, 10);
+		if (next_str[0] == '_')
+			array_id = (uint16_t) strtol(next_str+1, &next_str, 10);
+		else
+			array_id = (uint16_t) NO_VAL;
+		if ((job_id == 0) || (next_str[0] != '\0')) {
 			fprintf(stderr, "Invalid job id specified\n");
-			exit_code = 1;
-			return 0;
+			return 1;
 		}
 	} else {
 		fprintf(stderr, "Invalid job id specified\n");
-		exit_code = 1;
-		return 0;
+		return 1;
 	}
 
-	job_state = scontrol_get_job_state(job_msg.job_id);
-	if (job_state == (uint16_t) NO_VAL)
-		return SLURM_ERROR;
-	if ((job_state & JOB_STATE_BASE) != JOB_PENDING) {
-		slurm_seterrno(ESLURM_JOB_NOT_PENDING);
-		return ESLURM_JOB_NOT_PENDING;
+	if (scontrol_load_job(&resp, job_id)) {
+		if (quiet_flag == -1)
+			slurm_perror ("slurm_load_job error");
+		return 1;
 	}
 
+	slurm_init_job_desc_msg (&job_msg);
+	job_msg.job_id = job_id;
+	/* set current user, needed e.g., for AllowGroups checks */
+	job_msg.user_id = getuid();
 	if ((strncasecmp(op, "holdu", 5) == 0) ||
 	    (strncasecmp(op, "uhold", 5) == 0)) {
 		job_msg.priority = 0;
@@ -274,9 +276,24 @@ scontrol_hold(char *op, char *job_id_str)
 		job_msg.alloc_sid = 0;
 	} else
 		job_msg.priority = INFINITE;
+	for (i = 0, job_ptr = resp->job_array; i < resp->record_count;
+	     i++, job_ptr++) {
+		if ((array_id != (uint16_t) NO_VAL) &&
+		    (job_ptr->array_task_id != array_id))
+			continue;
 
-	if (slurm_update_job(&job_msg))
-		return slurm_get_errno();
+		if (!IS_JOB_PENDING(job_ptr)) {
+			if ((array_id == (uint16_t) NO_VAL) &&
+			    (job_ptr->array_task_id != (uint16_t) NO_VAL))
+				continue;
+			slurm_seterrno(ESLURM_JOB_NOT_PENDING);
+			return ESLURM_JOB_NOT_PENDING;
+		}
+
+		job_msg.job_id = job_ptr->job_id;
+		if (slurm_update_job(&job_msg))
+			rc = slurm_get_errno();
+	}
 
 	return rc;
 }
@@ -387,7 +404,8 @@ scontrol_update_job (int argc, char *argv[])
 		}
 
 		if (strncasecmp(tag, "JobId", MAX(taglen, 3)) == 0) {
-			if (parse_uint32(val, &job_msg.job_id)) {
+			job_msg.job_id = slurm_xlate_job_id(val);
+			if (job_msg.job_id == 0) {
 				error ("Invalid JobId value: %s", val);
 				exit_code = 1;
 				return 0;
@@ -608,6 +626,10 @@ scontrol_update_job (int argc, char *argv[])
 			job_msg.wckey = val;
 			update_cnt++;
 		}
+		else if (strncasecmp(tag, "StdOut", MAX(taglen, 6)) == 0) {
+			job_msg.std_out = val;
+			update_cnt++;
+		}
 		else if (strncasecmp(tag, "Switches", MAX(taglen, 5)) == 0) {
 			char *sep_char;
 			job_msg.req_switch =
@@ -737,7 +759,7 @@ scontrol_update_job (int argc, char *argv[])
 		}
 		else if (strncasecmp(tag, "Conn-Type", MAX(taglen, 2)) == 0) {
 			verify_conn_type(val, job_msg.conn_type);
-			if(job_msg.conn_type[0] != (uint16_t)NO_VAL)
+			if (job_msg.conn_type[0] != (uint16_t)NO_VAL)
 				update_cnt++;
 		}
 		else if (strncasecmp(tag, "Licenses", MAX(taglen, 1)) == 0) {
