@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -98,6 +98,19 @@ scontrol_parse_part_options (int argc, char *argv[], int *update_cnt_ptr,
 			part_msg_ptr->default_time = default_time;
 			(*update_cnt_ptr)++;
 		}
+		else if (strncasecmp(tag, "MaxCPUsPerNode", MAX(taglen, 4))
+			  == 0) {
+			if ((strcasecmp(val,"UNLIMITED") == 0) ||
+			    (strcasecmp(val,"INFINITE") == 0)) {
+				part_msg_ptr->max_cpus_per_node =
+					(uint32_t) INFINITE;
+			} else if (parse_uint32(val, &part_msg_ptr->
+						      max_cpus_per_node)) {
+				error("Invalid MaxCPUsPerNode value: %s", val);
+				return -1;
+			}
+			(*update_cnt_ptr)++;
+		}
 		else if (strncasecmp(tag, "MaxNodes", MAX(taglen, 4)) == 0) {
 			if ((strcasecmp(val,"UNLIMITED") == 0) ||
 			    (strcasecmp(val,"INFINITE") == 0))
