@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -48,6 +48,7 @@
 #include "src/slurmctld/slurmctld.h"
 #include "src/slurmctld/acct_policy.h"
 #include "src/common/node_select.h"
+#include "src/common/slurm_priority.h"
 
 #define _DEBUG 0
 
@@ -77,21 +78,6 @@ static slurmdb_used_limits_t *_get_used_limits_for_user(
 	return used_limits;
 }
 
-static uint64_t _get_unused_cpu_run_secs(struct job_record *job_ptr)
-{
-	uint64_t unused_cpu_run_secs = 0;
-	uint64_t time_limit_secs = (uint64_t)job_ptr->time_limit * 60;
-
-	/* No unused cpu_run_secs if job ran past its time limit */
-	if (job_ptr->end_time >= job_ptr->start_time + time_limit_secs) {
-		return 0;
-	}
-
-	unused_cpu_run_secs = job_ptr->total_cpus *
-		(job_ptr->start_time + time_limit_secs - job_ptr->end_time);
-	return unused_cpu_run_secs;
-}
-
 static bool _valid_job_assoc(struct job_record *job_ptr)
 {
 	slurmdb_association_rec_t assoc_rec, *assoc_ptr;
@@ -129,7 +115,6 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 	slurmdb_association_rec_t *assoc_ptr = NULL;
 	assoc_mgr_lock_t locks = { WRITE_LOCK, NO_LOCK,
 				   WRITE_LOCK, NO_LOCK, NO_LOCK };
-	uint64_t unused_cpu_run_secs = 0;
 	uint64_t used_cpu_run_secs = 0;
 	uint32_t job_memory = 0;
 	uint32_t node_cnt;
@@ -151,7 +136,7 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 #endif
 
 	if (type == ACCT_POLICY_JOB_FINI)
-		unused_cpu_run_secs = _get_unused_cpu_run_secs(job_ptr);
+		priority_g_job_end(job_ptr);
 	else if (type == ACCT_POLICY_JOB_BEGIN)
 		used_cpu_run_secs = (uint64_t)job_ptr->total_cpus
 			* (uint64_t)job_ptr->time_limit * 60;
@@ -197,14 +182,14 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 			used_limits->submit_jobs++;
 			break;
 		case ACCT_POLICY_REM_SUBMIT:
-			if(qos_ptr->usage->grp_used_submit_jobs)
+			if (qos_ptr->usage->grp_used_submit_jobs)
 				qos_ptr->usage->grp_used_submit_jobs--;
 			else
 				debug2("acct_policy_remove_job_submit: "
 				       "grp_submit_jobs underflow for qos %s",
 				       qos_ptr->name);
 
-			if(used_limits->submit_jobs)
+			if (used_limits->submit_jobs)
 				used_limits->submit_jobs--;
 			else
 				debug2("acct_policy_remove_job_submit: "
@@ -240,7 +225,7 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 			}
 
 			qos_ptr->usage->grp_used_mem -= job_memory;
-			if((int32_t)qos_ptr->usage->grp_used_mem < 0) {
+			if ((int32_t)qos_ptr->usage->grp_used_mem < 0) {
 				qos_ptr->usage->grp_used_mem = 0;
 				debug2("acct_policy_job_fini: grp_used_mem "
 				       "underflow for qos %s", qos_ptr->name);
@@ -253,18 +238,6 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 				       "underflow for qos %s", qos_ptr->name);
 			}
 
-			/* If the job finished early remove the extra
-			   time now. */
-			if (unused_cpu_run_secs >
-			    qos_ptr->usage->grp_used_cpu_run_secs) {
-				qos_ptr->usage->grp_used_cpu_run_secs = 0;
-				debug2("acct_policy_job_fini: "
-				       "grp_used_cpu_run_secs "
-				       "underflow for qos %s", qos_ptr->name);
-			} else
-				qos_ptr->usage->grp_used_cpu_run_secs -=
-					unused_cpu_run_secs;
-
 			used_limits->cpus -= job_ptr->total_cpus;
 			if ((int32_t)used_limits->cpus < 0) {
 				used_limits->cpus = 0;
@@ -357,27 +330,6 @@ static void _adjust_limit_usage(int type, struct job_record *job_ptr)
 				       assoc_ptr->acct);
 			}
 
-			/* If the job finished early remove the extra
-			   time now. */
-			if (unused_cpu_run_secs >
-			    assoc_ptr->usage->grp_used_cpu_run_secs) {
-				assoc_ptr->usage->grp_used_cpu_run_secs = 0;
-				debug2("acct_policy_job_fini: "
-				       "grp_used_cpu_run_secs "
-				       "underflow for account %s",
-				       assoc_ptr->acct);
-			} else {
-				assoc_ptr->usage->grp_used_cpu_run_secs -=
-					unused_cpu_run_secs;
-				debug4("acct_policy_job_fini: job %u. "
-				       "Removed %"PRIu64" unused seconds "
-				       "from assoc %s "
-				       "grp_used_cpu_run_secs = %"PRIu64"",
-				       job_ptr->job_id, unused_cpu_run_secs,
-				       assoc_ptr->acct,
-				       assoc_ptr->usage->grp_used_cpu_run_secs);
-			}
-
 			break;
 		default:
 			error("acct_policy: association unknown type %d", type);
@@ -436,14 +388,13 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 {
 	uint32_t time_limit;
 	slurmdb_association_rec_t *assoc_ptr = assoc_in;
-	int parent = 0;
+	int parent = 0, job_cnt = 1;
 	char *user_name = NULL;
 	bool rc = true;
 	uint32_t qos_max_cpus_limit = INFINITE;
 	uint32_t qos_max_nodes_limit = INFINITE;
+	uint32_t qos_time_limit = INFINITE;
 	uint32_t job_memory = 0;
-	uint64_t cpu_time_limit;
-	uint64_t job_cpu_time_limit;
 	bool admin_set_memory_limit = false;
 	assoc_mgr_lock_t locks = { READ_LOCK, NO_LOCK,
 				   READ_LOCK, NO_LOCK, NO_LOCK };
@@ -481,6 +432,9 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		}
 	}
 
+	if (job_desc->array_bitmap)
+		job_cnt = bit_set_count(job_desc->array_bitmap);
+
 	assoc_mgr_lock(&locks);
 
 	if (qos_ptr) {
@@ -624,8 +578,8 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		}
 
 		if ((qos_ptr->grp_submit_jobs != INFINITE) &&
-		    (qos_ptr->usage->grp_used_submit_jobs
-		     >= qos_ptr->grp_submit_jobs)) {
+		    ((qos_ptr->usage->grp_used_submit_jobs + job_cnt)
+		     > qos_ptr->grp_submit_jobs)) {
 			debug2("job submit for user %s(%u): "
 			       "group max submit job limit exceeded %u "
 			       "for qos '%s'",
@@ -647,23 +601,14 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		 * if you can end up in PENDING QOSJobLimit, you need
 		 * to validate it if DenyOnLimit is set
 		 */
-		if (strict_checking && (qos_ptr->max_cpu_mins_pj != INFINITE)
-		    && (job_desc->time_limit != NO_VAL)
-		    && (job_desc->min_cpus != NO_VAL)) {
-			cpu_time_limit = qos_ptr->max_cpu_mins_pj;
-			job_cpu_time_limit = (uint64_t)job_desc->time_limit
-				* (uint64_t)job_desc->min_cpus;
-			if (job_cpu_time_limit > cpu_time_limit) {
-				if (reason)
-					*reason = WAIT_QOS_JOB_LIMIT;
-				debug2("job submit for user %s(%u): "
-				       "cpu time limit %"PRIu64" exceeds "
-				       "qos max per-job %"PRIu64"",
-				       user_name, job_desc->user_id,
-				       job_cpu_time_limit, cpu_time_limit);
-				rc = false;
-				goto end_it;
-			}
+		if (((job_desc->min_cpus  != NO_VAL) ||
+		     (job_desc->min_nodes != NO_VAL)) &&
+		    (qos_ptr->max_cpu_mins_pj != INFINITE)) {
+			uint32_t cpu_cnt = job_desc->min_nodes;
+			if ((job_desc->min_nodes == NO_VAL) ||
+			    (job_desc->min_cpus > job_desc->min_nodes))
+				cpu_cnt = job_desc->min_cpus;
+			qos_time_limit = qos_ptr->max_cpu_mins_pj / cpu_cnt;
 		}
 
 		if ((acct_policy_limit_set->max_cpus == ADMIN_SET_LIMIT)
@@ -754,8 +699,9 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 					job_desc->user_id);
 			if ((!used_limits &&
 			     qos_ptr->max_submit_jobs_pu == 0) ||
-			    (used_limits && (used_limits->submit_jobs
-					     >= qos_ptr->max_submit_jobs_pu))) {
+			    (used_limits &&
+			     ((used_limits->submit_jobs + job_cnt) >
+			      qos_ptr->max_submit_jobs_pu))) {
 				debug2("job submit for user %s(%u): "
 				       "qos max submit job limit exceeded %u",
 				       user_name,
@@ -770,33 +716,36 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		    || (qos_ptr->max_wall_pj == INFINITE)
 		    || (update_call && (job_desc->time_limit == NO_VAL))) {
 			/* no need to check/set */
-		} else {
-			time_limit = qos_ptr->max_wall_pj;
+		} else if (qos_time_limit > qos_ptr->max_wall_pj) {
+			qos_time_limit = qos_ptr->max_wall_pj;
+		}
+
+		if (qos_time_limit != INFINITE) {
 			if (job_desc->time_limit == NO_VAL) {
 				if (part_ptr->max_time == INFINITE)
-					job_desc->time_limit = time_limit;
-				else
+					job_desc->time_limit = qos_time_limit;
+				else {
 					job_desc->time_limit =
-						MIN(time_limit,
+						MIN(qos_time_limit,
 						    part_ptr->max_time);
+				}
 				acct_policy_limit_set->time = 1;
 			} else if (acct_policy_limit_set->time &&
-				   job_desc->time_limit > time_limit) {
-				job_desc->time_limit = time_limit;
+				   job_desc->time_limit > qos_time_limit) {
+				job_desc->time_limit = qos_time_limit;
 			} else if (strict_checking
-				   && job_desc->time_limit > time_limit) {
+				   && job_desc->time_limit > qos_time_limit) {
 				if (reason)
 					*reason = WAIT_QOS_JOB_LIMIT;
 				debug2("job submit for user %s(%u): "
 				       "time limit %u exceeds qos max %u",
 				       user_name,
 				       job_desc->user_id,
-				       job_desc->time_limit, time_limit);
+				       job_desc->time_limit, qos_time_limit);
 				rc = false;
 				goto end_it;
 			}
 		}
-
 	}
 
 	while (assoc_ptr) {
@@ -897,8 +846,8 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		if ((!qos_ptr ||
 		     (qos_ptr && qos_ptr->grp_submit_jobs == INFINITE)) &&
 		    (assoc_ptr->grp_submit_jobs != INFINITE) &&
-		    (assoc_ptr->usage->used_submit_jobs
-		     >= assoc_ptr->grp_submit_jobs)) {
+		    ((assoc_ptr->usage->used_submit_jobs + job_cnt)
+		     > assoc_ptr->grp_submit_jobs)) {
 			debug2("job submit for user %s(%u): "
 			       "group max submit job limit exceeded %u "
 			       "for account '%s'",
@@ -1006,8 +955,8 @@ extern bool acct_policy_validate(job_desc_msg_t *job_desc,
 		if ((!qos_ptr ||
 		     (qos_ptr && qos_ptr->max_submit_jobs_pu == INFINITE)) &&
 		    (assoc_ptr->max_submit_jobs != INFINITE) &&
-		    (assoc_ptr->usage->used_submit_jobs
-		     >= assoc_ptr->max_submit_jobs)) {
+		    ((assoc_ptr->usage->used_submit_jobs + job_cnt)
+		     > assoc_ptr->max_submit_jobs)) {
 			debug2("job submit for user %s(%u): "
 			       "account max submit job limit exceeded %u",
 			       user_name,
@@ -1815,7 +1764,7 @@ extern bool acct_policy_job_runnable(struct job_record *job_ptr)
 		 * parents since we have pre-propogated them, so just
 		 * continue with the next parent
 		 */
-		if(parent) {
+		if (parent) {
 			assoc_ptr = assoc_ptr->usage->parent_assoc_ptr;
 			continue;
 		}
@@ -2072,8 +2021,12 @@ extern bool acct_policy_job_time_out(struct job_record *job_ptr)
 				   READ_LOCK, NO_LOCK, NO_LOCK };
 	time_t now;
 
-	/* now see if we are enforcing limits */
-	if (!(accounting_enforce & ACCOUNTING_ENFORCE_LIMITS))
+	/* Now see if we are enforcing limits.  If Safe is set then
+	 * return false as well since we are being safe if the limit
+	 * was changed after the job was already deemed safe to start.
+	 */
+	if (!(accounting_enforce & ACCOUNTING_ENFORCE_LIMITS)
+	    || (accounting_enforce & ACCOUNTING_ENFORCE_SAFE))
 		return false;
 
 	assoc_mgr_lock(&locks);
@@ -2195,7 +2148,7 @@ extern bool acct_policy_job_time_out(struct job_record *job_ptr)
 
 		assoc = assoc->usage->parent_assoc_ptr;
 		/* these limits don't apply to the root assoc */
-		if(assoc == assoc_mgr_root_assoc)
+		if (assoc == assoc_mgr_root_assoc)
 			break;
 	}
 job_failed:
