@@ -531,6 +531,7 @@ static void *_wdog(void *args)
 	ret_data_info_t *ret_data_info = NULL;
 
 	if ( (agent_ptr->msg_type == SRUN_JOB_COMPLETE)			||
+	     (agent_ptr->msg_type == SRUN_REQUEST_SUSPEND)		||
 	     (agent_ptr->msg_type == SRUN_STEP_MISSING)			||
 	     (agent_ptr->msg_type == SRUN_STEP_SIGNAL)			||
 	     (agent_ptr->msg_type == SRUN_EXEC)				||
@@ -620,6 +621,7 @@ static void _notify_slurmctld_jobs(agent_info_t *agent_ptr)
 		job_id  = msg->job_id;
 		step_id = NO_VAL;
 	} else if ((agent_ptr->msg_type == SRUN_JOB_COMPLETE)		||
+		   (agent_ptr->msg_type == SRUN_REQUEST_SUSPEND)	||
 		   (agent_ptr->msg_type == SRUN_STEP_MISSING)		||
 		   (agent_ptr->msg_type == SRUN_STEP_SIGNAL)		||
 		   (agent_ptr->msg_type == SRUN_EXEC)			||
@@ -1626,9 +1628,9 @@ static int _batch_launch_defer(queued_request_t *queued_req_ptr)
 		/* ready to launch, adjust time limit for boot time */
 		if (delay_time && (job_ptr->time_limit != INFINITE) &&
 		    (!wiki2_sched)) {
-			info("Job %u launch delayed by %d secs, "
-			     "updating end_time",
-			     launch_msg_ptr->job_id, delay_time);
+			verbose("Job %u launch delayed by %d secs, "
+				"updating end_time",
+				launch_msg_ptr->job_id, delay_time);
 			job_ptr->end_time += delay_time;
 		}
 		queued_req_ptr->last_attempt = (time_t) 0;
@@ -1644,9 +1646,9 @@ static int _batch_launch_defer(queued_request_t *queued_req_ptr)
 		      "sending batch request anyway...");
 		if (delay_time && (job_ptr->time_limit != INFINITE) &&
 		    (!wiki2_sched)) {
-			info("Job %u launch delayed by %d secs, "
-			     "updating end_time",
-			     launch_msg_ptr->job_id, delay_time);
+			verbose("Job %u launch delayed by %d secs, "
+				"updating end_time",
+				launch_msg_ptr->job_id, delay_time);
 			job_ptr->end_time += delay_time;
 		}
 		queued_req_ptr->last_attempt = (time_t) 0;
