@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -342,8 +342,6 @@ static void _build_parts(void)
 
 	gs_part_list = list_create(_destroy_parts);
 	part_iterator = list_iterator_create(part_list);
-	if (part_iterator == NULL)
-		fatal ("memory allocation failure");
 	while ((p_ptr = (struct part_record *) list_next(part_iterator))) {
 		gs_part_ptr = xmalloc(sizeof(struct gs_part));
 		gs_part_ptr->part_name = xstrdup(p_ptr->name);
@@ -422,8 +420,6 @@ static int _job_fits_in_active_row(struct job_record *job_ptr,
 
 	/* gr_type == GS_NODE || gr_type == GS_CPU */
 	job_map = bit_copy(job_res->node_bitmap);
-	if (!job_map)
-		fatal("gang: memory allocation error");
 	bit_and(job_map, p_ptr->active_resmap);
 	/* any set bits indicate contention for the same resource */
 	count = bit_set_count(job_map);
@@ -705,8 +701,6 @@ static void _cast_shadow(struct gs_job *j_ptr, uint16_t priority)
 	int i;
 
 	part_iterator = list_iterator_create(gs_part_list);
-	if (part_iterator == NULL)
-		fatal("memory allocation failure");
 	while ((p_ptr = (struct gs_part *) list_next(part_iterator))) {
 		if (p_ptr->priority >= priority)
 			continue;
@@ -747,8 +741,6 @@ static void _clear_shadow(struct gs_job *j_ptr)
 	int i;
 
 	part_iterator = list_iterator_create(gs_part_list);
-	if (part_iterator == NULL)
-		fatal("memory allocation failure");
 	while ((p_ptr = (struct gs_part *) list_next(part_iterator))) {
 		if (!p_ptr->shadow)
 			continue;
@@ -881,8 +873,6 @@ static void _update_all_active_rows(void)
 	list_sort(gs_part_list, _sort_partitions);
 
 	part_iterator = list_iterator_create(gs_part_list);
-	if (part_iterator == NULL)
-		fatal("memory allocation failure");
 	while ((p_ptr = (struct gs_part *) list_next(part_iterator)))
 		_update_active_row(p_ptr, 1);
 	list_iterator_destroy(part_iterator);
@@ -1054,8 +1044,6 @@ static void _scan_slurm_job_list(void)
 	if (gs_debug_flags & DEBUG_FLAG_GANG)
 		info("gang: _scan_slurm_job_list: job_list exists...");
 	job_iterator = list_iterator_create(job_list);
-	if (job_iterator == NULL)
-		fatal("list_iterator_create: malloc failure");
 	while ((job_ptr = (struct job_record *) list_next(job_iterator))) {
 		if (gs_debug_flags & DEBUG_FLAG_GANG) {
 			info("gang: _scan_slurm_job_list: checking job %u",
@@ -1368,8 +1356,6 @@ extern int gs_reconfig(void)
 
 	/* scan the old part list and add existing jobs to the new list */
 	part_iterator = list_iterator_create(old_part_list);
-	if (part_iterator == NULL)
-		fatal ("memory allocation failure");
 	while ((p_ptr = (struct gs_part *) list_next(part_iterator))) {
 		newp_ptr = (struct gs_part *) list_find_first(gs_part_list,
 							      _find_gs_part,
@@ -1593,8 +1579,6 @@ static void *_timeslicer_thread(void *arg)
 		if (gs_debug_flags & DEBUG_FLAG_GANG)
 			info("gang: _timeslicer_thread: scanning partitions");
 		part_iterator = list_iterator_create(gs_part_list);
-		if (part_iterator == NULL)
-			fatal("memory allocation failure");
 		while ((p_ptr = (struct gs_part *) list_next(part_iterator))) {
 			if (gs_debug_flags & DEBUG_FLAG_GANG) {
 				info("gang: _timeslicer_thread: part %s: "
