@@ -49,6 +49,7 @@
 #if defined(__FreeBSD__)
 #include <signal.h> /* for SIGKILL */
 #endif
+#include <ctype.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -1393,6 +1394,52 @@ extern void print_job_dependency(struct job_record *job_ptr)
 	list_iterator_destroy(depend_iter);
 }
 
+/*
+ * Remove a dependency from within the job dependency string.
+ */
+static void _rm_dependency(struct job_record *job_ptr,
+			   struct depend_spec *dep_ptr)
+{
+	int rmv_len;
+	char *base_off, *rmv_dep, *rmv_off;
+
+	if (dep_ptr->array_task_id == (uint16_t) INFINITE) {
+		rmv_dep = xstrdup_printf(":%u_*", dep_ptr->job_id);
+	} else if (dep_ptr->array_task_id != (uint16_t) NO_VAL) {
+		rmv_dep = xstrdup_printf(":%u_%u",
+					 dep_ptr->job_id,
+					 dep_ptr->array_task_id);
+	} else {
+		rmv_dep = xstrdup_printf(":%u", dep_ptr->job_id);
+	}
+	rmv_len = strlen(rmv_dep);
+	base_off = job_ptr->details->dependency;
+	while ((rmv_off = strstr(base_off, rmv_dep))) {
+		if (isdigit(rmv_off[rmv_len])) {
+			/* Partial job ID match (e.g. "123" rather than "12") */
+			base_off += rmv_len;
+			continue;
+		}
+		memmove(rmv_off, rmv_off + rmv_len,
+			strlen(rmv_off + rmv_len) + 1);
+		if (rmv_off[0] == ':')
+			continue;
+		if ((rmv_off == job_ptr->details->dependency) ||
+		    ! isalpha(rmv_off[-1]))
+			continue;
+		/* Remove dependency type also (e.g. "afterany"); */
+		for (base_off = rmv_off - 1;
+		     base_off > job_ptr->details->dependency; base_off--) {
+			if (!isalpha(base_off[0])) {
+				base_off++;
+				break;
+			}
+		}
+		memmove(base_off, rmv_off, strlen(rmv_off) + 1);
+	}
+	xfree(rmv_dep);
+}
+
 /*
  * Determine if a job's dependencies are met
  * RET: 0 = no dependencies
@@ -1505,21 +1552,7 @@ extern int test_job_dependency(struct job_record *job_ptr)
 		} else
 			failure = true;
 		if (clear_dep) {
-			char *rmv_dep;
-			if (dep_ptr->array_task_id == (uint16_t) INFINITE) {
-				rmv_dep = xstrdup_printf(":%u_*",
-							 dep_ptr->job_id);
-			} else if (dep_ptr->array_task_id != (uint16_t)NO_VAL) {
-				rmv_dep = xstrdup_printf(":%u_%u",
-							dep_ptr->job_id,
-							dep_ptr->array_task_id);
-			} else {
-				rmv_dep = xstrdup_printf(":%u",
-							 dep_ptr->job_id);
-			}
-			xstrsubstitute(job_ptr->details->dependency,
-				       rmv_dep, "");
-			xfree(rmv_dep);
+			_rm_dependency(job_ptr, dep_ptr);
 			list_delete_item(depend_iter);
 		}
 	}
