@@ -144,17 +144,65 @@ static uint16_t _get_ntasks_per_core(struct job_details *details) {
 }
 
 /*
- * _build_gres_alloc_string - Fill in the gres_alloc string field for a
- *      given job_record
- *	also claim required licenses and resources reserved by accounting
- *	policy association
+ * _get_gres_alloc - Fill in the gres_alloc string field for a given
+ *      job_record with the count of actually alllocated gres on each node
  * IN job_ptr - the job record whose "gres_alloc" field is to be constructed
- * IN valtype - The type of count associated which each allocated GRES type
- *              to retreive and record in the string.
  * RET Error number.  Currently not used (always set to 0).
  */
+static int _get_gres_alloc(struct job_record *job_ptr)
+{
+	char                buf[128], *prefix="";
+	char                gres_name[64];
+	int                 i, rv;
+	int                 node_cnt;
+	int                 gres_type_count;
+	int                 *gres_count_ids, *gres_count_vals;
 
-static int _build_gres_alloc_string(struct job_record *job_ptr, int valtype)
+	xstrcat(job_ptr->gres_alloc, "");
+	if (!job_ptr->node_bitmap || !job_ptr->gres_list)
+		return SLURM_SUCCESS;
+
+	node_cnt = bit_set_count(job_ptr->node_bitmap);
+	gres_type_count = list_count(job_ptr->gres_list);
+	gres_count_ids  = xmalloc(sizeof(int) * gres_type_count);
+	gres_count_vals = xmalloc(sizeof(int) * gres_type_count);
+	rv = gres_plugin_job_count(job_ptr->gres_list, gres_type_count,
+				   gres_count_ids, gres_count_vals);
+	if (rv == SLURM_SUCCESS) {
+		for (i = 0; i < gres_type_count; i++) {
+			if (!gres_count_ids[i])
+				break;
+			gres_count_vals[i] *= node_cnt;
+			/* Map the GRES type id back to a GRES type name. */
+			gres_gresid_to_gresname(gres_count_ids[i], gres_name,
+						sizeof(gres_name));
+			sprintf(buf,"%s%s:%d", prefix, gres_name,
+				gres_count_vals[i]);
+			xstrcat(job_ptr->gres_alloc, buf);
+			if (prefix[0] == '\0')
+				prefix = ",";
+
+			if (slurm_get_debug_flags() & DEBUG_FLAG_GRES) {
+				debug("(%s:%d) job id: %u -- gres_alloc "
+				      "substring=(%s)",
+				      THIS_FILE, __LINE__, job_ptr->job_id, buf);
+			}
+		}
+	}
+	xfree(gres_count_ids);
+	xfree(gres_count_vals);
+
+	return rv;
+}
+
+/*
+ * _get_gres_config - Fill in the gres_alloc string field for a given 
+ *      job_record with the count of gres on each node (e.g. for whole node
+ *	allocations.
+ * IN job_ptr - the job record whose "gres_alloc" field is to be constructed
+ * RET Error number.  Currently not used (always set to 0).
+ */
+static int _get_gres_config(struct job_record *job_ptr)
 {
 	char                buf[128], *prefix="";
 	List                gres_list;
@@ -186,7 +234,7 @@ static int _build_gres_alloc_string(struct job_record *job_ptr, int valtype)
 	gres_count_vals = xmalloc(sizeof(int) * gres_type_count);
 
 	/* Loop through each node allocated to the job tallying all GRES
-	 * types found.*/
+	 * types found. */
 	for (ix = i_first; ix <= i_last; ix++) {
 		if (!bit_test(node_bitmap, ix))
 			continue;
@@ -222,10 +270,10 @@ static int _build_gres_alloc_string(struct job_record *job_ptr, int valtype)
 		}
 
 		if (gres_list) {
-			gres_num_gres_alloced_all(gres_list, count,
-						  gres_count_ids_loc,
-						  gres_count_vals_loc,
-						  valtype);
+			gres_plugin_node_count(gres_list, count,
+					       gres_count_ids_loc,
+					       gres_count_vals_loc,
+					       GRES_VAL_TYPE_CONFIG);
 		}
 
 		/* Combine the local results into the master count results */
@@ -292,6 +340,35 @@ static int _build_gres_alloc_string(struct job_record *job_ptr, int valtype)
 	return rv;
 }
 
+/*
+ * _build_gres_alloc_string - Fill in the gres_alloc string field for a
+ *      given job_record
+ *	also claim required licenses and resources reserved by accounting
+ *	policy association
+ * IN job_ptr - the job record whose "gres_alloc" field is to be constructed
+ * RET Error number.  Currently not used (always set to 0).
+ */
+static int _build_gres_alloc_string(struct job_record *job_ptr)
+{
+	static int          val_type = -1;
+
+	if (val_type == -1) {
+		char *select_type = slurm_get_select_type();
+		/* Find out which select type plugin we have so we can decide
+		 * what value to look for. */
+		if (!strcmp(select_type, "select/cray"))
+			val_type = GRES_VAL_TYPE_CONFIG;
+		else
+			val_type = GRES_VAL_TYPE_ALLOC;
+		xfree(select_type);
+	}
+
+	if (val_type == GRES_VAL_TYPE_CONFIG)
+		return _get_gres_config(job_ptr);
+	else
+		return _get_gres_alloc(job_ptr);
+}
+
 /*
  * allocate_nodes - change state of specified nodes to NODE_STATE_ALLOCATED
  *	also claim required licenses and resources reserved by accounting
@@ -1718,7 +1795,7 @@ static int _fill_in_gres_fields(struct job_record *job_ptr)
 	char *req_config  = job_ptr->gres;
 	char *tmp_str;
 	uint32_t ngres_req;
-	int      valtype, rv = 0;
+	int      rv = SLURM_SUCCESS;
 
 	/* First build the GRES requested field. */
 	if ((req_config == NULL) || (req_config[0] == '\0')) {
@@ -1777,18 +1854,8 @@ static int _fill_in_gres_fields(struct job_record *job_ptr)
 	}
 
 	if ( !job_ptr->gres_alloc || (job_ptr->gres_alloc[0] == '\0') ) {
-		char *select_type = slurm_get_select_type();
-
-		/* Find out which select type plugin we have so we can decide
-		 * what value to look for. */
-		if (!strcmp(select_type, "select/cray"))
-			valtype = GRES_VAL_TYPE_CONFIG;
-		else
-			valtype = GRES_VAL_TYPE_ALLOC;
-		xfree(select_type);
-
 		/* Now build the GRES allocated field. */
-		rv = _build_gres_alloc_string(job_ptr, valtype);
+		rv = _build_gres_alloc_string(job_ptr);
 		if (slurm_get_debug_flags() & DEBUG_FLAG_GRES) {
 			debug("(%s:%d) job id: %u -- job_record->gres: (%s), "
 			      "job_record->gres_alloc: (%s)",
