@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -49,6 +49,7 @@
 #include <string.h>
 
 #include "src/common/hostlist.h"
+#include "src/common/node_select.h"
 #include "src/common/read_config.h"
 #include "src/slurmctld/agent.h"
 #include "src/slurmctld/front_end.h"
@@ -194,8 +195,10 @@ void ping_nodes (void)
 			else {
 				down_hostlist =
 					hostlist_create(front_end_ptr->name);
-				if (down_hostlist == NULL)
-					fatal("hostlist_create: malloc error");
+				if (!down_hostlist) {
+					fatal("invalid front_end list: %s",
+					      front_end_ptr->name);
+				}
 			}
 			set_front_end_down(front_end_ptr, "Not responding");
 			front_end_ptr->not_responding = false;
@@ -254,8 +257,10 @@ void ping_nodes (void)
 			else {
 				down_hostlist =
 					hostlist_create(node_ptr->name);
-				if (down_hostlist == NULL)
-					fatal("hostlist_create: malloc error");
+				if (!down_hostlist) {
+					fatal("Invalid host name: %s",
+					      node_ptr->name);
+				}
 			}
 			set_node_down_ptr(node_ptr, "Not responding");
 			node_ptr->not_responding = false;  /* logged below */
@@ -342,6 +347,7 @@ extern void run_health_check(void)
 	front_end_record_t *front_end_ptr;
 #else
 	struct node_record *node_ptr;
+	int node_states = slurmctld_conf.health_check_node_state;
 #endif
 	int i;
 	char *host_str = NULL;
@@ -351,9 +357,6 @@ extern void run_health_check(void)
 	check_agent_args->msg_type = REQUEST_HEALTH_CHECK;
 	check_agent_args->retry = 0;
 	check_agent_args->hostlist = hostlist_create("");
-	if (check_agent_args->hostlist == NULL)
-		fatal("hostlist_create: malloc failure");
-
 #ifdef HAVE_FRONT_END
 	for (i = 0, front_end_ptr = front_end_nodes;
 	     i < front_end_node_cnt; i++, front_end_ptr++) {
@@ -363,11 +366,43 @@ extern void run_health_check(void)
 		check_agent_args->node_count++;
 	}
 #else
+	if ((node_states != HEALTH_CHECK_NODE_ANY) &&
+	    (node_states != HEALTH_CHECK_NODE_IDLE)) {
+		/* Update each node's alloc_cpus count */
+		select_g_select_nodeinfo_set_all();
+	}
+
 	for (i=0, node_ptr=node_record_table_ptr;
 	     i<node_record_count; i++, node_ptr++) {
 		if (IS_NODE_NO_RESPOND(node_ptr) || IS_NODE_FUTURE(node_ptr) ||
 		    IS_NODE_POWER_SAVE(node_ptr))
 			continue;
+		if (node_states != HEALTH_CHECK_NODE_ANY) {
+			uint16_t cpus_total, cpus_used = 0;
+			if (slurmctld_conf.fast_schedule) {
+				cpus_total = node_ptr->config_ptr->cpus;
+			} else {
+				cpus_total = node_ptr->cpus;
+			}
+			if (!IS_NODE_IDLE(node_ptr)) {
+				select_g_select_nodeinfo_get(
+						node_ptr->select_nodeinfo,
+						SELECT_NODEDATA_SUBCNT,
+						NODE_STATE_ALLOCATED,
+						&cpus_used);
+			}
+			if (cpus_used == 0) {
+				if (!(node_states & HEALTH_CHECK_NODE_IDLE))
+					continue;
+			} else if (cpus_used < cpus_total) {
+				if (!(node_states & HEALTH_CHECK_NODE_MIXED))
+					continue;
+			} else {
+				if (!(node_states & HEALTH_CHECK_NODE_ALLOC))
+					continue;
+			}
+		}
+
 		hostlist_push(check_agent_args->hostlist, node_ptr->name);
 		check_agent_args->node_count++;
 	}
@@ -403,8 +438,6 @@ extern void update_nodes_acct_gather_data(void)
 	agent_args->msg_type = REQUEST_ACCT_GATHER_UPDATE;
 	agent_args->retry = 0;
 	agent_args->hostlist = hostlist_create("");
-	if (agent_args->hostlist == NULL)
-		fatal("hostlist_create: malloc failure");
 
 #ifdef HAVE_FRONT_END
 	for (i = 0, front_end_ptr = front_end_nodes;
