@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -172,6 +172,8 @@ extern void srun_node_fail (uint32_t job_id, char *node_name)
 
 	step_iterator = list_iterator_create(job_ptr->step_list);
 	while ((step_ptr = (struct step_record *) list_next(step_iterator))) {
+		if (step_ptr->step_node_bitmap == NULL)   /* pending step */
+			continue;
 		if ((bit_position >= 0) &&
 		    (!bit_test(step_ptr->step_node_bitmap, bit_position)))
 			continue;	/* job step not on this node */
@@ -331,16 +333,18 @@ extern int srun_user_message(struct job_record *job_ptr, char *msg)
 			return ESLURM_DISABLED;	/* no allocated nodes */
 		agent_arg_ptr = (agent_arg_t *) xmalloc(sizeof(agent_arg_t));
 		agent_arg_ptr->hostlist = hostlist_create(job_ptr->batch_host);
+		if (!agent_arg_ptr->hostlist)
+			fatal("Invalid srun host: %s", job_ptr->batch_host);
 #else
 		node_ptr = find_first_node_record(job_ptr->node_bitmap);
 		if (node_ptr == NULL)
 			return ESLURM_DISABLED;	/* no allocated nodes */
 		agent_arg_ptr = (agent_arg_t *) xmalloc(sizeof(agent_arg_t));
 		agent_arg_ptr->hostlist = hostlist_create(node_ptr->name);
+		if (!agent_arg_ptr->hostlist)
+			fatal("Invalid srun host: %s", node_ptr->name);
 #endif
-		if (agent_arg_ptr->hostlist == NULL)
-			fatal("hostlist_create: malloc failure");
-		notify_msg_ptr = (job_notify_msg_t *) 
+		notify_msg_ptr = (job_notify_msg_t *)
 				 xmalloc(sizeof(job_notify_msg_t));
 		notify_msg_ptr->job_id = job_ptr->job_id;
 		notify_msg_ptr->message = xstrdup(msg);
@@ -532,4 +536,3 @@ extern void srun_response(uint32_t job_id, uint32_t step_id)
 		return;
 	job_ptr->time_last_active = now;
 }
-
