@@ -7,7 +7,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -183,8 +183,6 @@ static List _script_list_create (const char *pattern)
 	switch (rc) {
 	case 0:
 		l = list_create ((ListDelF) _xfree_f);
-		if (l == NULL)
-			fatal("run_script: list_create: Out of memory");
 		for (i = 0; i < gl.gl_pathc; i++)
 			list_push (l, xstrdup (gl.gl_pathv[i]));
 		break;
@@ -222,9 +220,6 @@ int run_script(const char *name, const char *pattern, uint32_t jobid,
 		return error ("Unable to run %s [%s]", name, pattern);
 
 	i = list_iterator_create (l);
-	if (i == NULL)
-		fatal ("run_script: list_iterator_create: Out of memory");
-
 	while ((s = list_next (i))) {
 		rc = run_one_script (name, s, jobid, max_wait, env);
 		if (rc) {
