@@ -9,7 +9,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *  
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *  
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -85,6 +85,7 @@
 #  endif
 #endif
 
+#include <errno.h>
 #if defined(__NetBSD__)
 #include <stdlib.h>
 #include <string.h>
@@ -153,6 +154,7 @@ static const size_t ps_buffer_size = sizeof(ps_buffer);
 #else
 static char *ps_buffer;			/* will point to argv area */
 static size_t ps_buffer_size;		/* space determined at run time */
+static char **new_environ = (char **) NULL;
 #endif
 
 /* save the original argv[] location here */
@@ -260,7 +262,6 @@ init_setproctitle(int argc, char *argv[])
 {
 #if SETPROCTITLE_STRATEGY == PS_USE_CLOBBER_ARGV
 	char *end_of_area = NULL;
-	char **new_environ;
 	int i;
 #endif
 
@@ -309,12 +310,15 @@ init_setproctitle(int argc, char *argv[])
 	 * Duplicate and move the environment out of the way
 	 */
 	new_environ = malloc(sizeof(char *) * (i + 1));
+	if (!new_environ) {
+		fprintf(stderr, "ERROR: [%s:%d] %s: %s\n",
+			__FILE__, __LINE__, "init_setproctitle",
+			strerror(errno));
+		abort();
+	}
 	for (i = 0; environ[i] != NULL; i++) {
 		new_environ[i] = strdup(environ[i]);
-		//free(environ[i]);
 	}
-	/* if(environ) */
-/* 		free(environ); */
 	new_environ[i] = NULL;
 	environ = new_environ;
 #endif /* PS_USE_CLOBBER_ARGV */
@@ -327,11 +331,15 @@ void fini_setproctitle(void)
 #if SETPROCTITLE_STRATEGY == PS_USE_CLOBBER_ARGV
 	int i;
 
-	for (i = 0; environ[i] != NULL; i++) {
-		free(environ[i]);
+	if (!new_environ)
+		return;
+
+	for (i = 0; new_environ[i] != NULL; i++) {
+		free(new_environ[i]);
 	}
-	free(environ);
-	environ = (char **) NULL;
+	free(new_environ);
+	new_environ = (char **) NULL;
+	environ = new_environ;
 #endif /* PS_USE_CLOBBER_ARGV */
 }
 
