@@ -10,7 +10,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -169,7 +169,7 @@ static void      _term_handler(int);
 static void      _update_logging(void);
 static void      _update_nice(void);
 static void      _usage(void);
-static void      _wait_for_all_threads(void);
+static void      _wait_for_all_threads(int secs);
 
 
 int
@@ -293,6 +293,8 @@ main (int argc, char *argv[])
 	if (!conf->cleanstart && (_restore_cred_state(conf->vctx) < 0))
 		return SLURM_FAILURE;
 
+	if (jobacct_gather_init() != SLURM_SUCCESS)
+		fatal("Unable to initialize jobacct_gather");
 	if (interconnect_node_init() < 0)
 		fatal("Unable to initialize interconnect.");
 	if (conf->cleanstart && switch_g_clear_node_state())
@@ -306,11 +308,9 @@ main (int argc, char *argv[])
 	   so we keep the write lock of the pidfile.
 	*/
 	pidfd = create_pidfile(conf->pidfile, 0);
-	if (pidfd >= 0)
-		fd_set_close_on_exec(pidfd);
 
 	rfc2822_timestamp(time_stamp, sizeof(time_stamp));
-	info("%s started on %s", xbasename(argv[0]), time_stamp);
+	info("%s started on %s", slurm_prog_name, time_stamp);
 
 	_install_fork_handlers();
 	list_install_fork_handlers();
@@ -328,10 +328,7 @@ main (int argc, char *argv[])
 	if (unlink(conf->pidfile) < 0)
 		error("Unable to remove pidfile `%s': %m", conf->pidfile);
 
-	_wait_for_all_threads();
-
-	interconnect_node_fini();
-
+	_wait_for_all_threads(120);
 	_slurmd_fini();
 	_destroy_conf();
 	slurm_crypto_fini();	/* must be after _destroy_conf() */
@@ -403,6 +400,7 @@ _msg_engine(void)
 	while (!_shutdown) {
 		if (_reconfig) {
 			verbose("got reconfigure request");
+			_wait_for_all_threads(5); /* Wait for RPCs to finish */
 			_reconfigure();
 		}
 
@@ -452,15 +450,16 @@ _increment_thd_count(void)
 	slurm_mutex_unlock(&active_mutex);
 }
 
+/* secs IN - wait up to this number of seconds for all threads to complete */
 static void
-_wait_for_all_threads(void)
+_wait_for_all_threads(int secs)
 {
 	struct timespec ts;
 	int rc;
 
 	ts.tv_sec  = time(NULL);
 	ts.tv_nsec = 0;
-	ts.tv_sec += 120;       /* 2 minutes allowed for shutdown */
+	ts.tv_sec += secs;
 
 	slurm_mutex_lock(&active_mutex);
 	while (active_threads > 0) {
@@ -530,7 +529,7 @@ _service_connection(void *arg)
 
 	debug3("in the service_connection");
 	slurm_msg_t_init(msg);
-	if((rc = slurm_receive_msg_and_forward(con->fd, con->cli_addr, msg, 0))
+	if ((rc = slurm_receive_msg_and_forward(con->fd, con->cli_addr, msg, 0))
 	   != SLURM_SUCCESS) {
 		error("service_connection: slurm_receive_msg: %m");
 		/* if this fails we need to make sure the nodes we forward
@@ -619,13 +618,13 @@ _fill_registration_msg(slurm_node_registration_status_msg_t *msg)
 
 	if (first_msg) {
 		first_msg = false;
-		info("Procs=%u Boards=%u Sockets=%u Cores=%u Threads=%u "
+		info("CPUs=%u Boards=%u Sockets=%u Cores=%u Threads=%u "
 		     "Memory=%u TmpDisk=%u Uptime=%u",
 		     msg->cpus, msg->boards, msg->sockets, msg->cores,
 		     msg->threads, msg->real_memory, msg->tmp_disk,
 		     msg->up_time);
 	} else {
-		debug3("Procs=%u Boards=%u Sockets=%u Cores=%u Threads=%u "
+		debug3("CPUs=%u Boards=%u Sockets=%u Cores=%u Threads=%u "
 		       "Memory=%u TmpDisk=%u Uptime=%u",
 		       msg->cpus, msg->boards, msg->sockets, msg->cores,
 		       msg->threads, msg->real_memory, msg->tmp_disk,
@@ -671,6 +670,7 @@ _fill_registration_msg(slurm_node_registration_status_msg_t *msg)
 			close(fd);
 			continue;
 		}
+
 		close(fd);
 		if (stepd->stepid == NO_VAL)
 			debug("found apparently running job %u", stepd->jobid);
@@ -724,6 +724,8 @@ _read_config(void)
 {
 	char *path_pubkey = NULL;
 	slurm_ctl_conf_t *cf = NULL;
+	uint16_t tmp16 = 0;
+
 #ifndef HAVE_FRONT_END
 	bool cr_flag = false, gang_flag = false;
 #endif
@@ -786,8 +788,6 @@ _read_config(void)
 	xfree(conf->block_map);
 	xfree(conf->block_map_inv);
 
-	conf->block_map_size = 0;
-
 	_update_logging();
 	_update_nice();
 
@@ -840,7 +840,7 @@ _read_config(void)
 		if (cf->fast_schedule) {
 			info("Node configuration differs from hardware: "
 			     "CPUs=%u:%u(hw) Boards=%u:%u(hw) "
-			     "Sockets=%u:%u(hw) CoresPerSocket=%u:%u(hw) "
+			     "SocketsPerBoard=%u:%u(hw) CoresPerSocket=%u:%u(hw) "
 			     "ThreadsPerCore=%u:%u(hw)",
 			     conf->cpus,    conf->actual_cpus,
 			     conf->boards,  conf->actual_boards,
@@ -855,7 +855,7 @@ _read_config(void)
 			      "the bitmaps the slurmctld must create before "
 			      "the slurmd registers.\n"
 			      "   CPUs=%u:%u(hw) Boards=%u:%u(hw) "
-			      "Sockets=%u:%u(hw) CoresPerSocket=%u:%u(hw) "
+			      "SocketsPerBoard=%u:%u(hw) CoresPerSocket=%u:%u(hw) "
 			      "ThreadsPerCore=%u:%u(hw)",
 			      conf->cpus,    conf->actual_cpus,
 			      conf->boards,  conf->actual_boards,
@@ -887,10 +887,24 @@ _read_config(void)
 
 	conf->debug_flags = cf->debug_flags;
 	conf->propagate_prio = cf->propagate_prio_process;
-	conf->job_acct_gather_freq = cf->job_acct_gather_freq;
+
+	_free_and_set(&conf->job_acct_gather_freq,
+		      xstrdup(cf->job_acct_gather_freq));
+
+	conf->acct_freq_task = (uint16_t)NO_VAL;
+	tmp16 = acct_gather_parse_freq(PROFILE_TASK,
+				       conf->job_acct_gather_freq);
+	if (tmp16 != -1)
+		conf->acct_freq_task = tmp16;
 
 	_free_and_set(&conf->acct_gather_energy_type,
 		      xstrdup(cf->acct_gather_energy_type));
+	_free_and_set(&conf->acct_gather_filesystem_type,
+		      xstrdup(cf->acct_gather_filesystem_type));
+	_free_and_set(&conf->acct_gather_infiniband_type,
+		      xstrdup(cf->acct_gather_infiniband_type));
+	_free_and_set(&conf->acct_gather_profile_type,
+		      xstrdup(cf->acct_gather_profile_type));
 	_free_and_set(&conf->job_acct_gather_type,
 		      xstrdup(cf->job_acct_gather_type));
 
@@ -964,7 +978,7 @@ _reconfigure(void)
 				   stepd->jobid, stepd->stepid);
 		if (fd == -1)
 			continue;
-		if(stepd_reconfig(fd) != SLURM_SUCCESS)
+		if (stepd_reconfig(fd) != SLURM_SUCCESS)
 			debug("Reconfig jobid=%u.%u failed: %m",
 			      stepd->jobid, stepd->stepid);
 		close(fd);
@@ -1106,12 +1120,16 @@ _destroy_conf(void)
 {
 	if (conf) {
 		xfree(conf->acct_gather_energy_type);
+		xfree(conf->acct_gather_filesystem_type);
+		xfree(conf->acct_gather_infiniband_type);
+		xfree(conf->acct_gather_profile_type);
 		xfree(conf->block_map);
 		xfree(conf->block_map_inv);
 		xfree(conf->conffile);
 		xfree(conf->epilog);
 		xfree(conf->health_check_program);
 		xfree(conf->hostname);
+		xfree(conf->job_acct_gather_freq);
 		xfree(conf->job_acct_gather_type);
 		xfree(conf->logfile);
 		xfree(conf->node_name);
@@ -1156,7 +1174,7 @@ _print_config(void)
 	            &conf->actual_threads,
 	            &conf->block_map_size,
 	            &conf->block_map, &conf->block_map_inv);
-	printf("CPUs=%u Boards=%u Sockets=%u CoresPerSocket=%u "
+	printf("CPUs=%u Boards=%u SocketsPerBoard=%u CoresPerSocket=%u "
 	       "ThreadsPerCore=%u ",
 	       conf->actual_cpus, conf->actual_boards, conf->actual_sockets,
 	       conf->actual_cores, conf->actual_threads);
@@ -1223,6 +1241,7 @@ _process_cmdline(int ac, char **av)
 			break;
 		case 'v':
 			conf->debug_level++;
+			conf->debug_level_set = 1;
 			break;
 		case 'V':
 			print_slurm_version();
@@ -1369,8 +1388,7 @@ _slurmd_init(void)
 	cpu_freq_init(conf);
 
 	_print_conf();
-	if (jobacct_gather_init() != SLURM_SUCCESS)
-		return SLURM_FAILURE;
+
 	if (slurm_proctrack_init() != SLURM_SUCCESS)
 		return SLURM_FAILURE;
 	if (slurmd_task_init() != SLURM_SUCCESS)
@@ -1476,11 +1494,10 @@ _slurmd_init(void)
 		init_gids_cache(0);
 	slurm_conf_unlock();
 
-	if ((devnull = open("/dev/null", O_RDWR)) < 0) {
+	if ((devnull = open_cloexec("/dev/null", O_RDWR)) < 0) {
 		error("Unable to open /dev/null: %m");
 		return SLURM_FAILURE;
 	}
-	fd_set_close_on_exec(devnull);
 
 	/* make sure we have slurmstepd installed */
 	if (stat(conf->stepd_loc, &stat_buf))
@@ -1544,6 +1561,7 @@ cleanup:
 static int
 _slurmd_fini(void)
 {
+	interconnect_node_fini();
 	save_cred_state(conf->vctx);
 	switch_fini();
 	slurmd_task_fini();
@@ -1556,10 +1574,9 @@ _slurmd_fini(void)
 	slurmd_req(NULL);	/* purge memory allocated by slurmd_req() */
 	fini_setproctitle();
 	slurm_select_fini();
-	jobacct_gather_fini();
-	acct_gather_energy_fini();
 	spank_slurmd_exit();
 	cpu_freq_fini();
+	acct_gather_conf_destroy();
 
 	return SLURM_SUCCESS;
 }
@@ -1603,11 +1620,11 @@ int save_cred_state(slurm_cred_ctx_t ctx)
 		goto cleanup;
 	}
 	(void) unlink(old_file);
-	if(link(reg_file, old_file))
+	if (link(reg_file, old_file))
 		debug4("unable to create link for %s -> %s: %m",
 		       reg_file, old_file);
 	(void) unlink(reg_file);
-	if(link(new_file, reg_file))
+	if (link(new_file, reg_file))
 		debug4("unable to create link for %s -> %s: %m",
 		       new_file, reg_file);
 	(void) unlink(new_file);
@@ -1741,12 +1758,9 @@ static void _update_logging(void)
 	log_options_t *o = &conf->log_opts;
 	slurm_ctl_conf_t *cf;
 
-	/*
-	 * Initialize debug level if not already set
-	 */
+	/* Preserve execute line verbose arguments (if any) */
 	cf = slurm_conf_lock();
-	if ( (conf->debug_level == LOG_LEVEL_INFO)
-	     && (cf->slurmd_debug != (uint16_t) NO_VAL) )
+	if (!conf->debug_level_set && (cf->slurmd_debug != (uint16_t) NO_VAL))
 		conf->debug_level = cf->slurmd_debug;
 	slurm_conf_unlock();
 
