@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -79,7 +79,6 @@ static List  _build_step_list( char* str );
 static List  _build_user_list( char* str );
 static char *_get_prefix(char *token);
 static void  _help( void );
-static int   _max_cpus_per_node(void);
 static int   _parse_state( char* str, uint16_t* states );
 static void  _parse_token( char *token, char *field, int *field_size,
 			   bool *right_justify, char **suffix);
@@ -99,6 +98,7 @@ parse_command_line( int argc, char* argv[] )
 	static struct option long_options[] = {
 		{"accounts",   required_argument, 0, 'A'},
 		{"all",        no_argument,       0, 'a'},
+		{"array",      no_argument,       0, 'r'},
 		{"format",     required_argument, 0, 'o'},
 		{"help",       no_argument,       0, OPT_LONG_HELP},
 		{"hide",       no_argument,       0, OPT_LONG_HIDE},
@@ -129,6 +129,8 @@ parse_command_line( int argc, char* argv[] )
 
 	if (getenv("SQUEUE_ALL"))
 		params.all_flag = true;
+	if (getenv("SQUEUE_ARRAY"))
+		params.array_flag = true;
 	if ( ( env_val = getenv("SQUEUE_SORT") ) )
 		params.sort = xstrdup(env_val);
 	if ( ( env_val = getenv("SLURM_CLUSTERS") ) ) {
@@ -140,7 +142,7 @@ parse_command_line( int argc, char* argv[] )
 	}
 
 	while ((opt_char = getopt_long(argc, argv,
-				       "A:ahi:j::ln:M:o:p:q:R:s::S:t:u:U:vVw:",
+				       "A:ahi:j::ln:M:o:p:q:R:rs::S:t:u:U:vVw:",
 				       long_options, &option_index)) != -1) {
 		switch (opt_char) {
 		case (int)'?':
@@ -217,6 +219,9 @@ parse_command_line( int argc, char* argv[] )
 			xfree(params.reservation);
 			params.reservation = xstrdup(optarg);
 			break;
+		case (int)'r':
+			params.array_flag = true;
+			break;
 		case (int) 's':
 			if (optarg) {
 				params.steps = xstrdup(optarg);
@@ -309,8 +314,6 @@ parse_command_line( int argc, char* argv[] )
 		char *name1 = NULL;
 		char *name2 = NULL;
 		hostset_t nodenames = hostset_create(NULL);
-		if (nodenames == NULL)
-			fatal("malloc failure");
 
 		while ( hostset_count(params.nodes) > 0 ) {
 			name1 = hostset_pop(params.nodes);
@@ -377,7 +380,7 @@ parse_command_line( int argc, char* argv[] )
 	if ( params.start_flag && !params.step_flag ) {
 		/* Set more defaults */
 		if (params.format == NULL)
-			params.format = xstrdup("%.7i %.9P %.8j %.8u  %.2t  %.19S %.6D %R");
+			params.format = xstrdup("%.7i %.9P %.8j %.8u %.2t %.19S %.6D %R");
 		if (params.sort == NULL)
 			params.sort = xstrdup("S");
 		if (params.states == NULL) {
@@ -386,32 +389,29 @@ parse_command_line( int argc, char* argv[] )
 		}
 	}
 
-	params.max_cpus = _max_cpus_per_node();
+	if (params.job_list && (list_count(params.job_list) == 1)) {
+		ListIterator iterator;
+		uint32_t *job_id_ptr;
+		iterator = list_iterator_create(params.job_list);
+		job_id_ptr = list_next(iterator);
+		params.job_id = *job_id_ptr;
+		list_iterator_destroy(iterator);
+	}
+	if (params.user_list && (list_count(params.user_list) == 1)) {
+		ListIterator iterator;
+		uint32_t *uid_ptr;
+		iterator = list_iterator_create(params.user_list);
+		while ((uid_ptr = list_next(iterator))) {
+			params.user_id = *uid_ptr;
+			break;
+		}
+		list_iterator_destroy(iterator);
+	}
 
 	if ( params.verbose )
 		_print_options();
 }
 
-/* Return the maximum number of processors for any node in the cluster */
-static int   _max_cpus_per_node(void)
-{
-	int error_code, max_cpus = 1;
-	node_info_msg_t *node_info_ptr = NULL;
-
-	error_code = slurm_load_node ((time_t) NULL, &node_info_ptr,
-				      params.all_flag);
-	if (error_code == SLURM_SUCCESS) {
-		int i;
-		node_info_t *node_ptr = node_info_ptr->node_array;
-		for (i=0; i<node_info_ptr->record_count; i++) {
-			max_cpus = MAX(max_cpus, node_ptr[i].cpus);
-		}
-		slurm_free_node_info_msg (node_info_ptr);
-	}
-
-	return max_cpus;
-}
-
 /*
  * _parse_state - convert job state name string to numeric value
  * IN str - state name
@@ -557,6 +557,11 @@ extern int parse_format( char* format )
 							field_size,
 							right_justify,
 							suffix  );
+			else if (field[0] == 'A')
+				job_format_add_job_id2(params.format_list,
+						       field_size,
+						       right_justify,
+						       suffix);
 			else if (field[0] == 'b')
 				job_format_add_gres( params.format_list,
 						     field_size, right_justify,
@@ -602,6 +607,12 @@ extern int parse_format( char* format )
 							 field_size,
 							 right_justify,
 							 suffix );
+			else if (field[0] == 'F')
+				job_format_add_array_job_id(
+							params.format_list,
+							field_size,
+							right_justify,
+							suffix );
 			else if (field[0] == 'g')
 				job_format_add_group_name( params.format_list,
 							   field_size,
@@ -645,6 +656,12 @@ extern int parse_format( char* format )
 							field_size,
 							right_justify,
 							suffix );
+			else if (field[0] == 'K')
+				job_format_add_array_task_id(
+							params.format_list,
+							field_size,
+							right_justify,
+							suffix );
 			else if (field[0] == 'l')
 				job_format_add_time_limit( params.format_list,
 							   field_size,
@@ -852,7 +869,6 @@ _print_options(void)
 	uint32_t *user;
 	enum job_states *state_id;
 	squeue_job_step_t *job_step_id;
-	uint32_t *job_id;
 	char hostlist[8192];
 
 	if (params.nodes) {
@@ -863,11 +879,11 @@ _print_options(void)
 
 	printf( "-----------------------------\n" );
 	printf( "all         = %s\n", params.all_flag ? "true" : "false");
+	printf( "array       = %s\n", params.array_flag ? "true" : "false");
 	printf( "format      = %s\n", params.format );
 	printf( "iterate     = %d\n", params.iterate );
 	printf( "job_flag    = %d\n", params.job_flag );
 	printf( "jobs        = %s\n", params.jobs );
-	printf( "max_cpus    = %d\n", params.max_cpus ) ;
 	printf( "names       = %s\n", params.names );
 	printf( "nodes       = %s\n", hostlist ) ;
 	printf( "partitions  = %s\n", params.partitions ) ;
@@ -883,8 +899,15 @@ _print_options(void)
 	if ((params.verbose > 1) && params.job_list) {
 		i = 0;
 		iterator = list_iterator_create( params.job_list );
-		while ( (job_id = list_next( iterator )) ) {
-			printf( "job_list[%d] = %u\n", i++, *job_id);
+		while ( (job_step_id = list_next( iterator )) ) {
+			if (job_step_id->array_id == (uint16_t) NO_VAL) {
+				printf( "job_list[%d] = %u\n", i++,
+					job_step_id->job_id );
+			} else {
+				printf( "job_list[%d] = %u_%u\n", i++,
+					job_step_id->job_id,
+					job_step_id->array_id );
+			}
 		}
 		list_iterator_destroy( iterator );
 	}
@@ -922,8 +945,16 @@ _print_options(void)
 		i = 0;
 		iterator = list_iterator_create( params.step_list );
 		while ( (job_step_id = list_next( iterator )) ) {
-			printf( "step_list[%d] = %u.%u\n", i++,
-				job_step_id->job_id, job_step_id->step_id );
+			if (job_step_id->array_id == (uint16_t) NO_VAL) {
+				printf( "step_list[%d] = %u.%u\n", i++,
+					job_step_id->job_id,
+					job_step_id->step_id );
+			} else {
+				printf( "step_list[%d] = %u_%u.%u\n", i++,
+					job_step_id->job_id,
+					job_step_id->array_id,
+					job_step_id->step_id );
+			}
 		}
 		list_iterator_destroy( iterator );
 	}
@@ -950,9 +981,10 @@ static List
 _build_job_list( char* str )
 {
 	List my_list;
-	char *job = NULL, *tmp_char = NULL, *my_job_list = NULL;
-	int i;
-	uint32_t *job_id = NULL;
+	char *end_ptr = NULL, *job = NULL, *tmp_char = NULL;
+	char *my_job_list = NULL;
+	int job_id, array_id;
+	squeue_job_step_t *job_step_id;
 
 	if ( str == NULL )
 		return NULL;
@@ -960,14 +992,20 @@ _build_job_list( char* str )
 	my_job_list = xstrdup( str );
 	job = strtok_r( my_job_list, ",", &tmp_char );
 	while (job) {
-		i = strtol( job, (char **) NULL, 10 );
-		if (i <= 0) {
+		job_id = strtol( job, &end_ptr, 10 );
+		if (end_ptr[0] == '_')
+			array_id = strtol( end_ptr + 1, &end_ptr, 10 );
+		else
+			array_id = (uint16_t) NO_VAL;
+		if (job_id <= 0) {
 			error( "Invalid job id: %s", job );
 			exit( 1 );
 		}
-		job_id = xmalloc( sizeof( uint32_t ) );
-		*job_id = (uint32_t) i;
-		list_append( my_list, job_id );
+
+		job_step_id = xmalloc( sizeof( squeue_job_step_t ) );
+		job_step_id->job_id   = (uint32_t) job_id;
+		job_step_id->array_id = (uint16_t) array_id;
+		list_append( my_list, job_step_id );
 		job = strtok_r (NULL, ",", &tmp_char);
 	}
 	return my_list;
@@ -1060,16 +1098,16 @@ _build_all_states_list( void )
 
 /*
  * _build_step_list- build a list of job/step_ids
- * IN str - comma separated list of job_id.step_ids
+ * IN str - comma separated list of job_id[array_id].step_id values
  * RET List of job/step_ids (structure of uint32_t's)
  */
 static List
 _build_step_list( char* str )
 {
 	List my_list;
-	char *step = NULL, *tmp_char = NULL, *tmps_char = NULL;
+	char *end_ptr = NULL, *step = NULL, *tmp_char = NULL, *tmps_char = NULL;
 	char *job_name = NULL, *step_name = NULL, *my_step_list = NULL;
-	int i, j;
+	int job_id, array_id, step_id;
 	squeue_job_step_t *job_step_id = NULL;
 
 	if ( str == NULL)
@@ -1077,25 +1115,29 @@ _build_step_list( char* str )
 	my_list = list_create( NULL );
 	my_step_list = xstrdup( str );
 	step = strtok_r( my_step_list, ",", &tmp_char );
-	while (step)
-	{
+	while (step) {
 		job_name = strtok_r( step, ".", &tmps_char );
 		step_name = strtok_r( NULL, ".", &tmps_char );
-		i = strtol( job_name, (char **) NULL, 10 );
+		job_id = strtol( job_name, &end_ptr, 10 );
+		if (end_ptr[0] == '_')
+			array_id = strtol( end_ptr + 1, &end_ptr, 10 );
+		else
+			array_id = (uint16_t) NO_VAL;
 		if (step_name == NULL) {
 			error ( "Invalid job_step id: %s.??",
 				 job_name );
 			exit( 1 );
 		}
-		j = strtol( step_name, (char **) NULL, 10 );
-		if ((i <= 0) || (j < 0)) {
+		step_id = strtol( step_name, &end_ptr, 10 );
+		if ((job_id <= 0) || (step_id < 0)) {
 			error( "Invalid job_step id: %s.%s",
 				job_name, step_name );
 			exit( 1 );
 		}
 		job_step_id = xmalloc( sizeof( squeue_job_step_t ) );
-		job_step_id->job_id  = (uint32_t) i;
-		job_step_id->step_id = (uint32_t) j;
+		job_step_id->job_id   = (uint32_t) job_id;
+		job_step_id->array_id = (uint16_t) array_id;
+		job_step_id->step_id  = (uint32_t) step_id;
 		list_append( my_list, job_step_id );
 		step = strtok_r( NULL, ",", &tmp_char);
 	}
