@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -80,11 +80,16 @@ int print_step_from_format(job_step_info_t * job_step, List list);
 int job_format_add_function(List list, int width, bool right_justify,
 			    char *suffix,
 			    int (*function) (job_info_t *, int, bool, char*));
-
+#define job_format_add_array_job_id(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_array_job_id)
+#define job_format_add_array_task_id(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_array_task_id)
 #define job_format_add_batch_host(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_batch_host)
 #define job_format_add_job_id(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_job_id)
+#define job_format_add_job_id2(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_job_id2)
 #define job_format_add_partition(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_partition)
 #define job_format_add_prefix(list,wid,right,prefix) \
@@ -184,10 +189,16 @@ int job_format_add_function(List list, int width, bool right_justify,
 /*****************************************************************************
  * Job Line Print Functions
  *****************************************************************************/
+int _print_job_array_job_id(job_info_t * job, int width, bool right_justify,
+			    char* suffix);
+int _print_job_array_task_id(job_info_t * job, int width, bool right_justify,
+			     char* suffix);
 int _print_job_batch_host(job_info_t * job, int width, bool right_justify,
 			char* suffix);
 int _print_job_job_id(job_info_t * job, int width, bool right_justify,
 			char* suffix);
+int _print_job_job_id2(job_info_t * job, int width, bool right_justify,
+			char* suffix);
 int _print_job_prefix(job_info_t * job, int width, bool right_justify,
 			char* suffix);
 int _print_job_reason(job_info_t * job, int width, bool right_justify,
