@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -70,21 +70,21 @@
 #include "src/common/slurmdb_defs.h"
 #include "src/squeue/print.h"
 
-struct job_step {
+typedef struct job_step {
 	uint32_t job_id;
+	uint16_t array_id;
 	uint32_t step_id;
-};
-typedef struct job_step squeue_job_step_t;
+} squeue_job_step_t;
 
 struct squeue_parameters {
 	bool all_flag;
+	bool array_flag;
 	bool job_flag;
 	bool start_flag;
 	bool step_flag;
 	bool long_list;
 	bool no_header;
 	int  iterate;
-	int  max_cpus;
 	int  verbose;
 
 	char* accounts;
@@ -102,6 +102,9 @@ struct squeue_parameters {
 	char* steps;
 	char* users;
 
+	uint32_t job_id;	/* set if request for a single job ID */
+	uint32_t user_id;	/* set if request for a single user ID */
+
 	List  account_list;
 	List  format_list;
 	List  job_list;
