@@ -8,7 +8,7 @@
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of SLURM, a resource management program.
- *  For details, see <http://www.schedmd.com/slurmdocs/>.
+ *  For details, see <http://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
  *  SLURM is free software; you can redistribute it and/or modify it under
@@ -184,7 +184,7 @@ static bool _retry(void)
 	static char *msg = "Slurm controller not responding, "
 		"sleeping and retrying.";
 
-	if (errno == ESLURM_ERROR_ON_DESC_TO_RECORD_COPY) {
+	if ((errno == ESLURM_ERROR_ON_DESC_TO_RECORD_COPY) || (errno == EAGAIN)) {
 		if (retries == 0)
 			error("%s", msg);
 		else if (retries < MAX_RETRIES)
@@ -207,6 +207,16 @@ static bool _retry(void)
 		      slurm_strerror(ESLURM_NODES_BUSY));
 		error_exit = immediate_exit;
 		return false;
+	} else if ((errno == SLURM_PROTOCOL_AUTHENTICATION_ERROR) ||
+		   (errno == SLURM_UNEXPECTED_MSG_ERROR) ||
+		   (errno == SLURM_PROTOCOL_INSANE_MSG_LENGTH)) {
+		static int external_msg_count = 0;
+		error("Srun communication socket apparently being written to "
+		      "by something other than Slurm");
+		if (external_msg_count++ < 4)
+			return true;
+		error("Unable to allocate resources: %m");
+		return false;
 	} else {
 		error("Unable to allocate resources: %m");
 		return false;
@@ -300,7 +310,7 @@ static int _blocks_dealloc(void)
 		return -1;
 	}
 	for (i=0; i<new_bg_ptr->record_count; i++) {
-		if(new_bg_ptr->block_array[i].state == BG_BLOCK_TERM) {
+		if (new_bg_ptr->block_array[i].state == BG_BLOCK_TERM) {
 			rc = 1;
 			break;
 		}
@@ -379,7 +389,7 @@ allocate_test(void)
 {
 	int rc;
 	job_desc_msg_t *j = job_desc_msg_create_from_opts();
-	if(!j)
+	if (!j)
 		return SLURM_ERROR;
 
 	rc = slurm_job_will_run(j);
@@ -441,14 +451,44 @@ allocate_nodes(bool handle_signals)
 		 * Allocation granted!
 		 */
 		pending_job_id = resp->job_id;
+
+		/*
+		 * These values could be changed while the job was
+		 * pending so overwrite the request with what was
+		 * allocated so we don't have issues when we use them
+		 * in the step creation.
+		 */
+		if (opt.pn_min_memory != NO_VAL)
+			opt.pn_min_memory = (resp->pn_min_memory &
+					     (~MEM_PER_CPU));
+		else if (opt.mem_per_cpu != NO_VAL)
+			opt.mem_per_cpu = (resp->pn_min_memory &
+					   (~MEM_PER_CPU));
+		/*
+		 * FIXME: timelimit should probably also be updated
+		 * here since it could also change.
+		 */
+
 #ifdef HAVE_BG
+		uint32_t node_cnt = 0;
+		select_g_select_jobinfo_get(resp->select_jobinfo,
+					    SELECT_JOBDATA_NODE_CNT,
+					    &node_cnt);
+		if ((node_cnt == 0) || (node_cnt == NO_VAL)) {
+			opt.min_nodes = node_cnt;
+			opt.max_nodes = node_cnt;
+		} /* else we just use the original request */
+
 		if (!_wait_bluegene_block_ready(resp)) {
-			if(!destroy_job)
+			if (!destroy_job)
 				error("Something is wrong with the "
 				      "boot of the block.");
 			goto relinquish;
 		}
 #else
+		opt.min_nodes = resp->node_cnt;
+		opt.max_nodes = resp->node_cnt;
+
 		if (!_wait_nodes_ready(resp)) {
 			if (!destroy_job)
 				error("Something is wrong with the "
@@ -468,10 +508,11 @@ allocate_nodes(bool handle_signals)
 	return resp;
 
 relinquish:
-
-	slurm_free_resource_allocation_response_msg(resp);
-	if (!destroy_job)
-		slurm_complete_job(resp->job_id, 1);
+	if (resp) {
+		if (!destroy_job)
+			slurm_complete_job(resp->job_id, 1);
+		slurm_free_resource_allocation_response_msg(resp);
+	}
 	exit(error_exit);
 	return NULL;
 }
@@ -593,8 +634,8 @@ job_desc_msg_create_from_opts (void)
 		j->argv    = (char **) xmalloc(sizeof(char *) * 2);
 		j->argv[0] = xstrdup(opt.argv[0]);
 	}
-	if (opt.acctg_freq >= 0)
-		j->acctg_freq     = opt.acctg_freq;
+	if (opt.acctg_freq)
+		j->acctg_freq     = xstrdup(opt.acctg_freq);
 	j->reservation    = opt.reservation;
 	j->wckey          = opt.wckey;
 
@@ -602,7 +643,7 @@ job_desc_msg_create_from_opts (void)
 
 	/* simplify the job allocation nodelist,
 	 * not laying out tasks until step */
-	if(j->req_nodes) {
+	if (j->req_nodes) {
 		hl = hostlist_create(j->req_nodes);
 		xfree(opt.nodelist);
 		opt.nodelist = hostlist_ranged_string_xmalloc(hl);
@@ -613,7 +654,7 @@ job_desc_msg_create_from_opts (void)
 
 	}
 
-	if(opt.distribution == SLURM_DIST_ARBITRARY
+	if (opt.distribution == SLURM_DIST_ARBITRARY
 	   && !j->req_nodes) {
 		error("With Arbitrary distribution you need to "
 		      "specify a nodelist or hostfile with the -w option");
@@ -663,6 +704,8 @@ job_desc_msg_create_from_opts (void)
 		j->licenses = opt.licenses;
 	if (opt.network)
 		j->network = opt.network;
+	if (opt.profile)
+		j->profile = opt.profile;
 	if (opt.account)
 		j->account = opt.account;
 	if (opt.comment)
