@@ -157,9 +157,12 @@ int _do_stat(uint32_t jobid, uint32_t stepid, char *nodelist,
 			xfree(step.pid_str);
 		} else {
 			hostlist_push(hl, step_stat->step_pids->node_name);
-			jobacctinfo_2_stats(&temp_stats, step_stat->jobacct);
 			ntasks += step_stat->num_tasks;
-			aggregate_stats(&step.stats, &temp_stats);
+			if (step_stat->jobacct) {
+				jobacctinfo_2_stats(&temp_stats,
+						    step_stat->jobacct);
+				aggregate_stats(&step.stats, &temp_stats);
+			}
 		}
 	}
 	list_iterator_destroy(itr);
